@@ -1,4 +1,4 @@
-/* Copyright (C) 2008 AbiSource Corporation B.V.
+/* Copyright (C) 2008-2009 AbiSource Corporation B.V.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,22 +20,29 @@
 #define __ABICOLLAB_SAVE_INTERCEPTOR__
 
 #include "ev_EditMethod.h"
-#define SAVE_INTERCEPTOR_EM "com.abisource.abiword.abicollab.servicesaveinterceptor"
+#include "RealmConnection.h"
 
 class AV_View;
 class EV_EditMethodCallData;
 class EV_EditMethod;
 class PD_Document;
+class ServiceAccountHandler;
+
 class AbiCollabSaveInterceptor
 {
 public:
 	AbiCollabSaveInterceptor();
 	
 	bool intercept(AV_View * v, EV_EditMethodCallData * d);
-	bool saveRemotely(PD_Document * pDoc);
+	bool save(PD_Document * pDoc);
 	
 private:
-	void _save_cb(UT_Error error, AbiCollab* pSession);
+	bool _save(std::string uri, bool verify_webapp_host, std::string ssl_ca_file,
+			soa::function_call_ptr fc_ptr, boost::shared_ptr<std::string> result_ptr);
+	void _save_cb(bool success, ServiceAccountHandler* pAccount, 
+			AbiCollab* pSession, ConnectionPtr connection_ptr,
+			soa::function_call_ptr fc_ptr, boost::shared_ptr<std::string> result_ptr);
+	void _saveFailed(AbiCollab* pSession);
 
 	EV_EditMethod* m_pOldSaveEM;
 };
