@@ -21,6 +21,7 @@
 #include "SugarBuddy.h"
 #include <account/xp/AccountEvent.h>
 #include <account/xp/Event.h>
+#include <core/account/xp/SessionEvent.h>
 #include <session/xp/AbiCollabSessionManager.h>
 #include <session/xp/AbiCollab.h>
 #include <ev_EditMethod.h>
@@ -30,6 +31,7 @@
 // some fucntion prototype declarations
 static bool s_offerTube(AV_View* v, EV_EditMethodCallData *d);
 static bool s_joinTube(AV_View* v, EV_EditMethodCallData *d);
+static bool s_disconnectTube(AV_View* v, EV_EditMethodCallData *d);
 static bool s_buddyJoined(AV_View* v, EV_EditMethodCallData *d);
 static bool s_buddyLeft(AV_View* v, EV_EditMethodCallData *d);
 static DBusHandlerResult s_dbus_handle_message(DBusConnection *connection, DBusMessage *message, void *user_data);
@@ -44,7 +46,7 @@ SugarAccountHandler* SugarAccountHandler::getHandler() { return m_pHandler; }
 SugarAccountHandler::SugarAccountHandler()
 	: AccountHandler(),
 	m_pTube(NULL),
-	m_bLocallyControlled(false)
+	m_bIsInSession(false)
 {
 	UT_DEBUGMSG(("SugarAccountHandler::SugarAccountHandler()\n"));
 	m_pHandler = this;
@@ -54,11 +56,7 @@ SugarAccountHandler::SugarAccountHandler()
 SugarAccountHandler::~SugarAccountHandler()
 {
 	m_pHandler = NULL;
-	if (m_pTube)
-	{
-		dbus_connection_unref(m_pTube);
-		m_pTube = NULL;
-	}
+	disconnect();
 }
 
 UT_UTF8String SugarAccountHandler::getDescription()
@@ -73,7 +71,7 @@ UT_UTF8String SugarAccountHandler::getDisplayType()
 
 UT_UTF8String SugarAccountHandler::getStaticStorageType()
 {
-	return "com.abisource.abiword.abicollab.backend.sugar";
+	return SUGAR_STATIC_STORAGE_TYPE;
 }
 
 void SugarAccountHandler::storeProperties()
@@ -90,7 +88,11 @@ ConnectResult SugarAccountHandler::connect()
 
 bool SugarAccountHandler::disconnect()
 {
-	UT_ASSERT_HARMLESS(UT_NOT_REACHED);
+	if (m_pTube)
+	{
+		dbus_connection_unref(m_pTube);
+		m_pTube = NULL;
+	}
 	return true;
 }
 
@@ -115,16 +117,31 @@ BuddyPtr SugarAccountHandler::constructBuddy(const PropertyMap& props)
 	return boost::shared_ptr<SugarBuddy>(new SugarBuddy(this, cit->second.c_str()));
 }
 
-BuddyPtr SugarAccountHandler::constructBuddy(const std::string& /*descriptor*/, BuddyPtr /*pBuddy*/)
+BuddyPtr SugarAccountHandler::constructBuddy(const std::string& descriptor, BuddyPtr /*pBuddy*/)
 {
-	UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
-	return SugarBuddyPtr();
+	UT_DEBUGMSG(("SugarAccountHandler::constructBuddy() - descriptor: %s\n", descriptor.c_str()));
+
+	std::string uri_id = "sugar://";
+	UT_return_val_if_fail(descriptor.size() > uri_id.size(), SugarBuddyPtr());
+
+	std::string dbusAddress = descriptor.substr(uri_id.size());
+	SugarBuddyPtr pBuddy = getBuddy(dbusAddress.c_str());
+	UT_return_val_if_fail(pBuddy, SugarBuddyPtr());
+
+	return pBuddy;
 }
 
-bool SugarAccountHandler::recognizeBuddyIdentifier(const std::string& /*identifier*/)
+bool SugarAccountHandler::recognizeBuddyIdentifier(const std::string& identifier)
 {
-	UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
-	return false;
+	std::string uri_id = "sugar://";
+
+	if (identifier.compare(0, uri_id.size(), uri_id) != 0)
+		return false;
+
+	// The rest of the buddy descriptor contains the dbus address, which we
+	// can't really check.
+
+	return true;
 }
 
 void  SugarAccountHandler::handleEvent(Session& /*pSession*/)
@@ -134,35 +151,63 @@ void  SugarAccountHandler::handleEvent(Session& /*pSession*/)
 
 void SugarAccountHandler::signal(const Event& event, BuddyPtr pSource)
 {
-	AccountHandler::signal(event, pSource);
-
 	UT_DEBUGMSG(("SugarAccountHandler::signal()\n"));
 
 	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
 	UT_return_if_fail(pManager);
 
-	// we just want to listen for when we get a document handle from the other side
-	// (this obviously only makes sense for a joining party, not an offering one;
-	// the offering party should never even receive such an event
-	if (event.getClassType() == PCT_AccountBuddyAddDocumentEvent)
+	switch (event.getClassType())
 	{
-		UT_DEBUGMSG(("We received a document handle from an offering party; let's join it immediately!\n"));
-		AccountBuddyAddDocumentEvent& abade = (AccountBuddyAddDocumentEvent&)event;
-
-		if (!m_bLocallyControlled)
-		{
-			DocHandle* pDocHandle = abade.getDocHandle();
-			if (pDocHandle)
+		case PCT_CloseSessionEvent:
 			{
-				UT_DEBUGMSG(("Got dochandle, going to initiate a join on it!\n"));
-				// FIXME: remove const cast
-				pManager->joinSessionInitiate(pSource, pDocHandle);
+				UT_DEBUGMSG(("Got a PCT_CloseSessionEvent\n"));
+				const CloseSessionEvent cse = static_cast<const CloseSessionEvent&>(event);
+				UT_return_if_fail(!pSource); // we shouldn't receive these events over the wire on this backend
+
+				// If the session that is close was started by us, then disconnect from
+				// the tube. Otherwise, just drop the event on the floor....
+
+				if (cse.getSessionId() == m_sSessionId)
+				{
+					UT_DEBUGMSG(("We host session %s, disconnecting...\n", cse.getSessionId().utf8_str()));
+					disconnect();
+				}
 			}
-			else
-				UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-		}
-		else
-			UT_ASSERT_HARMLESS(UT_NOT_REACHED);
+			break;
+
+		case PCT_AccountBuddyAddDocumentEvent:
+			{
+				// Prevent joining other dochandles that come over the wire after having
+				// already joined the one we received just now. This should ofcourse never 
+				// happen, but it will in practice because of a Write/Activity bug.
+				// See ... for details.
+				if (m_bIsInSession)
+				{
+					UT_DEBUGMSG(("Received a bogus AccountBuddyAddDocumentEvent: we are already connected to a session.\n"));
+					return;
+				}
+
+				// We've received a document handle from the other side. This obviously only 
+				// makes sense for a joining party, not an offering one: the offering party 
+				// should never even receive such an event
+
+				UT_DEBUGMSG(("We received a document handle from an offering party; let's join it immediately!\n"));
+				AccountBuddyAddDocumentEvent& abade = (AccountBuddyAddDocumentEvent&)event;
+
+				// FIXME: should we check if we were waiting for a document to come our way?
+
+				DocHandle* pDocHandle = abade.getDocHandle();
+				UT_return_if_fail(pDocHandle);
+
+				UT_DEBUGMSG(("Got dochandle, going to initiate a join on it!\n"));
+				pManager->joinSessionInitiate(pSource, pDocHandle);
+				m_bIsInSession = true;
+			}
+			break;
+
+		default:
+			AccountHandler::signal(event, pSource);
+			break;
 	}
 }
 
@@ -172,9 +217,7 @@ bool SugarAccountHandler::send(const Packet* pPacket)
 	UT_return_val_if_fail(pPacket, false);
 	UT_return_val_if_fail(m_pTube, false);
 
-	// TODO: implement me
-
-	return true;
+	return _send(pPacket, NULL);
 }
 
 bool SugarAccountHandler::send(const Packet* pPacket, BuddyPtr pBuddy)
@@ -186,10 +229,32 @@ bool SugarAccountHandler::send(const Packet* pPacket, BuddyPtr pBuddy)
 	SugarBuddyPtr pSugarBuddy = boost::static_pointer_cast<SugarBuddy>(pBuddy);
 	UT_DEBUGMSG(("Sending packet to sugar buddy on dbus addess: %s\n", pSugarBuddy->getDBusAddress().utf8_str()));
 
-	DBusMessage* pMessage = dbus_message_new_method_call(pSugarBuddy->getDBusAddress().utf8_str(), "/org/laptop/Sugar/Presence/Buddies", INTERFACE, SEND_ONE_METHOD);
-	// TODO: check dst
-	/*bool dst =*/ dbus_message_set_destination(pMessage, pSugarBuddy->getDBusAddress().utf8_str());
-	UT_DEBUGMSG(("Destination (%s) set on message\n", pSugarBuddy->getDBusAddress().utf8_str()));
+	return _send(pPacket, pSugarBuddy->getDBusAddress().utf8_str());
+}
+
+Packet* SugarAccountHandler::createPacket(const std::string& packet, BuddyPtr pBuddy)
+{
+	return _createPacket(packet, pBuddy);
+}
+
+bool SugarAccountHandler::_send(const Packet* pPacket, const char* dbusAddress)
+{
+	UT_DEBUGMSG(("SugarAccountHandler::_send() - dbusAddress: %s\n", dbusAddress ? dbusAddress : "(broadcast)"));
+	UT_return_val_if_fail(pPacket, false);
+	UT_return_val_if_fail(m_pTube, false);
+
+	DBusMessage* pMessage = dbus_message_new_method_call(dbusAddress, "/org/laptop/Sugar/Presence/Buddies", INTERFACE, SEND_ONE_METHOD);
+	if (dbusAddress)
+	{
+		// TODO: isn't this redudant? we already set a destination in dbus_message_new_method_call()
+		if (!dbus_message_set_destination(pMessage, dbusAddress))
+		{
+			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+			dbus_message_unref(pMessage);
+			return false;
+		}
+		UT_DEBUGMSG(("Destination (%s) set on message\n", dbusAddress));
+	}
 
 	// we don't want replies, because then then easily run into dbus timeout problems 
 	// when sending large packets
@@ -201,9 +266,13 @@ bool SugarAccountHandler::send(const Packet* pPacket, BuddyPtr pBuddy)
 	_createPacketStream( data, pPacket );
 
 	const char* packet_contents = &data[0];
-	/*bool append =*/ dbus_message_append_args(pMessage,
-					DBUS_TYPE_ARRAY, DBUS_TYPE_BYTE, &packet_contents, data.size(),
-					DBUS_TYPE_INVALID);
+	if (!dbus_message_append_args(pMessage, DBUS_TYPE_ARRAY, DBUS_TYPE_BYTE, &packet_contents, data.size(), DBUS_TYPE_INVALID))
+	{
+		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+		dbus_message_unref(pMessage);
+		return false;
+	}
+
 	UT_DEBUGMSG(("Appended packet contents\n"));
 
 	bool sent = dbus_connection_send(m_pTube, pMessage, NULL);
@@ -211,12 +280,8 @@ bool SugarAccountHandler::send(const Packet* pPacket, BuddyPtr pBuddy)
 	if (sent)
 		dbus_connection_flush(m_pTube);
 	dbus_message_unref(pMessage);
-	return sent;
-}
 
-Packet* SugarAccountHandler::createPacket(const std::string& packet, BuddyPtr pBuddy)
-{
-	return _createPacket(packet, pBuddy);
+	return sent;	
 }
 
 void SugarAccountHandler::_registerEditMethods()
@@ -243,6 +308,14 @@ void SugarAccountHandler::_registerEditMethods()
 	);
 	pEMC->addEditMethod(emJoinTube);
 
+	EV_EditMethod *emDisconnectTube = new EV_EditMethod (
+		"com.abisource.abiword.abicollab.olpc.disconnectTube",     // name of callback function
+		s_disconnectTube,       // callback function itself.
+		0,                      // no additional data required.
+		""                      // description -- allegedly never used for anything
+	);
+	pEMC->addEditMethod(emDisconnectTube);
+
 	EV_EditMethod *emBuddyJoined = new EV_EditMethod (
 		"com.abisource.abiword.abicollab.olpc.buddyJoined",     // name of callback function
 		s_buddyJoined,       // callback function itself.
@@ -261,6 +334,32 @@ void SugarAccountHandler::_registerEditMethods()
 
 }
 
+void SugarAccountHandler::_handlePacket(Packet* packet, BuddyPtr buddy)
+{
+	UT_DEBUGMSG(("SugarAccountHandler::_handlePacket()\n"));
+
+	UT_return_if_fail(packet);
+	UT_return_if_fail(buddy);
+
+	switch (packet->getClassType())
+	{
+		case PCT_JoinSessionRequestResponseEvent:
+		{
+			JoinSessionRequestResponseEvent* jsre = static_cast<JoinSessionRequestResponseEvent*>( packet );
+			m_sSessionId = jsre->getSessionId();
+			// Let the AccountHandler::_handlePacket() call below handle the actual joining.
+			// This could mean that when the actual joining fails (unlikely), we have
+			// a bogus session ID stored. I doubt it will ever really be a problem though.
+			break;
+		}
+
+		default:
+			break;
+	}
+
+	AccountHandler::_handlePacket(packet, buddy);
+}
+
 bool SugarAccountHandler::offerTube(FV_View* pView, const UT_UTF8String& tubeDBusAddress)
 {
 	UT_DEBUGMSG(("SugarAccountHandler::offerTube()\n"));
@@ -277,31 +376,27 @@ bool SugarAccountHandler::offerTube(FV_View* pView, const UT_UTF8String& tubeDBu
 	UT_DEBUGMSG(("Got tube address: %s\n", tubeDBusAddress.utf8_str()));
 
 	m_pTube = dbus_connection_open(tubeDBusAddress.utf8_str(), NULL);
-	if (m_pTube)
-	{
-		UT_DEBUGMSG(("Opened a dbus connection for tube: %s\n", tubeDBusAddress.utf8_str()));
+	UT_return_val_if_fail(m_pTube, false);
 
-		UT_DEBUGMSG(("Adding dbus handlers to the main loop\n"));
-		dbus_connection_setup_with_g_main(m_pTube, NULL);
+	UT_DEBUGMSG(("Opened a dbus connection for tube: %s\n", tubeDBusAddress.utf8_str()));
 
-		UT_DEBUGMSG(("Adding message filter\n"));
-		dbus_connection_add_filter(m_pTube, s_dbus_handle_message, this, NULL);
+	UT_DEBUGMSG(("Adding dbus handlers to the main loop\n"));
+	dbus_connection_setup_with_g_main(m_pTube, NULL);
 
-		m_bLocallyControlled = true;
+	UT_DEBUGMSG(("Adding message filter\n"));
+	dbus_connection_add_filter(m_pTube, s_dbus_handle_message, this, NULL);
 
-		// we are "connected" now, time to start sending out, and listening to messages (such as events)
-		pManager->registerEventListener(this);
-		// start hosting a session on the current document
-		UT_UTF8String sID;
-		pManager->startSession(pDoc, sID, this, true, NULL, "");
-		return true;
-	}
-	else
-	{
-		UT_DEBUGMSG(("Failed to open a dbus connection for tube: %s\n", tubeDBusAddress.utf8_str()));
-	}
+	// start hosting a session on the current document
+	UT_return_val_if_fail(m_sSessionId == "", false);
+	AbiCollab* pSession = pManager->startSession(pDoc, m_sSessionId, this, true, NULL, "");
+	UT_return_val_if_fail(pSession, false);
 
-	return false;
+	// we are "connected" now, time to start sending out, and listening to messages (such as events)
+	pManager->registerEventListener(this);
+
+	m_bIsInSession = true;
+
+	return true;
 }
 
 bool SugarAccountHandler::joinTube(FV_View* pView, const UT_UTF8String& tubeDBusAddress)
@@ -315,58 +410,55 @@ bool SugarAccountHandler::joinTube(FV_View* pView, const UT_UTF8String& tubeDBus
 	// TODO: check that we aren't already in a session; this backend can only join one session at a time (for now)
 
 	m_pTube = dbus_connection_open(tubeDBusAddress.utf8_str(), NULL);
-	if (m_pTube)
-	{
-		UT_DEBUGMSG(("Opened a dbus connection for tube: %s\n", tubeDBusAddress.utf8_str()));
+	UT_return_val_if_fail(m_pTube, false);
 
-		UT_DEBUGMSG(("Adding dbus handlers to the main loop\n"));
-		dbus_connection_setup_with_g_main(m_pTube, NULL);
+	UT_DEBUGMSG(("Opened a dbus connection for tube: %s\n", tubeDBusAddress.utf8_str()));
 
-		UT_DEBUGMSG(("Adding message filter\n"));
-		dbus_connection_add_filter(m_pTube, s_dbus_handle_message, this, NULL);
+	UT_DEBUGMSG(("Adding dbus handlers to the main loop\n"));
+	dbus_connection_setup_with_g_main(m_pTube, NULL);
 
-		m_bLocallyControlled = false;
+	UT_DEBUGMSG(("Adding message filter\n"));
+	dbus_connection_add_filter(m_pTube, s_dbus_handle_message, this, NULL);
 
-		// we are "connected" now, time to start sending out, and listening to messages (such as events)
-		pManager->registerEventListener(this);
-	}
-	else
-	{
-		UT_DEBUGMSG(("Failed to open a dbus connection for tube: %s\n", tubeDBusAddress.utf8_str()));
-	}
+	// we are "connected" now, time to start sending out, and listening to messages (such as events)
+	pManager->registerEventListener(this);
 
-	return false;
+	// broadcast a request for sessions; if everything is alright then we should
+	// receive exactly 1 session in all the responses combined
+	UT_DEBUGMSG(("Sending a broadcast GetSessionsEvent\n"));
+	GetSessionsEvent event;
+	send(&event);
+
+	return true;
 }
 
-bool SugarAccountHandler::joinBuddy(FV_View* pView, const UT_UTF8String& buddyDBusAddress)
+bool SugarAccountHandler::disconnectTube(FV_View* pView)
 {
-	UT_DEBUGMSG(("SugarAccountHandler::joinBuddy()\n"));
+	UT_DEBUGMSG(("SugarAccountHandler::disconnectTube()\n"));
 	UT_return_val_if_fail(pView, false);
 
-	SugarBuddyPtr pBuddy = boost::shared_ptr<SugarBuddy>(new SugarBuddy(this, buddyDBusAddress));
-	addBuddy(pBuddy);
-
 	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
 	UT_return_val_if_fail(pManager, false);
 
 	PD_Document * pDoc = pView->getDocument();
 	UT_return_val_if_fail(pDoc, false);
 
-	if (m_bLocallyControlled)
-	{
-		AbiCollab* pSession = pManager->getSession(pDoc);
-		UT_return_val_if_fail(pSession, false);
-		pSession->addCollaborator(pBuddy);
-		return true;
-	}
-	else
-	{
-		UT_DEBUGMSG(("Buddy joined, while we are NOT hosting a session; requesting sessions buddy: %s\n", pBuddy->getDescriptor(false).utf8_str()));
-		getSessionsAsync(pBuddy);
-		return true;
-	}
+	AbiCollab* pSession = pManager->getSession(pDoc);
+	UT_return_val_if_fail(pSession, false);
+	pManager->disconnectSession(pSession);
 
-	return false;
+	return true;
+}
+
+bool SugarAccountHandler::joinBuddy(FV_View* pView, const UT_UTF8String& buddyDBusAddress)
+{
+	UT_DEBUGMSG(("SugarAccountHandler::joinBuddy() - buddyDBusAddress: %s\n", buddyDBusAddress.utf8_str()));
+	UT_return_val_if_fail(pView, false);
+
+	SugarBuddyPtr pBuddy = boost::shared_ptr<SugarBuddy>(new SugarBuddy(this, buddyDBusAddress));
+	addBuddy(pBuddy);
+
+	return true;
 }
 
 bool SugarAccountHandler::disjoinBuddy(FV_View* pView, const UT_UTF8String& buddyDBusAddress)
@@ -382,25 +474,14 @@ bool SugarAccountHandler::disjoinBuddy(FV_View* pView, const UT_UTF8String& budd
 	
 	m_ignoredBuddies.erase( buddyDBusAddress ); // buddy name is buddyDBusAddress!
 
- 	if (m_bLocallyControlled)
-	{
-		UT_DEBUGMSG(("Dropping buddy %s from the session!", buddyDBusAddress.utf8_str()));
-		AbiCollab* pSession = pManager->getSessionFromDocumentId(pDoc->getDocUUIDString());
-		if (pSession)
-		{	
-			SugarBuddyPtr pTmpBuddy = boost::shared_ptr<SugarBuddy>(new SugarBuddy(this, buddyDBusAddress));
-			pSession->removeCollaborator(pTmpBuddy);
-			return true;
-		}
-	}
-	else
-	{
-		UT_DEBUGMSG(("The session owner (%s) left!", buddyDBusAddress.utf8_str()));
-		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-		return true;
-	}
+	BuddyPtr pBuddy = getBuddy(buddyDBusAddress);
+	UT_return_val_if_fail(pBuddy, false);
 
-	return false;
+	pManager->removeBuddy(pBuddy, false);
+	
+	// TODO: shouldn't we remove this buddy from our own buddy list?	
+
+	return true;
 }
 
 void SugarAccountHandler::forceDisconnectBuddy(BuddyPtr pBuddy)
@@ -422,7 +503,7 @@ bool SugarAccountHandler::hasAccess(const std::vector<std::string>& /*vAcl*/, Bu
 
 	SugarBuddyPtr pExistingBuddy = getBuddy(pSugarBuddy->getDBusAddress());
 	if (!pExistingBuddy)
-		false;
+		return false;
 
 	return true;
 }
@@ -468,6 +549,17 @@ static bool s_joinTube(AV_View* v, EV_EditMethodCallData *d)
 	return pHandler->joinTube(pView, tubeDBusAddress);
 }
 
+static bool s_disconnectTube(AV_View* v, EV_EditMethodCallData */*d*/)
+{
+	UT_DEBUGMSG(("s_disconnectTube()\n"));
+	UT_return_val_if_fail(v, false);
+	FV_View* pView = static_cast<FV_View *>(v);
+	
+	SugarAccountHandler* pHandler = SugarAccountHandler::getHandler();
+	UT_return_val_if_fail(pHandler, false);
+	return pHandler->disconnectTube(pView);
+}
+
 static bool s_buddyJoined(AV_View* v, EV_EditMethodCallData *d)
 {
 	UT_DEBUGMSG(("s_buddyJoined()\n"));
@@ -493,22 +585,10 @@ static bool s_buddyLeft(AV_View* v, EV_EditMethodCallData *d)
 	UT_UTF8String buddyPath(d->m_pData, d->m_dataLength);
 	UT_DEBUGMSG(("Removing buddy with dbus path %s\n", buddyPath.utf8_str()));
 
-	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
-	UT_return_val_if_fail(pManager, false);
-
 	SugarAccountHandler* pHandler = SugarAccountHandler::getHandler();
 	UT_return_val_if_fail(pHandler, false);
 
-	if (pHandler->isLocallyControlled())
-	{
-		return pHandler->disjoinBuddy(pView, buddyPath);
-	}
-	else
-	{
-		// not much we can do here, but cry; kill off the entire handler
-		pManager->destroyAccount(pHandler);
-		return true;
-	}
+	return pHandler->disjoinBuddy(pView, buddyPath);
 }
 
 DBusHandlerResult s_dbus_handle_message(DBusConnection *connection, DBusMessage *message, void *user_data)
@@ -541,7 +621,9 @@ DBusHandlerResult s_dbus_handle_message(DBusConnection *connection, DBusMessage
 				BuddyPtr pBuddy = pHandler->getBuddy(senderDBusAddress);
 				if (!pBuddy)
 				{
-					UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+					// this can actually happen, for example when joining a tube
+					// we send out a broadcast GetSessionsEvent. Responses from
+					// that can return before joinBuddy() was called for that buddy.
 					pBuddy = boost::shared_ptr<SugarBuddy>(new SugarBuddy( pHandler, senderDBusAddress));
 					pHandler->addBuddy(pBuddy);
 				}
