@@ -569,6 +569,7 @@ bool AbiCollabSessionManager::destroySession(AbiCollab* pSession)
 void AbiCollabSessionManager::disconnectSession(AbiCollab* pSession)
 {
 	UT_return_if_fail(pSession);
+	UT_DEBUGMSG(("AbiCollabSessionManager::disconnectSession() - pSession: %s\n", pSession->getSessionId().utf8_str()));
 
 	if (isLocallyControlled(pSession->getDocument()))
 	{
@@ -581,6 +582,8 @@ void AbiCollabSessionManager::disconnectSession(AbiCollab* pSession)
 		*/
 		if (_canInitiateSessionTakeover(pSession))
 		{
+			UT_DEBUGMSG(("Can initiate session takeover\n"));
+
 			if (pSession->getCollaborators().size() > 0)
 			{
 				std::map<BuddyPtr, std::string>::const_iterator cit = pSession->getCollaborators().begin();
@@ -747,7 +750,7 @@ AbiCollab* AbiCollabSessionManager::startSession(PD_Document* pDoc, UT_UTF8Strin
 	UT_DEBUGMSG(("Creating a new collaboration session with UUID: %s\n", sSessionId.utf8_str()));
 
 	UT_return_val_if_fail(_setupFrame(&pFrame, pDoc), NULL);
-	AbiCollab* pAbiCollab = new AbiCollab(pDoc, sSessionId, pAclAccount, bLocallyOwned, pFrame);
+	AbiCollab* pAbiCollab = new AbiCollab(pDoc, sSessionId, pAclAccount, bLocallyOwned);
 	m_vecSessions.push_back(pAbiCollab);
 	
 	// notify all people we are sharing a new document
@@ -831,15 +834,18 @@ void AbiCollabSessionManager::joinSession(const UT_UTF8String& sSessionId, PD_Do
 	UT_return_if_fail(pDoc);
 	UT_return_if_fail(pAclAccount);
 	
-#ifdef ABICOLLAB_HANDLER_SUGAR		
-	// HACK, remove this some day: the sugar backend should just pass us a frame to use
-	pFrame = XAP_App::getApp()->getLastFocussedFrame();
-	pFrame->loadDocument(pDoc);
-#else
-	UT_return_if_fail(_setupFrame(&pFrame, pDoc));
-#endif
+	if (pAclAccount->getStorageType() == "com.abisource.abiword.abicollab.backend.sugar")
+	{
+		// HACK, remove this some day: the sugar backend should just pass us a frame to use
+		pFrame = XAP_App::getApp()->getLastFocussedFrame();
+		pFrame->loadDocument(pDoc);
+	}
+	else
+	{
+		UT_return_if_fail(_setupFrame(&pFrame, pDoc));
+	}
 
-	AbiCollab* pSession = new AbiCollab(sSessionId, pDoc, docUUID, iRev, pCollaborator, pAclAccount, bLocallyOwned, pFrame);
+	AbiCollab* pSession = new AbiCollab(sSessionId, pDoc, docUUID, iRev, pCollaborator, pAclAccount, bLocallyOwned);
 	m_vecSessions.push_back(pSession);
 
 	// signal everyone that we have joined this session
