@@ -31,23 +31,17 @@
 #include "xap_Frame.h"
 #include "ut_locale.h"
 #include "AbiGOChart.h"
+#include "AbiGOffice.h"
 #include "gr_UnixImage.h"
 #include "gr_UnixCairoGraphics.h"
 #include "xap_Menu_Layouts.h"
 #include "ap_Menu_Id.h"
 
 #include <gtk/gtk.h>
-#include <goffice/graph/gog-data-allocator.h>
-#include <goffice/graph/gog-series.h>
-#include <goffice/graph/gog-guru.h>
-#include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-data-set.h>
-#include <goffice/graph/gog-object-xml.h>
-#include <goffice/data/go-data-simple.h>
-#include <goffice/utils/go-locale.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-libxml.h>
+#include <cairo-svg.h>
 
 #define ABI_TYPE_CONTROL_GUI     (abi_control_gui_get_type ())
 #define ABI_CONTROL_GUI(obj)     (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABI_TYPE_CONTROL_GUI, AbiControlGUI))
@@ -493,7 +487,7 @@ UT_sint32 GR_GOChartManager::makeEmbedView(AD_Document * pDoc, UT_uint32 api, G_
   return iNew;
 }
 
-void GR_GOChartManager::makeSnapShot(UT_sint32 uid, UT_Rect & rec)
+void GR_GOChartManager::makeSnapShot(UT_sint32 uid, G_GNUC_UNUSED UT_Rect & rec)
 {
   if(!getGraphics()->queryProperties(GR_Graphics::DGP_SCREEN))
     {
@@ -501,20 +495,47 @@ void GR_GOChartManager::makeSnapShot(UT_sint32 uid, UT_Rect & rec)
     }
   GR_AbiGOChartItems * pItem = m_vecItems.getNthItem(uid);
   UT_return_if_fail(pItem);  
+  GOChartView * pGOChartView = m_vecGOChartView.getNthItem(uid);
   const PP_AttrProp * pSpanAP = NULL;
   PT_AttrPropIndex api = pItem->m_iAPI;
   bool bHaveProp = m_pDoc->getAttrProp(api, &pSpanAP);
   UT_return_if_fail(bHaveProp);
   const char * pszDataID = NULL;
   pSpanAP->getAttribute("dataid", pszDataID);
-  if(pItem->m_bHasSnapshot)
+  UT_ByteBuf *pBuf;
+/* FIXME: don't enable this code until svg snapshot are supported
+  if ((pBuf = pGOChartView->exportToSVG ()))
     {
-       updatePNGSnapshot(static_cast<AD_Document *>(m_pDoc),rec,pszDataID);
+      UT_UTF8String sID = "snapshot-svg-";
+      sID += pszDataID;
+      if(pItem->m_bHasSnapshot)
+        {
+          m_pDoc->replaceDataItem(sID.utf8_str(),reinterpret_cast< const UT_ByteBuf *>(pBuf));
+        }
+      else
+        {
+          const std::string mimetypeSVG = "image/svg";
+          m_pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypeSVG,NULL);
+          pItem->m_bHasSnapshot = true;
+        }
+      delete pBuf;
     }
-  else
+  else */
+  if ((pBuf = pGOChartView->exportToPNG ()))
     {
-       createPNGSnapshot(static_cast<AD_Document *>(m_pDoc),rec,pszDataID);
-       pItem->m_bHasSnapshot = true;
+      UT_UTF8String sID = "snapshot-png-";
+      sID += pszDataID;
+      if(pItem->m_bHasSnapshot)
+        {
+          m_pDoc->replaceDataItem(sID.utf8_str(),reinterpret_cast< const UT_ByteBuf *>(pBuf));
+        }
+      else
+        {
+          const std::string mimetypePNG = "image/png";
+          m_pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypePNG,NULL);
+          pItem->m_bHasSnapshot = true;
+        }
+      delete pBuf;
     }
 }
 
@@ -523,64 +544,6 @@ bool GR_GOChartManager::isDefault(void)
   return false;
 }
 
-
-bool GR_GOChartManager::createPNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
-					   const char * szDataID)
-{
-  if(isDefault())
-  {
-    return false;
-  }
-  if((rec.width == 0) || (rec.height ==0))
-  {
-    return false;
-  }
-  // TODO: use the goffice framework to get a high resolution png.
-  GR_Image * pImage = static_cast<GR_UnixCairoGraphics*>(getGraphics())->genImageFromRectangle(rec);
-  if(pImage == NULL)
-  {
-    return false;
-  }
-  UT_ByteBuf * pBuf = NULL;
-  pImage->convertToBuffer(&pBuf);
-  UT_UTF8String sID = "snapshot-png-";
-  sID += szDataID;
-  const char* mimetypePNG = NULL;
-  mimetypePNG = g_strdup("image/png");
-  pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypePNG,NULL);
-  delete pBuf;
-  delete pImage;
-  return true;
-}
-
-
-bool GR_GOChartManager::updatePNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
-					   const char * szDataID)
-{
-  if(isDefault())
-  {
-    return false;
-  }
-  if((rec.width == 0) || (rec.height ==0))
-  {
-    return false;
-  }
-  // TODO: use the goffice framework to get a high resolution png.
-  GR_Image * pImage = static_cast<GR_UnixCairoGraphics*>(getGraphics())->genImageFromRectangle(rec);
-  if(pImage == NULL)
-  {
-    return false;
-  }
-  UT_ByteBuf * pBuf = NULL;
-  pImage->convertToBuffer(&pBuf);
-  UT_UTF8String sID = "snapshot-png-";
-  sID += szDataID;
-   pDoc->replaceDataItem(sID.utf8_str(),reinterpret_cast< const UT_ByteBuf *>(pBuf));
-  delete pBuf;
-  delete pImage;
-  return true;
-}
-
 bool GR_GOChartManager::modify(UT_sint32 uid)
 {
   GOChartView * pGOChartView = m_vecGOChartView.getNthItem(uid);
@@ -778,6 +741,35 @@ void GOChartView::render(UT_Rect & rec)
 	cairo_restore (cr);
 }
 
+UT_ByteBuf *GOChartView::exportToPNG ()
+{
+	UT_return_val_if_fail (m_Graph, NULL);
+	UT_ByteBuf *pBuf = new UT_ByteBuf ();
+	cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+										width, height);
+	cairo_t *cr = cairo_create (surface);
+	gog_renderer_render_to_cairo (m_Renderer, cr, width, height);
+	cairo_destroy (cr);
+	cairo_surface_write_to_png_stream (surface,
+	    reinterpret_cast<cairo_write_func_t>(abi_CairoWrite), pBuf);
+	cairo_surface_destroy (surface);
+	return pBuf;
+}
+
+UT_ByteBuf *GOChartView::exportToSVG ()
+{
+	UT_return_val_if_fail (m_Graph, NULL);
+	UT_ByteBuf *pBuf = NULL; /*new UT_ByteBuf ();
+	cairo_surface_t *surface = cairo_svg_surface_create_for_stream (
+										reinterpret_cast<cairo_write_func_t>(UT_ByteBuf::CairoWrite),
+										pBuf, width, height);
+	cairo_t *cr = cairo_create (surface);
+	cairo_surface_destroy (surface);
+	gog_renderer_render_to_cairo (m_Renderer, cr, width, height);
+	cairo_destroy (cr);*/
+	return pBuf;
+}
+
 void GOChartView::loadBuffer(UT_UTF8String & sGOChartXML)
 {
 	if (m_Graph)
