@@ -21,7 +21,9 @@
  */
 
 // Class definition include
+#include "ODe_Style_List.h"
 #include "ODe_Style_Style.h"
+#include "ODe_ListLevelStyle.h"
 
 // Internal includes
 #include "ODe_Common.h"
@@ -111,7 +113,9 @@ bool ODe_Style_Style::write(GsfOutput* pODT, const UT_UTF8String& rSpacesOffset)
     escape = m_masterPageName;
     escape.escapeXML();
     ODe_writeAttribute(output, "style:master-page-name", escape);
-
+    escape = m_listStyleName;
+    escape.escapeXML();
+    ODe_writeAttribute(output, "style:list-style-name", escape);
     
     if (isEmpty()) {
         // This style has no props at all.
@@ -256,16 +260,9 @@ bool ODe_Style_Style::hasParagraphStyleProps(const PP_AttrProp* pAP) {
         return true;
     }
     
-    ok = pAP->getAttribute("listid", pValue);
+    ok = pAP->getProperty("margin-left", pValue);
     if (ok && pValue != NULL) {
-        // This block is a list item, so, its margin-left property is not
-        // valid as paragraph attribute.
-        // So, we don't check for it.
-    } else {
-        ok = pAP->getProperty("margin-left", pValue);
-        if (ok && pValue != NULL) {
-            return true;
-        }
+        return true;
     }
     
     ok = pAP->getProperty("margin-right", pValue);
@@ -353,7 +350,8 @@ bool ODe_Style_Style::isEquivalentTo(const ODe_Style_Style& rStyle) {
          m_family          == rStyle.m_family &&
          m_parentStyleName == rStyle.m_parentStyleName &&
          m_nextStyleName   == rStyle.m_nextStyleName &&
-         m_masterPageName  == rStyle.m_masterPageName;
+         m_masterPageName  == rStyle.m_masterPageName &&
+         m_listStyleName   == rStyle.m_listStyleName;
 
     if (!isEqual) {return false;}
 
@@ -510,7 +508,8 @@ void ODe_Style_Style::fetchAttributesFromAbiSpan(const PP_AttrProp* pAP) {
 /**
  * Fetch attributes from an AbiWord <p> tag. Usually paragraph style attributes.
  */
-void ODe_Style_Style::fetchAttributesFromAbiBlock(const PP_AttrProp* pAP) {
+void ODe_Style_Style::fetchAttributesFromAbiBlock(const PP_AttrProp* pAP,
+        const ODe_Style_List* pCurrentListStyle) {
     const gchar* pValue;
     bool ok;
     
@@ -531,9 +530,20 @@ void ODe_Style_Style::fetchAttributesFromAbiBlock(const PP_AttrProp* pAP) {
     
     ok = pAP->getAttribute("listid", pValue);
     if (ok && pValue != NULL) {
-        // This block is a list item, so, it's margin-left property is not
-        // valid as paragraph attribute.
-        m_pParagraphProps->m_marginLeft.clear();
+        // text:space-before and text:min-label-width are not paragraph properties,
+        // so we'll ignore those.
+        // We could also skip the fo:text-indent and fo:margin-left when they are
+        // the same size as those propties in the list style. It doesn't
+        // hurt to unconditionally write them out though, so we'll leave it
+        // as it is for now.
+        UT_UTF8String spaceBefore;
+        UT_UTF8String minLabelWidth;
+        ODe_ListLevelStyle::calculateListMargins(*pAP, m_pParagraphProps->m_textIndent, spaceBefore, minLabelWidth, m_pParagraphProps->m_marginLeft);
+
+        // store the list style name in the paragraph style
+        UT_ASSERT_HARMLESS(pCurrentListStyle);
+        if (pCurrentListStyle)
+            m_listStyleName = pCurrentListStyle->getName();
     }
 }
 
@@ -615,6 +625,13 @@ void ODe_Style_Style::setColumnWidth(const gchar* pColumnWidth) {
     m_pColumnProps->m_columnWidth = pColumnWidth;
 }
 
+void ODe_Style_Style::setRelColumnWidth(const gchar* pRelColumnWidth) {
+    if (m_pColumnProps == NULL) {
+        m_pColumnProps = new ColumnProps();
+    }
+    m_pColumnProps->m_RelColumnWidth = pRelColumnWidth;
+}
+
 
 /**
  * 
@@ -654,6 +671,62 @@ bool ODe_Style_Style::hasTableStyleProps(const PP_AttrProp* pAP) {
     if (ok && pValue != NULL) {
         return true;
     }
+
+    ok = pAP->getProperty("table-width", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+
+    ok = pAP->getProperty("table-rel-width", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-margin-left", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-margin-top", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-margin-right", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-margin-bottom", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-line-thickness", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-col-spacing", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-row-spacing", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-column-leftpos", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+
+    ok = pAP->getProperty("table-rel-column-props", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
     
     // If we reached this point it's because there are no table props at all
     // on this AbiWord element attributes and properties.
@@ -745,6 +818,14 @@ void ODe_Style_Style::setVerticalPos(const UT_UTF8String& rVerticalPos) {
     m_pGraphicProps->m_verticalPos = rVerticalPos;
 }
 
+void ODe_Style_Style::setVerticalRel(const UT_UTF8String& rVerticalRel) {
+    if (m_pGraphicProps == NULL) {
+        m_pGraphicProps = new GraphicProps();
+    }
+    
+    m_pGraphicProps->m_verticalRel = rVerticalRel;
+}
+
 
 /*******************************************************************************
  * SectionProps
@@ -1290,6 +1371,7 @@ bool ODe_Style_Style::TextProps::operator==(
  */
 bool ODe_Style_Style::TableProps::isEmpty() const {
     return m_width.empty() &&
+           m_RelTableWidth.empty() &&
            m_backgroundColor.empty() &&
            m_align.empty() &&
            m_marginLeft.empty() &&
@@ -1350,6 +1432,13 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     } else {
         m_align = "left";
     }
+
+    ok = rAP.getProperty("table-rel-width", pValue);
+    if (ok && pValue != NULL) 
+    {
+        m_RelTableWidth = pValue;
+    }
+
 }
 
 
@@ -1363,6 +1452,7 @@ void ODe_Style_Style::TableProps::write(UT_UTF8String& rOutput,
     rOutput += "<style:table-properties";
     
     ODe_writeAttribute(rOutput, "style:width", m_width);
+    ODe_writeAttribute(rOutput, "style:rel-width", m_RelTableWidth);
     ODe_writeAttribute(rOutput, "fo:background-color", m_backgroundColor);
     ODe_writeAttribute(rOutput, "table:align", m_align);
     ODe_writeAttribute(rOutput, "fo:margin-left", m_marginLeft);
@@ -1379,6 +1469,7 @@ ODe_Style_Style::TableProps& ODe_Style_Style::TableProps::operator=(
                                               const TableProps& rTableProps) {
 
     m_width = rTableProps.m_width;
+    m_RelTableWidth = rTableProps.m_RelTableWidth;
     m_backgroundColor = rTableProps.m_backgroundColor;
     m_align = rTableProps.m_align;
     m_marginLeft = rTableProps.m_marginLeft;
@@ -1396,6 +1487,7 @@ bool ODe_Style_Style::TableProps::operator==(
                             
     return
         m_width           == rTableProps.m_width &&
+        m_RelTableWidth   == rTableProps.m_RelTableWidth &&
         m_backgroundColor == rTableProps.m_backgroundColor &&
         m_align           == rTableProps.m_align &&
         m_marginLeft      == rTableProps.m_marginLeft &&
@@ -1412,7 +1504,7 @@ bool ODe_Style_Style::TableProps::operator==(
  * 
  */
 bool ODe_Style_Style::ColumnProps::isEmpty() const {
-    return m_columnWidth.empty();
+  return (m_columnWidth.empty() && m_RelColumnWidth.empty());
 }
 
 
@@ -1429,6 +1521,7 @@ void ODe_Style_Style::ColumnProps::write(UT_UTF8String& rOutput,
     rOutput += "<style:table-column-properties";
     
     ODe_writeAttribute(rOutput, "style:column-width", m_columnWidth);
+    ODe_writeAttribute(rOutput, "style:rel-column-width", m_RelColumnWidth);
     
     rOutput += "/>\n";
 }
@@ -1451,7 +1544,8 @@ ODe_Style_Style::ColumnProps& ODe_Style_Style::ColumnProps::operator=(
 bool ODe_Style_Style::ColumnProps::operator==(
                       const ODe_Style_Style::ColumnProps& rColumnProps) const {
                         
-    return m_columnWidth == rColumnProps.m_columnWidth;
+    return m_columnWidth == rColumnProps.m_columnWidth &&
+     m_RelColumnWidth ==  rColumnProps.m_RelColumnWidth;
 }
 
 /*******************************************************************************
@@ -1621,6 +1715,15 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
         // TODO: handle transparent?
         m_backgroundColor = UT_colorToHex(pValue, true);
     }
+
+    // Background Image
+    ok = rAP.getAttribute("strux-image-dataid", pValue);
+    if (ok && pValue != NULL) 
+    {
+        m_backgroundImage = "Pictures/";
+        m_backgroundImage += pValue;
+    }
+
 }
 
 
@@ -1635,8 +1738,11 @@ write(UT_UTF8String& rOutput, const UT_UTF8String& rSpacesOffset) const {
     }
     
     rOutput += rSpacesOffset;
-    rOutput += "<style:table-cell-properties";
-    
+    if(m_backgroundImage.length()==0)
+      rOutput += "<style:table-cell-properties";
+    else
+      rOutput += "<style:table-cell-properties>";
+
     ODe_writeAttribute(rOutput, "fo:border-left", m_leftThickness + " solid " + m_leftColor);
     ODe_writeAttribute(rOutput, "fo:border-right",m_rightThickness + " solid " + m_rightColor);
     ODe_writeAttribute(rOutput, "fo:border-top", m_topThickness + " solid " + m_topColor);
@@ -1644,6 +1750,18 @@ write(UT_UTF8String& rOutput, const UT_UTF8String& rSpacesOffset) const {
     ODe_writeAttribute(rOutput, "fo:background-color", m_backgroundColor);
     
     rOutput += "/>\n";
+
+    if(m_backgroundImage.length()>0)
+    {
+      rOutput += "<style:background-image";
+      ODe_writeAttribute(rOutput,"xlink:href",m_backgroundImage);
+      ODe_writeAttribute(rOutput,"xlink:type","simple");
+      ODe_writeAttribute(rOutput,"xlink:actuate","onLoad");
+      ODe_writeAttribute(rOutput,"style:repeat","stretch");
+      rOutput += "/>\n";
+      rOutput += "</style:table-cell-properties>\n";
+    }
+
 }
 
 
