@@ -29,7 +29,8 @@
 #include "ODi_FontFaceDecls.h"
 #include "ODi_ListenerStateAction.h"
 #include "ODi_ElementStack.h"
- 
+#include "ODi_Abi_Data.h"
+
 // AbiWord includes
 #include <pd_Document.h>
 #include <ut_math.h>
@@ -42,14 +43,16 @@
 /**
  * Constructor
  */
-ODi_Style_Style::ODi_Style_Style(ODi_ElementStack& rElementStack) :
+ODi_Style_Style::ODi_Style_Style(ODi_ElementStack& rElementStack,
+				  ODi_Abi_Data & rAbiData) :
                        ODi_ListenerState("StyleStyle", rElementStack),
                        m_pParentStyle(NULL),
                        m_pNextStyle(NULL),
                        m_haveTopBorder(HAVE_BORDER_UNSPECIFIED),
                        m_haveBottomBorder(HAVE_BORDER_UNSPECIFIED),
                        m_haveLeftBorder(HAVE_BORDER_UNSPECIFIED),
-                       m_haveRightBorder(HAVE_BORDER_UNSPECIFIED)
+                       m_haveRightBorder(HAVE_BORDER_UNSPECIFIED),
+		       m_rAbiData(rAbiData)
 {
     if (rElementStack.hasElement("office:automatic-styles")) {
         m_bAutomatic = true;
@@ -103,6 +106,10 @@ void ODi_Style_Style::startElement(const gchar* pName,
         
         _parse_style_tableCellProperties(ppAtts);
         
+    } else if (!strcmp("style:background-image", pName)) {
+        
+        _parse_style_background_image(ppAtts);
+        
     } else if (!strcmp("style:default-style", pName)) {
         
         const gchar* pAttr;
@@ -569,11 +576,15 @@ void ODi_Style_Style::_parse_style_tableProperties(const gchar** ppProps) {
         m_TableMarginRight = pVal;
     }
 
-
     pVal = UT_getAttribute("style:width",ppProps);
     if (pVal) {
         m_TableWidth = pVal;
     }
+
+    pVal = UT_getAttribute("style:rel-width",ppProps);
+    if (pVal) {
+        m_TableRelWidth = pVal;
+    }
 }
 
 
@@ -587,6 +598,11 @@ void ODi_Style_Style::_parse_style_tableColumnProperties(const gchar** ppProps)
     if (pVal) {
         m_columnWidth = pVal;
     }
+
+    pVal = UT_getAttribute("style:rel-column-width", ppProps);
+    if (pVal) {
+        m_columnRelWidth = pVal;
+    }
 }
 
 
@@ -608,6 +624,28 @@ void ODi_Style_Style::_parse_style_tableRowProperties(const gchar** ppProps) {
 }
 
 
+/**
+ * <style:background-image />
+ */
+void ODi_Style_Style::_parse_style_background_image(const gchar** ppProps) 
+{
+    const gchar* pVal;
+    
+    // only implement link:href for now
+    pVal = UT_getAttribute("xlink:href", ppProps);
+    if (pVal) 
+    {
+         UT_String dataId; // id of the data item that contains the image.
+	 if(!m_rAbiData.addImageDataItem(dataId, ppProps)) 
+	 {
+	     UT_DEBUGMSG(("ODT import: no suitable image importer found\n"));
+	     return;
+	 }
+	 m_backgroundImageID = dataId.c_str();
+    }
+}
+
+
 /**
  * <style:table-cell-properties />
  */
@@ -928,6 +966,16 @@ const UT_UTF8String* ODi_Style_Style::getBackgroundColor() const
 }
 
 
+const UT_UTF8String* ODi_Style_Style::getBackgroundImageID() const
+{
+    if (m_backgroundImageID.empty() && m_pParentStyle) {
+        return m_pParentStyle->getBackgroundImageID();
+    }
+
+    return &m_backgroundImageID;
+}
+
+
 /**
  * If pString is "0.0556in solid #0000ff", rColor will receive "#0000ff",
  * rLength "0.0556in" and rHaveBorder "yes".
