@@ -35,23 +35,21 @@ IE_Exp_OpenXML_Listener::IE_Exp_OpenXML_Listener(PD_Document* doc)
 	savedSection(NULL),
 	paragraph(NULL), 
 	savedParagraph(NULL),
-	table(NULL), 
-	row(NULL), 
-	cell(NULL), 
 	hyperlink(NULL),
-	bookmark(NULL),
 	textbox(NULL),
-	bInTable(false),
 	bInHyperlink(false),
-	bInBookmark(false),
 	bInTextbox(false),
-	idCount(10), //the first ten IDs are reserved for the XML file references
-	bookmarkId("")
+	idCount(10) //the first ten IDs are reserved for the XML file references
 {
 	document = OXML_Document::getNewInstance();
 	
 	if(!pdoc->tellListener(static_cast<PL_Listener *>(this)))
 		document = NULL;	
+
+	if(setPageSize() != UT_OK)
+	{
+		UT_DEBUGMSG(("FRT: ERROR, Setting page size failed\n"));	
+	}
 	if(addDocumentStyles() != UT_OK)
 	{
 		UT_DEBUGMSG(("FRT: ERROR, Adding Document Styles Failed\n"));	
@@ -325,17 +323,42 @@ bool IE_Exp_OpenXML_Listener::populate(PL_StruxFmtHandle /* sfh */, const PX_Cha
 
 				case PTO_Bookmark:
 				{
-					if(!bInBookmark)
-					{
-						bookmarkId = getNextId();
-					}
-					bInBookmark = !bInBookmark;
-
-					bookmark = new OXML_Element_Bookmark(bookmarkId);
-					OXML_SharedElement shared_element_bookmark(static_cast<OXML_Element*>(bookmark));
-
 					if(bHaveProp && pAP)
 					{
+						if(!pAP->getAttribute("name", szValue))
+						{
+							UT_DEBUGMSG(("FRT:OpenXML exporter bookmark without name attribute\n"));
+							return true;
+						}
+						std::string bookmarkName(szValue);
+
+						if(!pAP->getAttribute("type", szValue))
+						{
+							UT_DEBUGMSG(("FRT:OpenXML exporter bookmark without type attribute\n"));
+							return true;
+						}
+						std::string bookmarkType(szValue);
+
+						std::string bookmarkId("");
+						if(!bookmarkType.compare("start"))
+						{
+							bookmarkId = getNextId();
+							document->setBookmarkName(bookmarkId, bookmarkName);
+						}
+						else if(!bookmarkType.compare("end"))
+						{
+							bookmarkId = document->getBookmarkId(bookmarkName);
+						}
+						else
+						{
+							UT_DEBUGMSG(("FRT:OpenXML exporter bookmark with invalid type attribute=%s\n", bookmarkType.c_str()));
+							return true;
+						}							
+
+						OXML_Element_Bookmark* bookmark = new OXML_Element_Bookmark(bookmarkId);
+						bookmark->setName(bookmarkId);
+						OXML_SharedElement shared_element_bookmark(static_cast<OXML_Element*>(bookmark));
+
 						size_t propCount = pAP->getPropertyCount();
 				
 						size_t i;
@@ -362,8 +385,9 @@ bool IE_Exp_OpenXML_Listener::populate(PL_StruxFmtHandle /* sfh */, const PX_Cha
 									return false;		
 							}
 						}
+						return paragraph->appendElement(shared_element_bookmark) == UT_OK;
 					}
-					return paragraph->appendElement(shared_element_bookmark) == UT_OK;
+					return true;
 				}
 				default:
 					return true;
@@ -465,8 +489,11 @@ bool IE_Exp_OpenXML_Listener::populateStrux(PL_StruxDocHandle sdh, const PX_Chan
 				}
 			}
 			
-			if(bInTable)
+			if(!m_cellStack.empty())
+			{
+				OXML_Element_Cell* cell = m_cellStack.top();
 				return cell->appendElement(shared_paragraph) == UT_OK;
+			}
 			else if(bInTextbox)
 				return textbox->appendElement(shared_paragraph) == UT_OK;
 
@@ -570,8 +597,7 @@ bool IE_Exp_OpenXML_Listener::populateStrux(PL_StruxDocHandle sdh, const PX_Chan
 		}
 		case PTX_SectionTable:
 		{	
-			bInTable = true;
-			table = new OXML_Element_Table(getNextId());
+			OXML_Element_Table* table = new OXML_Element_Table(getNextId());
 			OXML_SharedElement shared_table(static_cast<OXML_Element*>(table));
 
 			if(bHaveProp && pAP)
@@ -607,17 +633,52 @@ bool IE_Exp_OpenXML_Listener::populateStrux(PL_StruxDocHandle sdh, const PX_Chan
 			}
 			tableHelper.OpenTable(sdh, pcr->getIndexAP());
 
+			bool tableInTable = !m_tableStack.empty();
+			m_tableStack.push(table);
+
+			if(tableInTable)
+			{
+				//this is a table inside another table
+				OXML_Element_Cell* cell = m_cellStack.top();
+				return cell->appendElement(shared_table) == UT_OK;
+			}
+
 			return section->appendElement(shared_table) == UT_OK;
 		}
 		case PTX_SectionCell:
 		{
+			OXML_Element_Table* table = NULL;
+			if(!m_tableStack.empty())
+				table = m_tableStack.top();
+
+			if(!table)
+			{
+				UT_DEBUGMSG(("FRT: OpenXML exporter corrupted table layout. Invalid Cell Open."));
+				return false;
+			}
+
+			OXML_Element_Row* row = NULL;
+			if(!m_rowStack.empty())
+				row = m_rowStack.top();
+
 			tableHelper.OpenCell(api);
 			UT_sint32 left = tableHelper.getLeft();
 			UT_sint32 right = tableHelper.getRight();
 			UT_sint32 top = tableHelper.getTop();
 			UT_sint32 bottom = tableHelper.getBot();
 
-			cell = new OXML_Element_Cell(getNextId(), table, left, right, top, bottom);
+			if(!row || tableHelper.isNewRow())
+			{
+				row = new OXML_Element_Row(getNextId(), table);
+				m_rowStack.push(row);
+				row->setNumCols(tableHelper.getNumCols());
+				OXML_SharedElement shared_row(static_cast<OXML_Element*>(row));
+				if(table->appendElement(shared_row) != UT_OK)
+					return false;
+			}
+
+			OXML_Element_Cell* cell = new OXML_Element_Cell(getNextId(), table, row, left, right, top, bottom);
+			m_cellStack.push(cell);
 			OXML_SharedElement shared_cell(static_cast<OXML_Element*>(cell));
 
 			if(bHaveProp && pAP)
@@ -651,16 +712,7 @@ bool IE_Exp_OpenXML_Listener::populateStrux(PL_StruxDocHandle sdh, const PX_Chan
 					}
 				}
 			}
-			
-			if(!row || tableHelper.isNewRow())
-			{
-				row = new OXML_Element_Row(getNextId(), table);
-				row->setNumCols(tableHelper.getNumCols());
-				OXML_SharedElement shared_row(static_cast<OXML_Element*>(row));
-				if(table->appendElement(shared_row) != UT_OK)
-					return false;
-			}
-			
+					
 			return row->appendElement(shared_cell) == UT_OK;
 		}
 		case PTX_SectionFootnote:
@@ -773,12 +825,30 @@ bool IE_Exp_OpenXML_Listener::populateStrux(PL_StruxDocHandle sdh, const PX_Chan
 		case PTX_EndCell:
 		{
 			tableHelper.CloseCell();
+			if(m_cellStack.empty())
+				return false;
+
+			m_cellStack.pop();
 			return true;
 		}
 		case PTX_EndTable:
 		{
-			bInTable = false;
 			tableHelper.CloseTable();
+			if(m_tableStack.empty())
+				return false;
+
+			//pop the rows that belong to this table
+			int nRows = m_tableStack.top()->getNumberOfRows();
+			for(int i=0; i<nRows; i++)
+			{
+				if(m_rowStack.empty())
+					return false;
+			
+				m_rowStack.pop();
+			}
+
+			//pop the table
+			m_tableStack.pop();
 			return true;
 		}
 		case PTX_EndFootnote:
@@ -950,31 +1020,31 @@ UT_Error IE_Exp_OpenXML_Listener::addImages()
 	UT_Error err = UT_OK;
 
 	const char* szName = NULL;
-	const char* szMimeType = NULL;
-	const char** pszMimeType = &szMimeType;
+    std::string mimeType;
 	const UT_ByteBuf* pByteBuf = NULL;
 
 	UT_uint32 k = 0;
-	while (pdoc->enumDataItems (k, 0, &szName, &pByteBuf, reinterpret_cast<const void**>(pszMimeType)))
+	while (pdoc->enumDataItems (k, 0, &szName, &pByteBuf, &mimeType))
 	{
 		k++;
 
-		if(!(szName && *szName && szMimeType && *szMimeType && pByteBuf && pByteBuf->getLength()))
+		if(!(szName && *szName && !mimeType.empty() && pByteBuf && pByteBuf->getLength()))
 		{
 			szName = NULL;
-			szMimeType = NULL;
+			mimeType.clear();
 			pByteBuf = NULL;
 			continue;
 		}
 
-		if(!(strcmp(szMimeType, "image/png") == 0 || strcmp(szMimeType, "image/svg+xml") == 0))
+		if(!((mimeType == "image/png") || (mimeType == "image/jpeg") || (mimeType == "image/svg+xml")))
 		{
 			// If you add a mime type, make sure to update the extension code in
 			// PD_Document::getDataItemFileExtension()
-			UT_DEBUGMSG(("OpenXML export: unhandled/ignored mime type: %s\n", szMimeType));
+			UT_DEBUGMSG(("OpenXML export: unhandled/ignored mime type: %s\n", 
+                         mimeType.c_str()));
 
 			szName = NULL;
-			szMimeType = NULL;
+			mimeType.clear();
 			pByteBuf = NULL;
 			continue;
 		}
@@ -983,7 +1053,7 @@ UT_Error IE_Exp_OpenXML_Listener::addImages()
 		const OXML_SharedImage shared_image(image);			
 
 		image->setId(szName);
-		image->setMimeType(szMimeType);
+		image->setMimeType(mimeType);
 		image->setData(pByteBuf);
 
 		err = document->addImage(shared_image);
@@ -991,7 +1061,7 @@ UT_Error IE_Exp_OpenXML_Listener::addImages()
 			return err;
 		
 		szName = NULL;
-		szMimeType = NULL;
+		mimeType.clear();
 		pByteBuf = NULL;
 	}
 
@@ -1009,3 +1079,43 @@ std::string IE_Exp_OpenXML_Listener::getNextId()
 	str += buffer;
 	return str;
 }
+
+UT_Error IE_Exp_OpenXML_Listener::setPageSize()
+{
+	const fp_PageSize* ps = pdoc->getPageSize();
+	if(!ps)
+		return UT_ERROR;
+
+	double w = ps->Width(DIM_IN) * 1440; //1440 twips = 1 in
+	double h = ps->Height(DIM_IN) * 1440;
+	bool portrait = ps->isPortrait();
+	double mt = ps->MarginTop(DIM_IN);
+	double ml = ps->MarginLeft(DIM_IN);
+	double mr = ps->MarginRight(DIM_IN);
+	double mb = ps->MarginBottom(DIM_IN);
+
+	std::string width(UT_convertToDimensionlessString(w, ".0"));
+	std::string height(UT_convertToDimensionlessString(h, ".0"));
+	std::string orientation("portrait");
+	std::string marginTop(UT_convertToDimensionlessString(mt, ".0"));
+	std::string marginLeft(UT_convertToDimensionlessString(ml, ".0"));
+	std::string marginRight(UT_convertToDimensionlessString(mr, ".0"));
+	std::string marginBottom(UT_convertToDimensionlessString(mb, ".0"));
+	marginTop += "in";
+	marginLeft += "in";
+	marginRight += "in";
+	marginBottom += "in";
+
+	if(!portrait)
+		orientation = "landscape";
+
+	if(!document)
+		return UT_ERROR;
+
+	document->setPageWidth(width);
+	document->setPageHeight(height);
+	document->setPageOrientation(orientation);
+	document->setPageMargins(marginTop, marginLeft, marginRight, marginBottom);
+
+	return UT_OK;			
+}
