@@ -106,7 +106,7 @@ tScriptRecordDigitSubstitution GR_Win32USPGraphics::fScriptRecordDigitSubstituti
 }
 
 #define GR_WIN32_USP_FONT_SCALING 20
-class GR_Win32USPItem: public GR_Item
+class ABI_EXPORT GR_Win32USPItem: public GR_Item
 {
 	friend class GR_Win32USPGraphics;
 
@@ -126,7 +126,7 @@ class GR_Win32USPItem: public GR_Item
 	SCRIPT_ITEM m_si;
 };
 
-class GR_Win32USPRenderInfo : public GR_RenderInfo
+class ABI_EXPORT GR_Win32USPRenderInfo : public GR_RenderInfo
 {
   public:
 	GR_Win32USPRenderInfo(GR_ScriptType type):
@@ -1308,7 +1308,9 @@ void GR_Win32USPGraphics::renderChars(GR_RenderInfo & ri)
 
 		if(!iAscentScreen)
 		{
-			TEXTMETRIC tm = { 0 };
+			TEXTMETRIC tm;
+			memset(&tm, 0, sizeof(tm));
+
 			GetTextMetrics(m_hdc, &tm);
 			iAscentScreen = (UT_sint32)((double)tm.tmAscent*(double)getResolution()*100.0/
 										((double)getDeviceResolution()*(double)getZoomPercentage()));
@@ -1455,7 +1457,9 @@ void GR_Win32USPGraphics::measureRenderedCharWidths(GR_RenderInfo & ri)
 			_setupFontOnDC(pFont, false);
 			bFontSetUpOnDC = true;
 			
-			TEXTMETRIC tm = { 0 };
+			TEXTMETRIC tm;
+			memset(&tm, 0, sizeof(tm));
+
 			GetTextMetrics(getPrintDC(), &tm);
 
 #if 0 //def DEBUG
@@ -1565,12 +1569,19 @@ void GR_Win32USPGraphics::measureRenderedCharWidths(GR_RenderInfo & ri)
 		
 		
 		SCRIPT_CACHE sc = NULL;
-		HRESULT hRes = fScriptPlace(m_hdc, &sc, RI.m_pIndices, RI.m_iIndicesCount, RI.m_pVisAttr,
+		HRESULT hResFSP = fScriptPlace(m_hdc, &sc, RI.m_pIndices, RI.m_iIndicesCount, RI.m_pVisAttr,
 									& pItem->m_si.a, pAdvances, pGoffsets, & stABC);
 
-		UT_ASSERT_HARMLESS( !hRes );
-		if(!hRes)
+		UT_ASSERT_HARMLESS( !hResFSP );
+		if(!hResFSP)
+		{
 			bAdjustAdvances = true;
+		}
+		else
+		{
+			UT_ASSERT_HARMLESS( UT_SHOULD_NOT_HAPPEN );
+			LOG_USP_EXCPT_X("fScriptPlace failed", hResFSP)
+		}
 
 		if(sc)
 			fScriptFreeCache(&sc);			
@@ -1699,7 +1710,7 @@ void GR_Win32USPGraphics::measureRenderedCharWidths(GR_RenderInfo & ri)
 	}
 }
 
-void GR_Win32USPGraphics::appendRenderedCharsToBuff(GR_RenderInfo & ri, UT_GrowBuf & buf) const
+void GR_Win32USPGraphics::appendRenderedCharsToBuff(GR_RenderInfo & /*ri*/, UT_GrowBuf & /*buf*/) const
 {
 	UT_return_if_fail( UT_NOT_IMPLEMENTED );
 }
@@ -2159,7 +2170,7 @@ void GR_Win32USPGraphics::justify(GR_RenderInfo & ri)
 	UT_ASSERT_HARMLESS( !iExtraSpace );
 }
 
-UT_uint32 GR_Win32USPGraphics::XYToPosition(const GR_RenderInfo & ri, UT_sint32 x, UT_sint32 y) const
+UT_uint32 GR_Win32USPGraphics::XYToPosition(const GR_RenderInfo & ri, UT_sint32 x, UT_sint32 /*y*/) const
 {
 	UT_return_val_if_fail(ri.getType() == GRRI_WIN32_UNISCRIBE, 0);
 	GR_Win32USPRenderInfo & RI = (GR_Win32USPRenderInfo &) ri;
@@ -2203,9 +2214,9 @@ UT_uint32 GR_Win32USPGraphics::XYToPosition(const GR_RenderInfo & ri, UT_sint32
 }
 
 void GR_Win32USPGraphics::positionToXY(const GR_RenderInfo & ri,
-										  UT_sint32& x, UT_sint32& y,
-										  UT_sint32& x2, UT_sint32& y2,
-										  UT_sint32& height, bool& bDirection) const
+										  UT_sint32& x, UT_sint32& /*y*/,
+										  UT_sint32& x2, UT_sint32& /*y2*/,
+										  UT_sint32& /*height*/, bool& /*bDirection*/) const
 {
 	UT_return_if_fail(ri.getType() == GRRI_WIN32_UNISCRIBE);
 	GR_Win32USPRenderInfo & RI = (GR_Win32USPRenderInfo &) ri;
@@ -2382,7 +2393,7 @@ void GR_Win32USPGraphics::setZoomPercentage(UT_uint32 iZoom)
 // GR_WinUSPRenderInfo Implementation
 //
 
-bool GR_Win32USPRenderInfo::append(GR_RenderInfo &ri, bool bReverse)
+bool GR_Win32USPRenderInfo::append(GR_RenderInfo & /*ri*/, bool /*bReverse*/)
 {
 	//UT_return_val_if_fail( UT_NOT_IMPLEMENTED, false );
 	m_bNeedsReshaping = true;
@@ -2390,7 +2401,7 @@ bool GR_Win32USPRenderInfo::append(GR_RenderInfo &ri, bool bReverse)
 	return false;
 }
 
-bool GR_Win32USPRenderInfo::split (GR_RenderInfo *&pri, bool bReverse)
+bool GR_Win32USPRenderInfo::split (GR_RenderInfo *&pri, bool /*bReverse*/)
 {
 	UT_return_val_if_fail(m_pGraphics && m_pFont && m_pItem, false);
 
@@ -2549,7 +2560,7 @@ bool GR_Win32USPRenderInfo::split (GR_RenderInfo *&pri, bool bReverse)
 #endif
 }
 
-bool GR_Win32USPRenderInfo::cut(UT_uint32 offset, UT_uint32 iLen, bool bReverse)
+bool GR_Win32USPRenderInfo::cut(UT_uint32 /*offset*/, UT_uint32 /*iLen*/, bool /*bReverse*/)
 {
 	//UT_return_val_if_fail( UT_NOT_IMPLEMENTED, false );
 	m_bNeedsReshaping = true;
