@@ -1447,6 +1447,10 @@ static cairo_line_join_t mapJoinStyle(GR_Graphics::JoinStyle in)
     }
 }
 
+void GR_CairoGraphics::_resetClip(void)
+{
+	cairo_reset_clip(m_cr);
+}
 
 void GR_CairoGraphics::_setProps()
 {
@@ -1460,7 +1464,7 @@ void GR_CairoGraphics::_setProps()
 	}
 	if(m_clipRectDirty)
 	{
-		cairo_reset_clip(m_cr);
+		_resetClip();
 		if (m_pRect)
 		{
 			double x, y, width, height;
@@ -1633,10 +1637,29 @@ bool GR_CairoGraphics::canBreak(GR_RenderInfo & ri, UT_sint32 &iNext,
 }
 
 
-bool GR_CairoGraphics::needsSpecialCaretPositioning(GR_RenderInfo &)
+bool GR_CairoGraphics::needsSpecialCaretPositioning(GR_RenderInfo &ri)
 {
 	// something smarter is needed here, so we do not go through this for
 	// langugages that do not need it.
+	// HACK HACK HACK
+	// This simple code will return false for European Languages, 
+	// otherwise it will return true
+	// We should really some fancy pango function to determine if 
+	// we have a complex script with combining chars
+	//
+	GR_PangoRenderInfo & RI = (GR_PangoRenderInfo &)ri;
+	if(RI.m_pText == NULL)
+		return false;
+
+	UT_TextIterator & text = static_cast<UT_TextIterator &>(*RI.m_pText);
+
+	for(UT_sint32 i = 0; i < RI.m_iLength && text.getStatus() == UTIter_OK;
+		++i, ++text)
+	{
+		UT_UCS4Char c = text.getChar();
+		if(c != ' ' && c<256)
+			return false;
+	}
 	return true;
 }
 
@@ -2378,19 +2401,23 @@ void GR_CairoGraphics::drawImage(GR_Image* pImg,
 	double idy = _tdudY(yDest);
 
 	cairo_save(m_cr);
-	cairo_reset_clip(m_cr);
+	_resetClip();
 
 	if (pImg->getType() == GR_Image::GRT_Raster) {
 		static_cast<GR_CairoRasterImage*>(pImg)->cairoSetSource(m_cr, idx, idy);
 	} else if (pImg->getType() == GR_Image::GRT_Vector) {
 		static_cast<GR_CairoVectorImage*>(pImg)->cairoSetSource(m_cr, idx, idy);
 	}
+	cairo_antialias_t prevAntiAlias = cairo_get_antialias(m_cr);
+	if(!getAntiAliasAlways() && queryProperties(GR_Graphics::DGP_PAPER ))
+		cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
 
 	cairo_pattern_t *pattern = cairo_get_source(m_cr);
 	cairo_pattern_set_extend(pattern, CAIRO_EXTEND_NONE);
 	cairo_rectangle(m_cr, idx, idy, iImageWidth, iImageHeight);
 	cairo_fill(m_cr);
 
+	cairo_set_antialias(m_cr,prevAntiAlias);
 	cairo_restore(m_cr);
 }
 
@@ -2912,7 +2939,8 @@ void GR_CairoGraphics::drawLine(UT_sint32 x1, UT_sint32 y1,
 	UT_sint32 idy1 = _tduY(y1);
 	UT_sint32 idy2 = _tduY(y2);
 	cairo_antialias_t prevAntiAlias = cairo_get_antialias(m_cr);
-	cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
+	if(!getAntiAliasAlways())
+		cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
 	cairo_move_to (m_cr,idx1, idy1);
 	cairo_line_to (m_cr,idx2, idy2);
 	cairo_stroke (m_cr);
@@ -2994,7 +3022,8 @@ void GR_CairoGraphics::xorLine(UT_sint32 x1, UT_sint32 y1, UT_sint32 x2,
 		r.height = tlu(idy2 - idy1+2);
 		saveRectangle(r,m_iPrevRect);
 		cairo_antialias_t prevAntiAlias = cairo_get_antialias(m_cr);
-		cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
+		if(!getAntiAliasAlways())
+			cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
 		cairo_save(m_cr);
 		cairo_set_source_rgb(m_cr, 0.0 , 0.0 , 0.0);
 
@@ -3014,7 +3043,8 @@ void GR_CairoGraphics::polyLine(UT_Point * pts, UT_uint32 nPoints)
 
 	UT_return_if_fail(nPoints > 1);
 	cairo_antialias_t prevAntiAlias = cairo_get_antialias(m_cr);
-	cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
+	if(!getAntiAliasAlways())
+		cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
 
 	i = 0;
 	cairo_move_to(m_cr, _tdudX(pts[i].x), _tdudY(pts[i].y));
@@ -3066,7 +3096,8 @@ void GR_CairoGraphics::fillRect(const UT_RGBColor& c, UT_sint32 x, UT_sint32 y,
 {
 	_setProps();
 	cairo_antialias_t prevAntiAlias = cairo_get_antialias(m_cr);
-	cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
+	if(!getAntiAliasAlways())
+		cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
 	cairo_save(m_cr);
 
 	_setSource(m_cr, c);
@@ -3167,7 +3198,8 @@ void GR_CairoGraphics::fillRect(GR_Color3D c, UT_sint32 x, UT_sint32 y, UT_sint3
 	_setProps();
 	UT_ASSERT(m_bHave3DColors && c < COUNT_3D_COLORS);
 	cairo_antialias_t prevAntiAlias = cairo_get_antialias(m_cr);
-	cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
+	if(!getAntiAliasAlways())
+		cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
 
 	cairo_save (m_cr);
 
@@ -3190,7 +3222,8 @@ void GR_CairoGraphics::polygon(UT_RGBColor& c, UT_Point *pts,
 
 	UT_return_if_fail(nPoints > 1);
 	cairo_antialias_t prevAntiAlias = cairo_get_antialias(m_cr);
-	cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
+	if(!getAntiAliasAlways())
+		cairo_set_antialias(m_cr,CAIRO_ANTIALIAS_NONE);
 	cairo_save(m_cr);
 
 	i = 0;
@@ -3392,9 +3425,9 @@ bool GR_PangoFont::doesGlyphExist(UT_UCS4Char g)
 	return true;
 }
 
-static double fontPoints2float(UT_sint32 iSize, UT_sint32 iFontPoints)
+static double fontPoints2float(double dSize, UT_sint32 iFontPoints)
 {
-	return iSize * ((double)iFontPoints / PANGO_SCALE) * 1.44/20.; // Last 20 is points to inches
+	return dSize * ((double)iFontPoints / PANGO_SCALE) * 1.44/20.; // Last 20 is points to inches
 }
 
 static PangoGlyph getGlyphForChar(UT_UCS4Char g,
@@ -3452,16 +3485,16 @@ bool GR_PangoFont::glyphBox(UT_UCS4Char g, UT_Rect & rec, GR_Graphics * pG)
 	PangoRectangle ink_rect;
 	pango_font_get_glyph_extents(m_pLayoutF, iGlyphIndx, &ink_rect, NULL);
 
-	UT_sint32 iSize = (UT_sint32)(0.5 + resRatio *(double)pG->getResolution() /
-								  (double)pG->getDeviceResolution());
+	double dSize = resRatio *(double)pG->getResolution() /
+								  (double)pG->getDeviceResolution();
 
-	rec.left   = static_cast<UT_sint32>(0.5 + fontPoints2float(iSize, ink_rect.x));
+	rec.left   = static_cast<UT_sint32>(0.5 + fontPoints2float(dSize, ink_rect.x));
 	
-	rec.width  = static_cast<UT_sint32>(0.5 + fontPoints2float(iSize, ink_rect.width));
+	rec.width  = static_cast<UT_sint32>(0.5 + fontPoints2float(dSize, ink_rect.width));
 	
-	rec.top    = static_cast<UT_sint32>(0.5 + fontPoints2float(iSize, -ink_rect.y));
+	rec.top    = static_cast<UT_sint32>(0.5 + fontPoints2float(dSize, -ink_rect.y));
 	
-	rec.height = static_cast<UT_sint32>(0.5 + fontPoints2float(iSize, ink_rect.height));
+	rec.height = static_cast<UT_sint32>(0.5 + fontPoints2float(dSize, ink_rect.height));
 
 	UT_DEBUGMSG(("GlyphBox: %c [l:%d, w:%d, t:%d, h:%d\n",
 				 (char)g, rec.left,rec.width,rec.top,rec.height));
