@@ -70,11 +70,10 @@ bool GR_EmbedView::getSnapShots(void)
   UT_UTF8String sName = "snapshot-png-";
   sName += m_sDataID;
   bool bFound = false;
-  const void * pToken = NULL;
   void * pHandle = NULL;
   const UT_ByteBuf * pPNG = NULL;
   const UT_ByteBuf * pSVG = NULL;
-  bFound = m_pDoc->getDataItemDataByName(sName.utf8_str(),&pPNG,&pToken,&pHandle);
+  bFound = m_pDoc->getDataItemDataByName(sName.utf8_str(),&pPNG,NULL,&pHandle);
   if(!bFound)
   {
     m_bHasPNGSnapshot = false;    
@@ -87,7 +86,7 @@ bool GR_EmbedView::getSnapShots(void)
   }
   UT_UTF8String sPNGName = "snapshot-svg-";
   sName += m_sDataID;
-  bFound = m_pDoc->getDataItemDataByName(sName.utf8_str(),&pSVG,&pToken,&pHandle);
+  bFound = m_pDoc->getDataItemDataByName(sName.utf8_str(),&pSVG,NULL,&pHandle);
   if(!bFound)
   {
     m_bHasSVGSnapshot = false;    
@@ -437,7 +436,7 @@ void GR_EmbedManager::render(UT_sint32 uid ,UT_Rect & rec )
       iHeight = rec.height;
       iWidth = rec.width;
     }
-    pEView->m_pPreview = getGraphics()->createNewImage(pEView->m_sDataID.utf8_str(),pEView->m_PNGBuf,iWidth,iHeight);
+    pEView->m_pPreview = getGraphics()->createNewImage(pEView->m_sDataID.utf8_str(),pEView->m_PNGBuf,"image/png",iWidth,iHeight);
     GR_Painter painter(getGraphics());
     painter.drawImage(pEView->m_pPreview,rec.left,rec.top);
     return;
