@@ -356,6 +356,7 @@ class ABI_EXPORT AllCarets
 	void	    enable(void);
 	void		disable(bool bNoMulti = false);
 	void		setBlink(bool bBlink);
+	void        JustErase(UT_sint32 xPoint,UT_sint32 yPoint);
 	void        setWindowSize(UT_uint32 width, UT_uint32 height);
 	void		setCoords(UT_sint32 x, UT_sint32 y, UT_uint32 h,
 						  UT_sint32 x2 = 0, UT_sint32 y2 = 0, UT_uint32 h2 = 0, 
@@ -399,6 +400,11 @@ class ABI_EXPORT GR_Graphics
 	UT_sint32	tlu(UT_sint32 deviceUnits) const;
 	double	    tduD(double layoutUnits) const;
 	double  	tluD(double deviceUnits) const;
+	void        antiAliasAlways(bool bAntiAlias)
+	{ m_bAntiAliasAlways = bAntiAlias;}
+	bool        getAntiAliasAlways(void)
+	{ return m_bAntiAliasAlways;}
+
 	/*!
 		Font units to layout units. Returns the dimension in layout units since font
 		are not Zoomed
@@ -870,6 +876,7 @@ class ABI_EXPORT GR_Graphics
 	static UT_UCS4Char      s_cDefaultGlyph;
 	UT_GenericVector<GR_Caret *>  m_vecCarets;
 	AllCarets               m_AllCarets;
+	bool                    m_bAntiAliasAlways;
 };
 
 #endif /* GR_GRAPHICS_H */
