@@ -1,3 +1,5 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+
 /* AbiSource Application Framework
  * Copyright (C) 1998-2000 AbiSource, Inc.
  * Copyright (C) 2002
@@ -18,6 +20,9 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "xap_Win32FrameImpl.h"
 #include "commctrl.h"
@@ -118,13 +123,18 @@ XAP_Win32FrameImpl::XAP_Win32FrameImpl(XAP_Frame *pFrame) :
 	m_hwndRebar(NULL),
 	m_hwndContainer(NULL),
 	m_hwndStatusBar(NULL),
-	m_dialogFactory(pFrame, XAP_App::getApp()), /* note: pFrame->getApp() not initialized properly yet! */
+	m_dialogFactory(XAP_App::getApp(), pFrame), /* note: pFrame->getApp() not initialized properly yet! */		
 	m_pWin32Menu(NULL),
 	m_pWin32Popup(NULL),
 	m_iBarHeight(0),
 	m_iStatusBarHeight(0),
-	m_iRealSizeWidth(0),
 	m_iRealSizeHeight(0),
+	m_iRealSizeWidth(0),
+	m_iWindowStateBeforeFS(SW_SHOWNORMAL),
+	m_iWindowXBeforeFS(0),
+	m_iWindowYBeforeFS(0),
+	m_iWindowHeightBeforeFS(0),
+	m_iWindowWidthBeforeFS(0),
 	m_mouseWheelMessage(0),
 	m_iSizeWidth(0),
 	m_iSizeHeight(0)
@@ -164,10 +174,10 @@ bool XAP_Win32FrameImpl::_updateTitle(void)
 		return false;
 	}
 
-	UT_String sTmp = pFrame->getTitle(INT_MAX);
+	UT_UTF8String sTmp = pFrame->getTitle();
 	sTmp += " - ";
 	sTmp += XAP_App::getApp()->getApplicationTitleForTitleBar();
-	UT_SetWindowText(m_hwndFrame, sTmp.c_str());
+	UT_SetWindowText(m_hwndFrame, sTmp.utf8_str());
 
 	return true;
 }
@@ -469,6 +479,27 @@ void XAP_Win32FrameImpl::_setFullScreen(bool isFullScreen)
 			// Assume we were at Normal (non-maximized) state
 			m_iWindowStateBeforeFS = SW_SHOWNORMAL;
 		}
+
+		// Save window dimensions, as well
+		RECT rc;
+
+		if(!GetWindowRect(hwndFrame, &rc))
+		{
+			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+			// try to pick some sane defaults that will work with any monitor
+			m_iWindowXBeforeFS = 0;
+			m_iWindowYBeforeFS = 0;
+			m_iWindowHeightBeforeFS = 400;
+			m_iWindowWidthBeforeFS = 400;
+		}
+		else
+		{
+			m_iWindowXBeforeFS = rc.left;
+			m_iWindowYBeforeFS = rc.top;
+			m_iWindowHeightBeforeFS = rc.bottom - rc.top;
+			m_iWindowWidthBeforeFS = rc.right - rc.left;
+		}
+		
 	}
 
 	// Add or remove title-bar and border
@@ -481,6 +512,32 @@ void XAP_Win32FrameImpl::_setFullScreen(bool isFullScreen)
 
 	ShowWindow(hwndFrame, isFullScreen ? SW_SHOWMAXIMIZED : m_iWindowStateBeforeFS);
 
+	// TODO: does the following code work well with multiple monitors?
+	if(isFullScreen)
+	{
+		int width = GetSystemMetrics(SM_CXSCREEN);
+		int height = GetSystemMetrics(SM_CYSCREEN);
+
+		if((height > 0) && (width > 0))
+		{
+			if(!SetWindowPos(hwndFrame, 0, 0, 0, width, height, 0))
+			{
+				UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+			}
+		}
+		else
+		{
+			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+		}
+	}
+	else
+	{
+		if(!SetWindowPos(hwndFrame, 0, m_iWindowXBeforeFS, m_iWindowYBeforeFS, m_iWindowWidthBeforeFS, m_iWindowHeightBeforeFS, 0))
+		{
+			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+		}
+	}
+
 	UpdateWindow(hwndFrame);
 }
 
@@ -499,7 +556,7 @@ void XAP_Win32FrameImpl::_nullUpdate (void) const
 	}
 }
 
-void XAP_Win32FrameImpl::_setCursor(GR_Graphics::Cursor cursor)
+void XAP_Win32FrameImpl::_setCursor(GR_Graphics::Cursor /*cursor*/)
 {
 	FV_View* pView = (FV_View *) getFrame()->getCurrentView();
 
@@ -934,7 +991,9 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 		{
 			SendMessage(fimpl->m_hwndRebar,WM_SYSCOLORCHANGE,0,0);
 
-			REBARBANDINFO rbbi = { 0 };
+			REBARBANDINFO rbbi;
+			memset(&rbbi, 0, sizeof(rbbi));
+
 			rbbi.cbSize = sizeof(REBARBANDINFO);
 			rbbi.fMask = RBBIM_COLORS;
 			rbbi.clrFore = GetSysColor(COLOR_BTNTEXT);
@@ -967,7 +1026,7 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 					DragQueryFile(hDrop, i, szFileName, PATH_MAX);
 					XAP_App * pApp = XAP_App::getApp();
 					UT_return_val_if_fail(pApp, 0);
-					FV_View* pView = (FV_View *) f->getCurrentView();
+					FV_View* pCurrentView = (FV_View *) f->getCurrentView();
 					XAP_Frame * pNewFrame = 0;
 					IEGraphicFileType iegft = IEGFT_Unknown;					
 					IE_ImpGraphic *pIEG;
@@ -991,7 +1050,7 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 						DELETEP(pIEG);
 						if(errorCode == UT_OK && pFG)
 						{
-						  errorCode = pView->cmdInsertGraphic(pFG);
+						  errorCode = pCurrentView->cmdInsertGraphic(pFG);
 						  DELETEP(pFG);
 						}
 					  }
