@@ -22,7 +22,6 @@
 
 #include <stdlib.h>
 #include <cstring>
-
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
 #include "ut_string.h"
@@ -99,6 +98,8 @@ AD_Document::AD_Document() :
 	m_pMyUUID->setUUID(s);
 	UT_UTF8String OrigS;
 	m_pOrigUUID->toString(OrigS);
+	m_pOrigUUID->toString(m_sOrigUUIDString);
+	m_pMyUUID->toString(m_sMyUUIDString);
 	UT_DEBUGMSG(("!!!!!!!!!!----------------- Created string %s \n",s.utf8_str()));
 	UT_DEBUGMSG(("!!!!!!!!!!----------------- Orig string %s \n",OrigS.utf8_str()));
 }
@@ -120,12 +121,19 @@ AD_Document::~AD_Document()
 	if (m_szFilename)
 		g_free(const_cast<void *>(static_cast<const void *>(m_szFilename)));
 
-	if(m_pUUID)
-		delete m_pUUID;
-	if(m_pOrigUUID)
-		delete m_pOrigUUID;
-	if(m_pMyUUID)
-		delete m_pMyUUID;
+	DELETEP(m_pUUID);
+	DELETEP(m_pOrigUUID);
+	DELETEP(m_pMyUUID);
+}
+
+const std::string & AD_Document::getPrintFilename(void) const
+{
+	return m_sPrintFilename;
+}
+
+void AD_Document::setPrintFilename(const std::string & sFilename)
+{
+	m_sPrintFilename = sFilename;
 }
 
 bool AD_Document::isOrigUUID(void) const
@@ -140,7 +148,7 @@ bool AD_Document::isOrigUUID(void) const
   return b;
 }
 
-bool AD_Document::isPieceTableChanging(void)
+bool AD_Document::isPieceTableChanging(void) const
 {
         return m_bPieceTableChanging;
 }
@@ -261,7 +269,7 @@ void AD_Document::addRecordToHistory(const AD_VersionData &vd)
 /*!
     Get the version number for n-th record in version history
 */
-UT_uint32 AD_Document::getHistoryNthId(UT_uint32 i)const
+UT_uint32 AD_Document::getHistoryNthId(UT_sint32 i)const
 {
 	if(!m_vHistory.getItemCount())
 		return 0;
@@ -274,7 +282,7 @@ UT_uint32 AD_Document::getHistoryNthId(UT_uint32 i)const
 	return v->getId();
 }
 
-UT_uint32 AD_Document::getHistoryNthTopXID(UT_uint32 i)const
+UT_uint32 AD_Document::getHistoryNthTopXID(UT_sint32 i)const
 {
 	if(!m_vHistory.getItemCount())
 		return 0;
@@ -291,7 +299,7 @@ UT_uint32 AD_Document::getHistoryNthTopXID(UT_uint32 i)const
     Get time stamp for n-th record in version history
     NB: the time stamp represents the last save time
 */
-time_t AD_Document::getHistoryNthTime(UT_uint32 i)const
+time_t AD_Document::getHistoryNthTime(UT_sint32 i)const
 {
 	if(!m_vHistory.getItemCount())
 		return 0;
@@ -304,7 +312,7 @@ time_t AD_Document::getHistoryNthTime(UT_uint32 i)const
 	return v->getTime();
 }
 
-time_t AD_Document::getHistoryNthTimeStarted(UT_uint32 i)const
+time_t AD_Document::getHistoryNthTimeStarted(UT_sint32 i)const
 {
 	if(!m_vHistory.getItemCount())
 		return 0;
@@ -317,7 +325,7 @@ time_t AD_Document::getHistoryNthTimeStarted(UT_uint32 i)const
 	return v->getStartTime();
 }
 
-bool AD_Document::getHistoryNthAutoRevisioned(UT_uint32 i)const
+bool AD_Document::getHistoryNthAutoRevisioned(UT_sint32 i)const
 {
 	if(!m_vHistory.getItemCount())
 		return 0;
@@ -334,7 +342,7 @@ bool AD_Document::getHistoryNthAutoRevisioned(UT_uint32 i)const
 /*!
     Get get cumulative edit time for n-th record in version history
 */
-UT_uint32 AD_Document::getHistoryNthEditTime(UT_uint32 i)const
+time_t AD_Document::getHistoryNthEditTime(UT_sint32 i)const
 {
 	if(!m_vHistory.getItemCount() || !m_pUUID)
 		return 0;
@@ -354,7 +362,7 @@ UT_uint32 AD_Document::getHistoryNthEditTime(UT_uint32 i)const
 /*!
     Get the UID for n-th record in version history
 */
-const UT_UUID & AD_Document::getHistoryNthUID(UT_uint32 i) const
+const UT_UUID & AD_Document::getHistoryNthUID(UT_sint32 i) const
 {
 	if(!m_vHistory.getItemCount())
 		return UT_UUID::getNull();
@@ -435,7 +443,7 @@ AD_HISTORY_STATE AD_Document::verifyHistoryState(UT_uint32 &iVersion) const
 	AD_HISTORY_STATE eRet = ADHIST_FULL_RESTORE; // be optimistic
 
 	const AD_VersionData * v = NULL;
-	UT_uint32 i;
+	UT_sint32 i;
 	bool bFullRestore = false;
 	bool bFound = false;
 	
@@ -515,7 +523,7 @@ AD_HISTORY_STATE AD_Document::verifyHistoryState(UT_uint32 &iVersion) const
 
 const AD_VersionData * AD_Document::findHistoryRecord(UT_uint32 iVersion) const
 {
-	for(UT_uint32 i = 0; i < getHistoryCount(); ++i)
+	for(UT_sint32 i = 0; i < getHistoryCount(); ++i)
 	{
 		const AD_VersionData * v = (const AD_VersionData*)m_vHistory.getNthItem(i);
 
@@ -565,6 +573,7 @@ void AD_Document::setOrigUUID(const char * s)
 		if(!m_pOrigUUID->isValid())
 			m_pOrigUUID->makeUUID();
 	}
+	m_pOrigUUID->toString(m_sOrigUUIDString);
 }
 
 
@@ -586,6 +595,7 @@ void AD_Document::setMyUUID(const char * s)
 		if(!m_pMyUUID->isValid())
 			m_pMyUUID->makeUUID();
 	}
+	m_pMyUUID->toString(m_sMyUUIDString);
 }
 
 /*!
@@ -608,9 +618,7 @@ const char * AD_Document::getDocUUIDString() const
 const char * AD_Document::getOrigDocUUIDString() const
 {
 	UT_return_val_if_fail(m_pOrigUUID, NULL);
-	static UT_UTF8String s;
-	m_pOrigUUID->toString(s);
-	return s.utf8_str();
+	return m_sOrigUUIDString.utf8_str();
 }
 
 
@@ -624,9 +632,7 @@ const char * AD_Document::getOrigDocUUIDString() const
 UT_UTF8String AD_Document::getMyUUIDString() const
 {
 	UT_return_val_if_fail(m_pMyUUID, "");
-	UT_UTF8String s;
-	m_pMyUUID->toString(s);
-	return s;
+	return m_sMyUUIDString;
 }
 
 ///////////////////////////////////////////////////////////////////
@@ -639,7 +645,7 @@ UT_UTF8String AD_Document::getMyUUIDString() const
 */
 UT_sint32 AD_Document::getRevisionIndxFromId(UT_uint32 iId) const
 {
-	for(UT_uint32 i = 0; i < m_vRevisions.getItemCount(); i++)
+	for(UT_sint32 i = 0; i < m_vRevisions.getItemCount(); i++)
 	{
 		if(m_vRevisions.getNthItem(i)->getId() == iId)
 			return i;
@@ -653,7 +659,7 @@ UT_uint32 AD_Document::getHighestRevisionId() const
 {
 	UT_uint32 iId = 0;
 
-	for(UT_uint32 i = 0; i < m_vRevisions.getItemCount(); i++)
+	for(UT_sint32 i = 0; i < m_vRevisions.getItemCount(); i++)
 	{
 		iId = UT_MAX(iId, m_vRevisions.getNthItem(i)->getId());
 	}
@@ -666,7 +672,7 @@ const AD_Revision * AD_Document::getHighestRevision() const
 	UT_uint32 iId = 0;
 	const AD_Revision * r = NULL;
 
-	for(UT_uint32 i = 0; i < m_vRevisions.getItemCount(); i++)
+	for(UT_sint32 i = 0; i < m_vRevisions.getItemCount(); i++)
 	{
 		const AD_Revision * t = m_vRevisions.getNthItem(i);
 		UT_uint32 t_id = t->getId();
@@ -681,9 +687,9 @@ const AD_Revision * AD_Document::getHighestRevision() const
 	return r;
 }
 
-bool AD_Document::addRevision(UT_uint32 iId, UT_UCS4Char * pDesc, time_t tStart, UT_uint32 iVer)
+bool AD_Document::addRevision(UT_uint32 iId, UT_UCS4Char * pDesc, time_t tStart, UT_uint32 iVer, bool bGenCR)
 {
-	for(UT_uint32 i = 0; i < m_vRevisions.getItemCount(); i++)
+	for(UT_sint32 i = 0; i < m_vRevisions.getItemCount(); i++)
 	{
 		const AD_Revision * r = m_vRevisions.getNthItem(i);
 		if(r->getId() == iId)
@@ -691,18 +697,16 @@ bool AD_Document::addRevision(UT_uint32 iId, UT_UCS4Char * pDesc, time_t tStart,
 	}
 
 	AD_Revision * pRev = new AD_Revision(iId, pDesc, tStart, iVer);
-
-	m_vRevisions.addItem(pRev);
-	forceDirty();
+	addRevision(pRev, bGenCR);
 	m_iRevisionID = iId;
 	return true;
 }
 
 bool AD_Document::addRevision(UT_uint32 iId,
 							  const UT_UCS4Char * pDesc, UT_uint32 iLen,
-							  time_t tStart, UT_uint32 iVer)
+							  time_t tStart, UT_uint32 iVer,bool bGenCR)
 {
-	for(UT_uint32 i = 0; i < m_vRevisions.getItemCount(); i++)
+	for(UT_sint32 i = 0; i < m_vRevisions.getItemCount(); i++)
 	{
 		const AD_Revision * r = m_vRevisions.getNthItem(i);
 		if(r->getId() == iId)
@@ -719,13 +723,36 @@ bool AD_Document::addRevision(UT_uint32 iId,
 	}
 	
 	AD_Revision * pRev = new AD_Revision(iId, pD, tStart, iVer);
-
-	m_vRevisions.addItem(pRev);
-	forceDirty();
+	addRevision(pRev,bGenCR);
 	m_iRevisionID = iId;
 	return true;
 }
 
+bool AD_Document::addRevision(AD_Revision * pRev, bool bGenCR)
+{
+	m_vRevisions.addItem(pRev);
+	if(bGenCR)
+	{
+		const gchar * szAtts[11]={"docprop","revision",
+							 "revision",NULL,
+							 "revision-desc",NULL,
+							 "revision-time",NULL,
+							 "revision-ver",NULL,NULL};
+		UT_UTF8String sID,sTime,sVer;
+		UT_UTF8String_sprintf(sID,"%d",pRev->getId());
+		UT_UTF8String_sprintf(sTime,"%d",pRev->getStartTime());
+		UT_UTF8String_sprintf(sVer,"%d",pRev->getVersion());
+		UT_UTF8String sDesc(pRev->getDescription());
+		szAtts[3]= sID.utf8_str();
+		szAtts[5] = sDesc.utf8_str();
+		szAtts[7] = sTime.utf8_str();
+		szAtts[9] = sVer.utf8_str();
+		createAndSendDocPropCR(szAtts,NULL);
+	}
+	forceDirty();
+	return true;
+}
+
 void AD_Document::_purgeRevisionTable()
 {
 	UT_VECTOR_PURGEALL(AD_Revision*, m_vRevisions);
@@ -872,7 +899,7 @@ void AD_Document::setAutoRevisioning(bool b)
 */
 UT_uint32 AD_Document::findAutoRevisionId(UT_uint32 iVersion) const
 {
-	for(UT_uint32 i = 0; i < m_vRevisions.getItemCount(); i++)
+	for(UT_sint32 i = 0; i < m_vRevisions.getItemCount(); i++)
 	{
 		const AD_Revision *pRev= m_vRevisions.getNthItem(i);
 		UT_return_val_if_fail(pRev, 0);
@@ -898,7 +925,7 @@ UT_uint32 AD_Document::findNearestAutoRevisionId(UT_uint32 iVersion, bool bLesse
 {
 	UT_uint32 iId = 0;
 	
-	for(UT_uint32 i = 0; i < m_vRevisions.getItemCount(); i++)
+	for(UT_sint32 i = 0; i < m_vRevisions.getItemCount(); i++)
 	{
 		const AD_Revision *pRev= m_vRevisions.getNthItem(i);
 		UT_return_val_if_fail(pRev, 0);
@@ -1056,7 +1083,7 @@ bool AD_Document::_restoreVersion(XAP_Frame * pFrame, UT_uint32 iVersion)
 		// history record
 		UT_sint32 iCount = getHistoryCount();
 		const AD_VersionData * pVLast = NULL;
-		UT_uint32 iEditTime = 0;
+		time_t iEditTime = 0;
 		
 		for(UT_sint32 j = 0; j < iCount; ++j)
 		{
@@ -1372,8 +1399,7 @@ bool AD_VersionData::operator == (const AD_VersionData &v)
 
 AD_VersionData::~AD_VersionData()
 {
-	if(m_pUUID)
-		delete m_pUUID;
+	DELETEP(m_pUUID);
 }
 
 time_t AD_VersionData::getTime()const
