@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <string.h>
 #include <time.h>
 
 #include <glib.h>
@@ -39,7 +40,6 @@
 #include "ev_Toolbar_Actions.h"
 #include "xap_App.h"
 #include "xap_AppImpl.h"
-#include "xap_Args.h"
 #include "xap_InputModes.h"
 #include "gr_Image.h"
 #include "xap_Frame.h"
@@ -66,13 +66,22 @@
 
 /*****************************************************************/
 
+XAP_StateData::XAP_StateData()
+	: iFileCount(0)
+{
+	memset(&filenames, 0, sizeof(filenames));
+	memset(&iDocPos, 0, sizeof(iDocPos));
+	memset(&iXScroll, 0, sizeof(iXScroll));
+	memset(&iYScroll, 0, sizeof(iYScroll));
+}
+
+
 XAP_App * XAP_App::m_pApp = NULL;
 
 XAP_App * XAP_App::getApp() {return m_pApp;}
 
-XAP_App::XAP_App(XAP_Args * pArgs, const char * szAppName)
-	: m_pArgs(pArgs),
-	  m_szAppName(szAppName),
+XAP_App::XAP_App(const char * szAppName)
+	: m_szAppName(szAppName),
 	  m_szAbiSuiteLibDir(NULL),
 	  m_pEMC(NULL),
 	  m_pBindingSet(NULL),
@@ -217,7 +226,7 @@ XAP_Module * XAP_App::getPlugin(const char * szPluginName)
      XAP_Module * pModule = NULL;
      const UT_GenericVector<XAP_Module*> * pVec = XAP_ModuleManager::instance().enumModules ();
      bool bFound = false;
-     for (UT_uint32 i = 0; (i < pVec->size()) && !bFound; i++)
+     for (UT_sint32 i = 0; (i < pVec->size()) && !bFound; i++)
      {
           pModule = pVec->getNthItem (i);
 	  const char * szName = pModule->getModuleInfo()->name;
@@ -236,14 +245,14 @@ XAP_Module * XAP_App::getPlugin(const char * szPluginName)
 /*!
  * Register an embeddable plugin with XAP_App
  */
-UT_uint32 XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed)
+UT_sint32 XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed)
 {
-	 UT_return_val_if_fail( pEmbed, 0xFFFFFFF );
+	 UT_return_val_if_fail( pEmbed, -1 );
 	 
      UT_sint32 i=0;
      bool bFound = false;
      GR_EmbedManager * pCur = NULL;
-     for(i=0; !bFound && (i< static_cast<UT_sint32>(m_vecEmbedManagers.getItemCount())); i++)
+     for(i=0; !bFound && (i< m_vecEmbedManagers.getItemCount()); i++)
      {
 		 pCur =  m_vecEmbedManagers.getNthItem(i);
 		 if(pCur && (strcmp(pCur->getObjectType(),pEmbed->getObjectType()) == 0))
@@ -256,7 +265,7 @@ UT_uint32 XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed)
 		 m_vecEmbedManagers.addItem(pEmbed);
 		 return  m_vecEmbedManagers.getItemCount() - 1;
      }
-     return 0xFFFFFFF;
+     return -1;
 }
 
 
@@ -264,7 +273,7 @@ UT_uint32 XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed)
  * UnRegister an embeddable plugin with XAP_App. The plugin itself is 
  * responsible for actually deleting the object.
  */
-bool XAP_App::unRegisterEmbeddable(UT_uint32 uid)
+bool XAP_App::unRegisterEmbeddable(UT_sint32 uid)
 {
   if(uid < m_vecEmbedManagers.getItemCount())
     {
@@ -283,7 +292,7 @@ GR_EmbedManager * XAP_App:: getEmbeddableManager(GR_Graphics * pG, const char *
      UT_sint32 i=0;
      bool bFound = false;
      GR_EmbedManager * pCur = NULL;
-     for(i=0; !bFound && (i< static_cast<UT_sint32>(m_vecEmbedManagers.getItemCount())); i++)
+     for(i=0; !bFound && (i< m_vecEmbedManagers.getItemCount()); i++)
      {
        pCur =  m_vecEmbedManagers.getNthItem(i);
        UT_DEBUGMSG(("Look at Manager for Object type %s requested %s strcmp %d strcmp %d \n",pCur->getObjectType(),szObjectType,strcmp(pCur->getObjectType(),szObjectType),strcmp(pCur->getObjectType(),szObjectType) ));
@@ -322,23 +331,6 @@ bool XAP_App::initialize(const char * szKeyBindingsKey, const char * szKeyBindin
 	m_pDict->load();
 	clearIdTable();
 //
-// Reload toolbar configuration from prefs
-//
-	bool bAllowCustom = true;
-	getPrefsValueBool(XAP_PREF_KEY_AllowCustomToolbars, &bAllowCustom);
-	if(bAllowCustom)
-		setToolbarsCustomizable(true);
-	else
-	{
-		setToolbarsCustomizable(false);
-		setToolbarsCustomized(false);
-	}
-	m_pToolbarFactory->restoreToolbarsFromCurrentScheme();
-	if(!bAllowCustom)
-	{
-		m_pToolbarFactory->resetAllToolbarsToDefault();
-	}
-//
 // Set Smooth Scrolling
 //
 	bool bEnableSmooth = true;
@@ -348,8 +340,6 @@ bool XAP_App::initialize(const char * szKeyBindingsKey, const char * szKeyBindin
 	else
 		setEnableSmoothScrolling(false);
 
-	// TODO use m_pArgs->{argc,argv} to process any command-line
-	// TODO options that we need.
 	//
 	// Need to initialize the random number generator. 
 	//
@@ -418,11 +408,11 @@ bool XAP_App::initialize(const char * szKeyBindingsKey, const char * szKeyBindin
 bool XAP_App::addListener(AV_Listener * pListener, 
 							 AV_ListenerId * pListenerId)
 {
-	UT_uint32 kLimit = m_vecPluginListeners.getItemCount();
-	UT_uint32 k;
+	UT_sint32 kLimit = m_vecPluginListeners.getItemCount();
+	UT_sint32 k;
 
 	// see if we can recycle a cell in the vector.
-	UT_DEBUGMSG(("Asked to register pListener %x \n",pListener));
+	UT_DEBUGMSG(("Asked to register pListener %p \n",pListener));
 	
 	for (k=0; k<kLimit; k++)
 		if (m_vecPluginListeners.getNthItem(k) == 0)
@@ -522,53 +512,11 @@ bool XAP_App::notifyListeners(AV_View * pView, const AV_ChangeMask hint, void *
 }
 
 
-void XAP_App::resetToolbarsToDefault(void)
-{
-	//
-	// Set all the frames to default toolbars
-	//
-	m_pToolbarFactory->resetAllToolbarsToDefault();
-	UT_uint32 count = m_vecFrames.getItemCount();
-	UT_GenericVector<XAP_Frame*> vClones;
-	UT_uint32 i = 0;
-	for(i=0; i< count; i++)
-	{
-		XAP_Frame * pFrame = m_vecFrames.getNthItem(i);
-		if(pFrame->getViewNumber() > 0)
-		{
-			getClones(&vClones,pFrame);
-			UT_uint32 j=0;
-			for(j=0; j < vClones.getItemCount(); j++)
-			{
-				XAP_Frame * f = vClones.getNthItem(j);
-				f->rebuildAllToolbars();
-			}
-		}
-		else
-		{
-			pFrame->rebuildAllToolbars();
-		}
-	}
-	setToolbarsCustomized (true);
-}
-
 void XAP_App::setEnableSmoothScrolling(bool b)
 {
 	m_bEnableSmoothScrolling = b;
 }
 
-void XAP_App::setToolbarsCustomizable(bool b)
-{
-	if(m_bAllowCustomizing != b)
-		m_bAllowCustomizing = b;
-}
-
-void XAP_App::setToolbarsCustomized(bool b)
-{
-	if(m_bAreCustomized != b)
-		m_bAreCustomized = b;
-}
-
 const char * XAP_App::getApplicationTitleForTitleBar() const
 {
 	static char _title[512];
@@ -671,7 +619,7 @@ bool XAP_App::rememberFrame(XAP_Frame * pFrame, XAP_Frame * pCloneOf)
 		pvClones->addItem(pFrame);
 
 		// notify all clones of their new view numbers
-		for (UT_uint32 j=0; j<pvClones->getItemCount(); j++)
+		for (UT_sint32 j=0; j<pvClones->getItemCount(); j++)
 		{
 			XAP_Frame * f = pvClones->getNthItem(j);
 			UT_continue_if_fail(f);
@@ -783,7 +731,7 @@ bool XAP_App::forgetClones(XAP_Frame * pFrame)
 	UT_GenericVector<XAP_Frame*> vClones;
 	getClones(&vClones, pFrame);
 	
-	for (UT_uint32 i = 0; i < vClones.getItemCount(); i++)
+	for (UT_sint32 i = 0; i < vClones.getItemCount(); i++)
 	{
 		XAP_Frame * f = static_cast<XAP_Frame *>(vClones.getNthItem(i));
 		forgetFrame(f);
@@ -841,12 +789,12 @@ void XAP_App::notifyFrameCountChange() // default is empty method
 	UT_DEBUGMSG(("XAP_App::notifyFrameCountChange(): count=%lu\n", static_cast<unsigned long>(getFrameCount())));
 }
 
-UT_uint32 XAP_App::getFrameCount() const
+UT_sint32 XAP_App::getFrameCount() const
 {
 	return m_vecFrames.getItemCount();
 }
 
-XAP_Frame * XAP_App::getFrame(UT_uint32 ndx) const
+XAP_Frame * XAP_App::getFrame(UT_sint32 ndx) const
 {
 	XAP_Frame * pFrame = NULL;
 	
@@ -868,7 +816,7 @@ UT_sint32 XAP_App::findFrame(const char * szFilename)
 	if (!szFilename || !*szFilename)
 		return -1;
 
-	for (UT_uint32 i=0; i<getFrameCount(); i++)
+	for (UT_sint32 i=0; i<getFrameCount(); i++)
 	{
 		XAP_Frame * f = getFrame(i);
 		UT_continue_if_fail(f);
@@ -876,7 +824,7 @@ UT_sint32 XAP_App::findFrame(const char * szFilename)
 
 		if (s && *s && (0 == g_ascii_strcasecmp(szFilename, s)))
 		{
-			return static_cast<UT_sint32>(i);
+			return i;
 		}
 	}
 
@@ -901,11 +849,6 @@ bool XAP_App::findAbiSuiteLibFile(UT_String & path, const char * filename, const
 		return false;
 	}
 
-#if defined(WIN32)
-	const char * sep = "\\";
-#else
-	const char * sep = "/";
-#endif
 	bool bFound = false;
 
 	const char * dir = getUserPrivateDirectory();
@@ -914,10 +857,10 @@ bool XAP_App::findAbiSuiteLibFile(UT_String & path, const char * filename, const
 		path = dir;
 		if (subdir)
 		{
-			path += sep;
+			path += G_DIR_SEPARATOR;
 			path += subdir;
 		}
-		path += sep;
+		path += G_DIR_SEPARATOR;
 		path += filename;
 		bFound = UT_isRegularFile (path.c_str ());
 	}
@@ -926,10 +869,10 @@ bool XAP_App::findAbiSuiteLibFile(UT_String & path, const char * filename, const
 		path = dir;
 		if (subdir)
 		{
-			path += sep;
+			path += G_DIR_SEPARATOR;
 			path += subdir;
 		}
-		path += sep;
+		path += G_DIR_SEPARATOR;
 		path += filename;
 		bFound = UT_isRegularFile (path.c_str ());
 	}
@@ -943,11 +886,6 @@ bool XAP_App::findAbiSuiteAppFile(UT_String & path, const char * filename, const
 		return false;
 	}
 
-#if defined(WIN32)
-	const char * sep = "\\";
-#else
-	const char * sep = "/";
-#endif
 	bool bFound = false;
 
 	const char * dir = getAbiSuiteAppDir();
@@ -956,10 +894,10 @@ bool XAP_App::findAbiSuiteAppFile(UT_String & path, const char * filename, const
 		path = dir;
 		if (subdir)
 		{
-			path += sep;
+			path += G_DIR_SEPARATOR;
 			path += subdir;
 		}
-		path += sep;
+		path += G_DIR_SEPARATOR;
 		path += filename;
 		bFound = UT_isRegularFile (path.c_str ());
 	}
@@ -1083,9 +1021,12 @@ void XAP_App::rememberModelessId(UT_sint32 id, XAP_Dialog_Modeless * pDialog)
 	// find a free slot in the m_IdTable
  
 	UT_sint32 i;
-	for(i=0; (i<= NUM_MODELESSID) && (m_IdTable[i].id !=  -1); i++);
+	for(i=0; (i<= NUM_MODELESSID) && (m_IdTable[i].id !=  -1); i++) {
+
+	}
 	UT_ASSERT( i <= NUM_MODELESSID );
-	UT_ASSERT( m_IdTable[i].id == -1 );
+// This assert cause a warning because array subscript is out of bounds.
+//	UT_ASSERT( m_IdTable[i].id == -1 );
 	UT_ASSERT( pDialog);
 	m_IdTable[i].id =  id;
 	m_IdTable[i].pDialog =  pDialog;
@@ -1096,7 +1037,9 @@ void XAP_App::forgetModelessId( UT_sint32 id )
 	// remove the id, pDialog pair from the m_IdTable
 
 	UT_sint32 i;
-	for(i=0; i <= NUM_MODELESSID && m_IdTable[i].id != id; i++) ;
+	for(i=0; i <= NUM_MODELESSID && m_IdTable[i].id != id; i++) {
+
+	} 
 	if(i >  NUM_MODELESSID)
 	{
 //
@@ -1113,7 +1056,9 @@ bool XAP_App::isModelessRunning(UT_sint32 id)
 	// returns true if the modeless dialog given by id is running
 	
 	UT_sint32 i;
-	for(i=0; i <= NUM_MODELESSID && m_IdTable[i].id != id; i++) ;
+	for(i=0; i <= NUM_MODELESSID && m_IdTable[i].id != id; i++) {
+
+	}
 	if( i> NUM_MODELESSID)
 	{
 		return false;
@@ -1275,7 +1220,7 @@ void XAP_App::setKbdLanguage(const char * pszLang)
 
 void XAP_App::enumerateFrames(UT_Vector & v)
 {
-	for(UT_uint32 i = 0; i < getFrameCount(); ++i)
+	for(UT_sint32 i = 0; i < getFrameCount(); ++i)
 	{
 		XAP_Frame * pF = getFrame(i);
 		if(pF)
@@ -1303,7 +1248,7 @@ void XAP_App::enumerateDocuments(UT_Vector & v, const AD_Document * pExclude)
 {
 	UT_sint32 iIndx;
 
-	for(UT_uint32 i = 0; i < getFrameCount(); ++i)
+	for(UT_sint32 i = 0; i < getFrameCount(); ++i)
 	{
 		XAP_Frame * pF = getFrame(i);
 
@@ -1332,7 +1277,7 @@ EV_EditEventMapper * XAP_App::getEditEventMapper(void) const
 
 UT_sint32 XAP_App::setInputMode(const char * szName, bool bForce)
 {
-	UT_uint32 i;
+	UT_sint32 i;
 	
 	UT_DEBUGMSG(("XAP_App::setInputMode: %s %d\n", szName, bForce));
 	
@@ -1459,7 +1404,7 @@ const char* XAP_App::findNearestFont(const char* pszFontFamily,
 bool XAP_App::saveState(bool bQuit)
 {
 	// gather the state data for platform code to deal with
-	XAP_StateData sd = {0};
+	XAP_StateData sd;
 
 	bool bRet = true;
 
@@ -1468,7 +1413,7 @@ bool XAP_App::saveState(bool bQuit)
 
 	XAP_Frame * pLastFrame = getLastFocussedFrame();
 
-	UT_uint32 i;
+	UT_sint32 i;
 	UT_sint32 j;
 	
 	for(i = 0, j = 0; i < m_vecFrames.getItemCount(); ++i, ++j)
@@ -1576,7 +1521,7 @@ bool XAP_App::saveState(bool bQuit)
 
     returns true on success
 */
-bool XAP_App::_saveState(XAP_StateData & sd)
+bool XAP_App::_saveState(XAP_StateData & )
 {
 	return false;
 }
@@ -1590,7 +1535,7 @@ bool XAP_App::_saveState(XAP_StateData & sd)
 
 bool XAP_App::retrieveState()
 {
-	XAP_StateData sd = {0};
+	XAP_StateData sd;
 
 	bool bRet = true;
 	
@@ -1698,7 +1643,7 @@ bool XAP_App::retrieveState()
 
     returns true on success
 */
-bool XAP_App::_retrieveState(XAP_StateData & sd)
+bool XAP_App::_retrieveState(XAP_StateData & )
 {
 	return false;
 }
