@@ -190,7 +190,7 @@ int XAP_Frame::_getNextUntitledNumber(void)
 
 /*****************************************************************/
 
-bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBindingsDefaultValue,
+bool XAP_Frame::initialize(const char * /*szKeyBindingsKey*/, const char * /*szKeyBindingsDefaultValue*/,
 						   const char * szMenuLayoutKey, const char * szMenuLayoutDefaultValue,
 						   const char * szMenuLabelSetKey, const char * szMenuLabelSetDefaultValue,
 						   const char * szToolbarLayoutsKey, const char * szToolbarLayoutsDefaultValue,
@@ -391,10 +391,12 @@ static void autoSaveCallback(UT_Worker *wkr)
 	{
 		UT_Error error = me->backup();
 
-		if (!error)
+		if (!error) {
 			xxx_UT_DEBUGMSG(("Document Auto saved\n"));
-		else
+		}
+		else {
 			xxx_UT_DEBUGMSG(("Error [%d] saving document.\n", error));
+		}
 	}
 	else
 	{
@@ -427,7 +429,7 @@ void XAP_Frame::_createAutoSaveTimer()
 void XAP_Frame::_removeAutoSaveFile()
 {
 	const char *filename = NULL;
-	bool bURI = UT_go_path_is_uri(m_stAutoSaveNamePrevious.c_str());
+	gboolean bURI = UT_go_path_is_uri(m_stAutoSaveNamePrevious.c_str());
 
 	if(bURI)
 	{
@@ -604,23 +606,9 @@ const char * XAP_Frame::getViewKey(void) const
 	return buf;
 }
 
-const char * XAP_Frame::getTitle(int len) const
+const UT_UTF8String & XAP_Frame::getTitle() const
 {
-	UT_ASSERT(len >= 0);
-
-	// Returns the pathname being edited (with view and dirty bit
-	// '*' adornments), if all that fits. If it doesn't fit,
-	// returns the tail of the string that does fit. Would be
-	// better to chop it at a pathname separator boundary.
-	if (static_cast<int>(m_sTitle.size()) <= len)
-		return m_sTitle.utf8_str();
-
-	// WL_FIXME: we probably need a string truncation function, in the ut_utf8string class..
-	UT_UTF8Stringbuf::UTF8Iterator iter = m_sTitle.getIterator ();
-	iter = iter.start ();
-	for (int currentSize = m_sTitle.size(); currentSize > len; currentSize--)
-		iter.advance();
-	return iter.current();
+	return m_sTitle;
 }
 
 const char * XAP_Frame::getNonDecoratedTitle() const
@@ -660,7 +648,7 @@ UT_uint32 XAP_Frame::getZoomPercentage(void)
 	return m_iZoomPercentage;
 }
 
-EV_Toolbar *  XAP_Frame::getToolbar(UT_uint32 ibar)
+EV_Toolbar *  XAP_Frame::getToolbar(UT_sint32 ibar)
 {
 	if(ibar >= m_pFrameImpl->m_vecToolbars.getItemCount())
 		return NULL;
@@ -687,8 +675,8 @@ bool XAP_Frame::repopulateCombos(void)
 void XAP_FrameImpl::_createToolbars(void)
 {
 	bool bResult;
-	UT_uint32 nrToolbars = m_vecToolbarLayoutNames.getItemCount();
-	for (UT_uint32 k=0; k < nrToolbars; k++)
+	UT_sint32 nrToolbars = m_vecToolbarLayoutNames.getItemCount();
+	for (UT_sint32 k=0; k < nrToolbars; k++)
 	{
 		EV_Toolbar * pToolbar = m_pFrame->_newToolbar(m_pFrame,
 							      reinterpret_cast<const char *>(m_vecToolbarLayoutNames.getNthItem(k)),
@@ -703,7 +691,7 @@ void XAP_FrameImpl::_createToolbars(void)
 
 UT_sint32 XAP_Frame::findToolbarNr(EV_Toolbar * pTB)
 {
-	UT_uint32 i = 0;
+	UT_sint32 i = 0;
 	bool bFound =  false;
 	for(i =0; !bFound && (i < m_pFrameImpl->m_vecToolbars.getItemCount()); i++)
 	{
@@ -843,6 +831,13 @@ XAP_Dialog_MessageBox::tAnswer XAP_Frame::showMessageBox(XAP_String_Id id,
   return showMessageBox(pDialog);
 }
 
+XAP_Dialog_MessageBox::tAnswer XAP_Frame::showMessageBox(const std::string & msg,
+							 XAP_Dialog_MessageBox::tButtons buttons,
+							 XAP_Dialog_MessageBox::tAnswer default_answer)
+{
+	return showMessageBox(msg.c_str(), buttons, default_answer);
+}
+
 XAP_Dialog_MessageBox::tAnswer XAP_Frame::showMessageBox(const char * szMessage,
 							 XAP_Dialog_MessageBox::tButtons buttons,
 							 XAP_Dialog_MessageBox::tAnswer default_answer)
@@ -859,21 +854,22 @@ UT_String XAP_Frame::makeBackupName(const char* szExt)
   UT_String backupName;
   UT_DEBUGMSG(("In make Backup name. Old Name is (%s) \n",oldName.c_str()));
   if (oldName.empty())
-    {
+  {
       const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
 	  UT_String sTmp;
 	  pSS->getValue(XAP_STRING_ID_UntitledDocument, XAP_App::getApp()->getDefaultEncoding(), sTmp);
 	  UT_String_sprintf(oldName, sTmp.c_str(), m_iUntitled);
 
       UT_DEBUGMSG(("Untitled.  We will give it the name [%s]\n", oldName.c_str()));
-    }
-  else
+  }
+  else {
     UT_DEBUGMSG(("Filename [%s]\n", oldName.c_str()));
+  }
   
   backupName = oldName + ext;
 
   const char* uri = NULL;
-  bool bURI = UT_go_path_is_uri(backupName.c_str());
+  gboolean bURI = UT_go_path_is_uri(backupName.c_str());
 
   if(!bURI)
     uri = UT_go_filename_to_uri(backupName.c_str());
@@ -1037,6 +1033,8 @@ void XAP_Frame::dragBegin(XAP_Toolbar_Id srcId, EV_Toolbar * pTBsrc)
  */
 void XAP_Frame::dragDropToIcon(XAP_Toolbar_Id srcId,XAP_Toolbar_Id destId, EV_Toolbar * pTBsrc, EV_Toolbar * pTBdest)
 {
+	UT_UNUSED(srcId);
+	UT_UNUSED(pTBsrc);
 	UT_ASSERT(m_isrcId == srcId);
 	UT_ASSERT(m_isrcTBNr == findToolbarNr(pTBsrc));
 	m_idestId = destId;
@@ -1050,81 +1048,15 @@ void XAP_Frame::dragDropToIcon(XAP_Toolbar_Id srcId,XAP_Toolbar_Id destId, EV_To
  */
 void XAP_Frame::dragDropToTB(XAP_Toolbar_Id srcId,EV_Toolbar * pTBsrc, EV_Toolbar * pTBdest)
 {
+	UT_UNUSED(srcId);
+	UT_UNUSED(pTBsrc);
 	UT_ASSERT(m_isrcId == srcId);
 	UT_ASSERT(m_isrcTBNr == findToolbarNr(pTBsrc));
 	m_idestTBNr = findToolbarNr(pTBdest);
 	m_bHasDroppedTB = true;
 }
 
-/*
- * Actually do the toolbar(s) rebuild from the info recorded.
- */
-void XAP_Frame::dragEnd(XAP_Toolbar_Id srcId)
-{
-	UT_ASSERT(m_isrcId == srcId);
-	if(!XAP_App::getApp()->areToolbarsCustomizable())
-	{
-		return;
-	}
-//
-// Drop to icon
-//
-	if(m_bisDragging && m_bHasDropped)
-	{
-		if(m_isrcId != m_idestId)
-		{
-			const char * szTBSrcName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr));
-			XAP_App::getApp()->getToolbarFactory()->removeIcon(szTBSrcName,m_isrcId);
-			const char * szTBDestName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_idestTBNr));
-			XAP_App::getApp()->getToolbarFactory()->addIconBefore(szTBDestName,m_isrcId,m_idestId);
-			m_pFrameImpl->_rebuildToolbar(m_isrcTBNr);
-			if(m_isrcTBNr != m_idestTBNr)
-			{
-				m_pFrameImpl->_rebuildToolbar(m_idestTBNr);
-			}
-			XAP_App::getApp()->setToolbarsCustomized(true);
-		}
-	}
-//
-// Drop to Toolbar
-//
-	if(m_bisDragging && m_bHasDroppedTB)
-	{
-		const char * szTBSrcName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr));
-		XAP_App::getApp()->getToolbarFactory()->removeIcon(szTBSrcName,m_isrcId);
-		const char * szTBDestName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_idestTBNr));
-		XAP_App::getApp()->getToolbarFactory()->addIconAtEnd(szTBDestName,m_isrcId);
-		m_pFrameImpl->_rebuildToolbar(m_isrcTBNr);
-		if(m_isrcTBNr != m_idestTBNr)
-		{
-			m_pFrameImpl->_rebuildToolbar(m_idestTBNr);
-		}
-	}
-//
-// Remove icon
-//
-	if(m_bisDragging && !m_bHasDroppedTB && !m_bHasDropped)
-	{
-//
-// Ask if icon should be removed.
-//
-		if(XAP_Dialog_MessageBox::a_YES == showMessageBox(XAP_STRING_ID_DLG_Remove_Icon,XAP_Dialog_MessageBox::b_YN,XAP_Dialog_MessageBox::a_NO))
-		{
-			const char * szTBSrcName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr));
-			XAP_App::getApp()->getToolbarFactory()->removeIcon(szTBSrcName,m_isrcId);
-			m_pFrameImpl->_rebuildToolbar(m_isrcTBNr);
-		}
-	}
-	m_isrcId = 0;
-	m_isrcTBNr = 0;
-	m_idestId = 0;
-	m_idestTBNr = 0;
-	m_bisDragging = true;
-	m_bHasDropped = false;
-	m_bHasDroppedTB = false;
-}
-
-UT_uint32 XAP_Frame::getTimeSinceSave() const
+time_t XAP_Frame::getTimeSinceSave() const
 {
 	return m_pDoc->getTimeSinceSave();
 }
