@@ -77,13 +77,13 @@ TOCEntry::TOCEntry(fl_BlockLayout * pBlock,
 	m_bInherit(bInherit),
 	m_iStartAt(iStartAt)
 {
-	UT_DEBUGMSG(("created entry %x \n",this));
+	UT_DEBUGMSG(("created entry %p \n",this));
 }
 
 TOCEntry::~TOCEntry(void)
 {
 	m_iLevel = -1;
-	UT_DEBUGMSG(("Deleteing entry %x \n",this));
+	UT_DEBUGMSG(("Deleteing entry %p \n",this));
 }
 
 PT_DocPosition TOCEntry::getPositionInDoc(void)
@@ -152,7 +152,7 @@ fl_TOCLayout::fl_TOCLayout(FL_DocLayout* pLayout, fl_DocSectionLayout* pDocSL, P
 fl_TOCLayout::~fl_TOCLayout()
 {
 	// NB: be careful about the order of these
-	UT_DEBUGMSG(("Deleting TOClayout %x \n",this));
+	UT_DEBUGMSG(("Deleting TOClayout %p \n",this));
 	_purgeLayout();
 	fp_TOCContainer * pTC = static_cast<fp_TOCContainer *>(getFirstContainer());
 	while(pTC)
@@ -282,7 +282,7 @@ void fl_TOCLayout::setTOCEndIn(void)
 /*!
  * This signals an incomplete footnote section.
  */
-bool fl_TOCLayout::doclistener_deleteEndTOC( const PX_ChangeRecord_Strux * pcrx)
+bool fl_TOCLayout::doclistener_deleteEndTOC( const PX_ChangeRecord_Strux * /*pcrx*/)
 {
 	m_bHasEndTOC = false;
 	return true;
@@ -348,7 +348,7 @@ eTabLeader fl_TOCLayout::getTabLeader(UT_sint32 iLevel)
 	return static_cast<eTabLeader>(0);
 }
 
-UT_sint32 fl_TOCLayout::getTabPosition(UT_sint32 iLevel, fl_BlockLayout * pBlock)
+UT_sint32 fl_TOCLayout::getTabPosition(UT_sint32 iLevel, const fl_BlockLayout * pBlock)
 {
 	fp_TOCContainer * pTOCC = static_cast<fp_TOCContainer *>(getFirstContainer());
 	if(pTOCC == NULL)
@@ -684,7 +684,7 @@ void fl_TOCLayout::_createAndFillTOCEntry(PT_DocPosition posStart, PT_DocPositio
 			pNewBlock = static_cast<fl_BlockLayout *>(pNewBlock->getNext());
 		}
 	}
-	UT_DEBUGMSG(("New TOC block in TOCLayout %x \n",pNewBlock));
+	UT_DEBUGMSG(("New TOC block in TOCLayout %p \n",pNewBlock));
 
 	// OK Now add the block to our vector.
 	TOCEntry *pNewEntry = createNewEntry(pNewBlock);
@@ -692,7 +692,7 @@ void fl_TOCLayout::_createAndFillTOCEntry(PT_DocPosition posStart, PT_DocPositio
 	{
 		m_vecEntries.insertItemAt(pNewEntry,0);
 	}
-	else if (iAllBlocks < static_cast<UT_sint32>(m_vecEntries.getItemCount()))
+	else if (iAllBlocks < m_vecEntries.getItemCount())
 	{
 		m_vecEntries.insertItemAt(pNewEntry,iAllBlocks);
 	}
@@ -739,7 +739,7 @@ void fl_TOCLayout::_addBlockInVec(fl_BlockLayout * pBlock, UT_UTF8String & sStyl
 	UT_sint32 i = 0;
 	bool bFound = false;
 	
-	for(i=0; i< static_cast<UT_sint32>(m_vecEntries.getItemCount()); i++)
+	for(i=0; i< m_vecEntries.getItemCount(); i++)
 	{
 		pEntry = m_vecEntries.getNthItem(i);
 		pPrevBL = pEntry->getBlock();
@@ -840,7 +840,7 @@ UT_sint32 fl_TOCLayout::isInVector(fl_BlockLayout * pBlock,
 	TOCEntry * pThisEntry = NULL;
 	fl_BlockLayout * pThisBL = NULL;
 	UT_sint32 i = 0;
-	for(i=0; i< static_cast<UT_sint32>(pVecEntries->getItemCount()); i++)
+	for(i=0; i< pVecEntries->getItemCount(); i++)
 	{
 
 		pThisEntry = pVecEntries->getNthItem(i);
@@ -884,7 +884,7 @@ fl_BlockLayout * fl_TOCLayout::findMatchingBlock(fl_BlockLayout * pBlock)
 	fl_BlockLayout * pThisBL = NULL;
 	UT_sint32 i = 0;
 	bool bFound = false;
-	for(i=0; i< static_cast<UT_sint32>(m_vecEntries.getItemCount()); i++)
+	for(i=0; i< m_vecEntries.getItemCount(); i++)
 	{
 		pThisEntry = m_vecEntries.getNthItem(i);
 		pThisBL = pThisEntry->getBlock();
@@ -907,13 +907,13 @@ fl_BlockLayout * fl_TOCLayout::findMatchingBlock(fl_BlockLayout * pBlock)
     recursive call to ourselves. bDontRecurse indicates that the recursive processing should not be
     done; it has a default value false.
 */
-void fl_TOCLayout::_removeBlockInVec(fl_BlockLayout * pBlock, bool bDontRecurse)
+void fl_TOCLayout::_removeBlockInVec(fl_BlockLayout * pBlock, bool /*bDontRecurse*/)
 {
 	TOCEntry * pThisEntry = NULL;
 	fl_BlockLayout * pThisBL = NULL;
 	UT_sint32 i = 0;
 	bool bFound = false;
-	for(i=0; i< static_cast<UT_sint32>(m_vecEntries.getItemCount()); i++)
+	for(i=0; i< m_vecEntries.getItemCount(); i++)
 	{
 		pThisEntry = m_vecEntries.getNthItem(i);
 		pThisBL = pThisEntry->getBlock();
@@ -930,7 +930,7 @@ void fl_TOCLayout::_removeBlockInVec(fl_BlockLayout * pBlock, bool bDontRecurse)
 	//
 	// Clear it!
 	//
-	UT_DEBUGMSG(("Removing block %x Entry %x \n",pThisBL,pThisEntry));
+	UT_DEBUGMSG(("Removing block %p Entry %p \n",pThisBL,pThisEntry));
 	if(!pBlock->isContainedByTOC())
 	{
 		// we only clear if the block passed to us is not one of our TOC blocks (i.e., if we are not
@@ -1010,7 +1010,7 @@ void fl_TOCLayout::_calculateLabels(void)
 	TOCEntry * pPrevEntry = NULL;
 	UT_Stack stEntry;
 	stEntry.push(NULL);
-	UT_sint32 iCount = static_cast<UT_sint32>(m_vecEntries.getItemCount());
+	UT_sint32 iCount = m_vecEntries.getItemCount();
 	if(iCount == 0)
 	{
 		return;
@@ -1035,7 +1035,7 @@ void fl_TOCLayout::_calculateLabels(void)
 			UT_ASSERT(stEntry.getDepth() > 0);
 			stEntry.viewTop(&pTmp);
 			TOCEntry * pPrevLevel = static_cast<TOCEntry*>(pTmp);
-			UT_DEBUGMSG(("Using prevLevel %x thisentry %x \n",pPrevLevel,pThisEntry));
+			UT_DEBUGMSG(("Using prevLevel %p thisentry %p \n",pPrevLevel,pThisEntry));
 			if(pPrevLevel && pPrevLevel->getLevel() < pThisEntry->getLevel())
 			{
 				UT_ASSERT(pPrevLevel->getLevel() >= 0);
@@ -1158,7 +1158,7 @@ bool fl_TOCLayout::isBlockInTOC(fl_BlockLayout * pBlock)
 	TOCEntry * pEntry = NULL;
 	PL_StruxDocHandle sdh = pBlock->getStruxDocHandle();
 	UT_sint32 i = 0;
-	for(i=0; i< static_cast<UT_sint32>(m_vecEntries.getItemCount()); i++)
+	for(i=0; i< m_vecEntries.getItemCount(); i++)
 	{
 
 		pEntry = m_vecEntries.getNthItem(i);
@@ -1180,7 +1180,7 @@ UT_UTF8String & fl_TOCLayout::getTOCListLabel(fl_BlockLayout * pBlock)
 	PL_StruxDocHandle sdh = pBlock->getStruxDocHandle();
 	UT_sint32 i = 0;
 	bool bFound = false;
-	for(i=0; i< static_cast<UT_sint32>(m_vecEntries.getItemCount()); i++)
+	for(i=0; i< m_vecEntries.getItemCount(); i++)
 	{
 
 		pEntry = m_vecEntries.getNthItem(i);
@@ -1245,7 +1245,7 @@ void fl_TOCLayout::markAllRunsDirty(void)
 	}
 }
 
-void fl_TOCLayout::updateLayout(bool bDoAll)
+void fl_TOCLayout::updateLayout(bool /*bDoAll*/)
 {
 	if(needsReformat())
 	{
@@ -1281,6 +1281,7 @@ void fl_TOCLayout::redrawUpdate(void)
 
 bool fl_TOCLayout::doclistener_deleteStrux(const PX_ChangeRecord_Strux * pcrx)
 {
+	UT_UNUSED(pcrx);
 	UT_ASSERT(pcrx->getType()==PX_ChangeRecord::PXT_DeleteStrux);
 //
 // Remove all remaining structures
@@ -1309,11 +1310,11 @@ TOCEntry * fl_TOCLayout::createNewEntry(fl_BlockLayout * pNewBL)
 {
 	UT_UTF8String sDispStyle("");
 	bool bHaveLabel = true;
-	FootnoteType iFType; 
+	FootnoteType iFType = FOOTNOTE_TYPE_NUMERIC; 
 	UT_UTF8String sBefore;
 	UT_UTF8String sAfter; 
-	bool bInherit; 	
-	UT_sint32 iStartAt;
+	bool bInherit = false; 	
+	UT_sint32 iStartAt = 0;
 	if(m_iCurrentLevel == 1)
 	{
 		sDispStyle = m_sDestStyle1;
@@ -1354,6 +1355,9 @@ TOCEntry * fl_TOCLayout::createNewEntry(fl_BlockLayout * pNewBL)
 		bInherit = m_bInherit4;
 		iStartAt = m_iStartAt4;
 	}
+	else {
+		UT_ASSERT_NOT_REACHED();
+	}
 	TOCEntry * pNew = new TOCEntry(pNewBL,m_iCurrentLevel,
 								   sDispStyle,
 								   bHaveLabel,
@@ -1403,8 +1407,7 @@ void fl_TOCLayout::_createTOCContainer(void)
 	{
 		pCL = pCL->myContainingLayout();
 	}
-	fl_DocSectionLayout * pDSL = static_cast<fl_DocSectionLayout *>(pCL);
-	UT_ASSERT(pDSL != NULL);
+	UT_ASSERT(pCL);
 
 	fp_Container * pCon = pCL->getLastContainer();
 	UT_ASSERT(pCon);
@@ -1501,12 +1504,12 @@ void fl_TOCLayout::_insertTOCContainer( fp_TOCContainer * pNewTOC)
 		{
 			pUpCon = pUPCL->getLastContainer();
 		}
-		UT_ASSERT(pUpCon);
+		UT_return_if_fail(pUpCon);
 	}
 	else
 	{
 		pUpCon = pUPCL->getLastContainer();
-		UT_ASSERT(pUpCon);
+		UT_return_if_fail(pUpCon);
 	}
 	if(pPrevL == NULL)
 	{
@@ -1519,12 +1522,12 @@ void fl_TOCLayout::_insertTOCContainer( fp_TOCContainer * pNewTOC)
 	{
 		UT_sint32 i = pUpCon->findCon(pPrevCon);
 		xxx_UT_DEBUGMSG(("SEVIOR!!!!!!!!!! New TOC %x inserted into %x \n",pNewTOC,pUpCon));
-		if(i >= 0 && (i+1) < static_cast<UT_sint32>(pUpCon->countCons()))
+		if(i >= 0 && (i+1) < pUpCon->countCons())
 		{
 			pUpCon->insertConAt(pNewTOC,i+1);
 			pNewTOC->setContainer(pUpCon);
 		}
-		else if( i >=0 &&  (i+ 1) == static_cast<UT_sint32>(pUpCon->countCons()))
+		else if( i >=0 &&  (i+ 1) == pUpCon->countCons())
 		{
 			pUpCon->addCon(pNewTOC);
 			pNewTOC->setContainer(pUpCon);
@@ -1826,7 +1829,7 @@ void fl_TOCLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		}
 		else
 		{
-			m_bInherit1 = false;;
+			m_bInherit1 = false;
 		}
 	}
 	pszTOCLABELINHERITS = NULL;
@@ -1842,7 +1845,7 @@ void fl_TOCLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		}
 		else
 		{
-			m_bInherit2 = false;;
+			m_bInherit2 = false;
 		}
 	}
 	pszTOCLABELINHERITS = NULL;
@@ -1858,7 +1861,7 @@ void fl_TOCLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		}
 		else
 		{
-			m_bInherit3 = false;;
+			m_bInherit3 = false;
 		}
 	}
 	pszTOCLABELINHERITS = NULL;
@@ -1874,7 +1877,7 @@ void fl_TOCLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		}
 		else
 		{
-			m_bInherit4 = false;;
+			m_bInherit4 = false;
 		}
 	}
 //
@@ -2290,7 +2293,7 @@ bool fl_TOCListener::populate(PL_StruxFmtHandle sfh,
 	}
 
 	UT_ASSERT(m_pTOCL);
-	UT_DEBUGMSG(("fl_TOCListener::populate block %x \n",m_pCurrentBL));
+	UT_DEBUGMSG(("fl_TOCListener::populate block %p \n",m_pCurrentBL));
 
 	bool bResult = false;
 	//FV_View* pView = m_pTOCL->getDocLayout()->getView();
@@ -2301,9 +2304,9 @@ bool fl_TOCListener::populate(PL_StruxFmtHandle sfh,
 		const PX_ChangeRecord_Span * pcrs = static_cast<const PX_ChangeRecord_Span *> (pcr);
 
 		{
-			const fl_Layout * pL = static_cast<const fl_Layout *>(sfh);
-			UT_ASSERT(pL->getType() == PTX_Block);
-			UT_ASSERT(m_pCurrentBL == (static_cast<const fl_ContainerLayout *>(pL)));
+			UT_UNUSED(sfh);
+			UT_ASSERT(static_cast<const fl_Layout *>(sfh)->getType() == PTX_Block);
+			UT_ASSERT(m_pCurrentBL == (static_cast<const fl_ContainerLayout *>(sfh)));
 		}
 		PT_BlockOffset blockOffset = pcrs->getBlockOffset();
 		UT_uint32 len = pcrs->getLength();
@@ -2318,9 +2321,8 @@ bool fl_TOCListener::populate(PL_StruxFmtHandle sfh,
 		const PX_ChangeRecord_Object * pcro = static_cast<const PX_ChangeRecord_Object *>(pcr);
 
 		{
-			const fl_Layout * pL = static_cast<const fl_Layout *>(sfh);
-			UT_ASSERT(pL->getType() == PTX_Block);
-			UT_ASSERT(m_pCurrentBL == (static_cast<const fl_ContainerLayout *>(pL)));
+			UT_ASSERT(static_cast<const fl_Layout *>(sfh)->getType() == PTX_Block);
+			UT_ASSERT(m_pCurrentBL == (static_cast<const fl_ContainerLayout *>(sfh)));
 		}
 		PT_BlockOffset blockOffset = pcro->getBlockOffset();
 
@@ -2363,7 +2365,7 @@ bool fl_TOCListener::populateStrux(PL_StruxDocHandle sdh,
 		{
 			// append a new BlockLayout to that SectionLayout
 			fl_ContainerLayout*	pBL = m_pTOCL->insert(sdh,pMyBL, iTOC,FL_CONTAINER_BLOCK);
-			UT_DEBUGMSG(("New TOC block %x created and set as current \n",pBL));
+			UT_DEBUGMSG(("New TOC block %p created and set as current \n",pBL));
 			if (!pBL)
 			{
 				UT_DEBUGMSG(("no memory for BlockLayout"));
