@@ -86,6 +86,7 @@ class ABI_EXPORT fl_ColProps
 {
 public:
 	UT_sint32 m_iColWidth;
+	double    m_dColRelWidth;
 };
 
 class ABI_EXPORT fl_RowProps
@@ -182,7 +183,8 @@ UT_sint32                    getBottomOffset(void) const;
 	bool                     isDirty(void) const
 		{ return m_bIsDirty;}
 	void                     setDirty(void);
-
+	double                   getTableRelWidth(void) const
+	{ return m_dTableRelWidth;}
 	UT_sint32                getLineThickness(void) const;
 	UT_sint32                getColSpacing(void) const;
 	UT_sint32                getRowSpacing(void) const;
@@ -260,6 +262,8 @@ private:
     UT_sint32              m_iHeightChanged;
 	fp_CellContainer *     m_pNewHeightCell;
 	bool                   m_bDoingDestructor;
+	UT_sint32              m_iTableWidth;
+	double                 m_dTableRelWidth;
 };
 
 
