@@ -108,6 +108,11 @@ void fp_FrameContainer::setPage(fp_Page * pPage)
 	}
 }
 
+
+bool fp_FrameContainer::isAbove(void)
+{
+  return  m_bIsAbove;
+}
 /*!
  * Returns true if the frame should be relocated before placing on a page
  */
@@ -573,6 +578,7 @@ void  fp_FrameContainer::drawHandles(dg_DrawArgs * pDA)
 	UT_sint32 iYlow = pDA->yoff - m_iYpad;
 
 	UT_Rect box(iXlow + pDA->pG->tlu(2), iYlow + pDA->pG->tlu(2), getFullWidth() - pDA->pG->tlu(4), iFullHeight - pDA->pG->tlu(4));
+	getPage()->expandDamageRect(box.left,box.top,box.width,box.height);
 	getView()->drawSelectionBox(box, true);
 }
 
@@ -626,6 +632,10 @@ void fp_FrameContainer::draw(dg_DrawArgs* pDA)
 	dg_DrawArgs da = *pDA;
 	GR_Graphics * pG = da.pG;
 	UT_return_if_fail( pG);
+
+	UT_sint32 x = pDA->xoff - m_iXpad;
+	UT_sint32 y = pDA->yoff - m_iYpad;
+	getPage()->expandDamageRect(x,y,getFullWidth(),getFullHeight());
 	if(!pDA->bDirtyRunsOnly || m_bNeverDrawn)
 	{
 		if(m_bNeverDrawn)
@@ -636,11 +646,6 @@ void fp_FrameContainer::draw(dg_DrawArgs* pDA)
 		getSectionLayout()->checkGraphicTick(pG);
 		srcX = -m_iXpad;
 		srcY = -m_iYpad;
-
-		UT_sint32 x = pDA->xoff - m_iXpad;
-		UT_sint32 y = pDA->yoff - m_iYpad;
-		getPage()->expandDamageRect(x,y,getFullWidth(),getFullHeight());
-
 		//
 		// Only fill to the bottom of the viewed page.
 		//
@@ -661,21 +666,23 @@ void fp_FrameContainer::draw(dg_DrawArgs* pDA)
 		        iFullHeight = iFullHeight - (iBot-iMaxHeight);
 		}
 		getFillType()->Fill(pG,srcX,srcY,x,y,getFullWidth(),iFullHeight);
+		m_bNeverDrawn = false;
 	}
 	UT_uint32 count = countCons();
+	UT_DEBUGMSG(("Number of containers in frame %d \n",count));
 	const UT_Rect * pPrevRect = pDA->pG->getClipRect();
 	UT_Rect * pRect = getScreenRect();
 	UT_Rect newRect;
 	bool bRemoveRectAfter = false;
 	bool bSetOrigClip = false;
 	bool bSkip = false;
-	if(pPrevRect == NULL)
+	if((pPrevRect == NULL) && pG->queryProperties(GR_Graphics::DGP_SCREEN))
 	{
 		pDA->pG->setClipRect(pRect);
 		UT_DEBUGMSG(("Clip bottom is %d \n",pRect->top + pRect->height));
 		bRemoveRectAfter = true;
 	}
-	else if(!pRect->intersectsRect(pPrevRect))
+	else if(pPrevRect && !pRect->intersectsRect(pPrevRect))
 	{
 		bSkip = true;
 		xxx_UT_DEBUGMSG(("External Clip bottom is %d \n",pRect->top + pRect->height));
@@ -688,7 +695,7 @@ void fp_FrameContainer::draw(dg_DrawArgs* pDA)
 		newRect.height = UT_MIN(iBotPrev,iBot) - newRect.top;
 		newRect.width = pPrevRect->width;
 		newRect.left = pPrevRect->left;
-		if(newRect.height > 0)
+		if((newRect.height > 0) && pDA->pG->queryProperties(GR_Graphics::DGP_SCREEN))
 		{
 			pDA->pG->setClipRect(&newRect);
 			bSetOrigClip = true;
@@ -813,4 +820,21 @@ void fp_FrameContainer::layout(void)
 			pPrevContainer->setAssignedScreenHeight(iY - iPrevY + 1);
 		}
 	}
+	fl_FrameLayout * pFL = static_cast<fl_FrameLayout *>(getSectionLayout());
+	if(pFL->expandHeight() && (iY > pFL->minHeight()))
+	{
+	     setHeight(iY+m_iYpad*2);
+	}
+}
+
+void fp_FrameContainer::setHeight(UT_sint32 iY)
+{
+        if(iY != getFullHeight())
+	{
+	     xxx_UT_DEBUGMSG((" SetHeight Frame iY %d Fullheight %d Height %d \n",iY,getFullHeight(),getHeight()));
+	     clearScreen();
+	     fp_VerticalContainer::setHeight(iY);
+	     fp_Page * pPage = getPage();
+	     getDocSectionLayout()->setNeedsSectionBreak(true,pPage);
+	}
 }
