@@ -696,6 +696,12 @@ void fp_TOCContainer::adjustBrokenTOCs(void)
 	{
 		return;
 	}
+	//
+	// FIXME. Both this code and the code in fp_TableContainer, somehow leads to bugs. I've clearly found
+	// workarounds to what this is trying to achive. In pricinple this code should make laying out TOC's
+	// faster. In parctice I suspect it leads to bugs in fb_ColumnBreaker. I'll leave these returns in place
+	// for now, pending removal of the methods.
+	//
 	return;
 	fp_TOCContainer * pBroke = getFirstBrokenTOC();
 	fp_VerticalContainer * pVC = static_cast<fp_VerticalContainer *>(getContainer());
@@ -836,15 +842,19 @@ void fp_TOCContainer::deleteBrokenTOCs(bool bClearFirst)
 		pLast = pBroke;
 		if(!bFirst)
 		{
-			UT_sint32 i = pBroke->getContainer()->findCon(pBroke);
+		        fp_Container * pConBroke =  pBroke->getContainer();
+			if(pConBroke)
+			{
+			    UT_sint32 i = pBroke->getContainer()->findCon(pBroke);
 //
 // First broken TOC is not in the container.
 //
-			if(i >=0)
-			{
-				fp_Container * pCon = pBroke->getContainer();
+			    if(i >=0)
+			    {
+			        fp_Container * pCon = pBroke->getContainer();
 				pBroke->setContainer(NULL);
 				pCon->deleteNthCon(i);
+			    }
 			}
 		}
 		bFirst = false;
