@@ -414,6 +414,7 @@ public:
 	bool            isTOCSelected(void) const;
 	bool            setTOCProps(PT_DocPosition pos, const char * szProps);
 
+	bool			cmdSelectNoNotify(PT_DocPosition dpBeg, PT_DocPosition dpEnd);
 	void			cmdSelect(PT_DocPosition dpBeg, PT_DocPosition dpEnd);
 	void			cmdCharMotion(bool bForward, UT_uint32 count);
 	bool			cmdCharInsert(const UT_UCSChar * text, UT_uint32 count, bool bForce = false);
@@ -849,6 +850,7 @@ protected:
 	void				_moveInsPtNextPrevPage(bool bNext);
 	void				_moveInsPtNextPrevScreen(bool bNext);
 	void				_moveInsPtNextPrevLine(bool bNext);
+	fp_Line *           _getNextLineInDoc(fp_Container * pCon);
 	fp_Page *			_getCurrentPage(void) const;
 	void				_moveInsPtNthPage(UT_sint32 n);
 	void				_moveInsPtToPage(fp_Page *page);
