@@ -136,8 +136,11 @@ static const char * AbiPropertyName[PP_PropertyMap::abi__count] = {
 	"table-margin-left",
 	"table-margin-right",
 	"table-margin-top",
+	"table-rel-column-props",
+	"table-rel-width",
 	"table-row-props",
 	"table-row-spacing",
+	"table-width",
 	"tabstops",
 	"text-align",
 	"text-decoration",
