@@ -40,7 +40,6 @@
 #include "px_CR_Strux.h"
 #include "fd_Field.h"
 #include "pp_Revision.h"
-#include "ut_uuid.h"
 #include "pd_Document.h"
 
 /****************************************************************/
@@ -157,8 +156,6 @@ bool pt_PieceTable::_insertSpan(pf_Frag * pf,
 	// return true if successful.
 
 	pf_Frag_Text * pft = NULL;
-	PT_DocPosition newPos = pf->getPos();
-	uuid myUID;
 	switch (pf->getType())
 	{
 	default:
@@ -215,13 +212,8 @@ bool pt_PieceTable::_insertSpan(pf_Frag * pf,
 			// we are to insert it immediately after this fragment.
 			// if we are coalescable, just append it to this fragment
 			// rather than create a new one.
-		        PX_ChangeRecord * pcr = NULL;
-			getNthUndo(&pcr,0);
-			AD_Document *pDoc = static_cast<AD_Document *>(getDocument());
-			const UT_UUID * pUUID = pDoc->getMyUUID();
-			pUUID->toBinary( myUID );
 			if (   (pft->getIndexAP()==indexAP)
-			       && m_varset.isContiguous(pft->getBufIndex(),fragLen,bi) && pcr && (pcr->isSameDocUUID(myUID)))
+			       && m_varset.isContiguous(pft->getBufIndex(),fragLen,bi))
 			{
 				// new text is contiguous, we just update the length of this fragment.
 
@@ -598,18 +590,22 @@ bool pt_PieceTable::_realInsertSpan(PT_DocPosition dpos,
                                    blockOffset, pField);
 	UT_return_val_if_fail (pcr, false);
 
-	if (!bAddChangeRec || _canCoalesceInsertSpan(pcr))
 	{
-		if (bAddChangeRec)
-			m_history.coalesceHistory(pcr);
+	        pcr->setDocument(m_pDocument);
+		bool canCoalesce = _canCoalesceInsertSpan(pcr);
+		if (!bAddChangeRec || (canCoalesce && !m_pDocument->isCoalescingMasked()))
+		{
+			if (canCoalesce)
+				m_history.coalesceHistory(pcr);
 
-		m_pDocument->notifyListeners(pfs,pcr);
-		delete pcr;
-	}
-	else
-	{
-		m_history.addChangeRecord(pcr);
-		m_pDocument->notifyListeners(pfs,pcr);
+			m_pDocument->notifyListeners(pfs,pcr);
+			delete pcr;
+		}
+		else
+		{
+			m_history.addChangeRecord(pcr);
+			m_pDocument->notifyListeners(pfs,pcr);
+		}
 	}
 
 	bSuccess = true;
@@ -636,6 +632,9 @@ bool pt_PieceTable::_canCoalesceInsertSpan(PX_ChangeRecord_Span * pcrSpan) const
 		return false;
 
 	PX_ChangeRecord_Span * pcrUndoSpan = static_cast<PX_ChangeRecord_Span *>(pcrUndo);
+	if((pcrUndoSpan->isFromThisDoc() != pcrSpan->isFromThisDoc()))
+	   return false;
+
 	UT_uint32 lengthUndo = pcrUndoSpan->getLength();
 
 	if ((pcrUndo->getPosition() + lengthUndo) != pcrSpan->getPosition())
