@@ -297,8 +297,8 @@ bool pt_PieceTable::_doTheDo(const PX_ChangeRecord * pcr, bool bUndo)
 			UNDO_return_val_if_fail (bFound, false);
 
 			pf_Frag_Strux * pfs = NULL;
-			bool bFoundStrux = _getStruxFromFrag(pf,&pfs);
-			UNDO_return_val_if_fail (bFoundStrux, false);
+			bool bFoundStrux2 = _getStruxFromFrag(pf,&pfs);
+			UNDO_return_val_if_fail (bFoundStrux2, false);
 			if(isEndFootnote(static_cast<pf_Frag *>(pfs)))
 			{
 				bool bFoundStrux = _getStruxFromFragSkip(static_cast<pf_Frag *>(pfs),&pfs);
@@ -343,8 +343,8 @@ bool pt_PieceTable::_doTheDo(const PX_ChangeRecord * pcr, bool bUndo)
 			UNDO_return_val_if_fail (fragOffset == 0,false);
 			
 			pf_Frag_Strux * pfs = NULL;
-			bool bFoundStrux = _getStruxFromFrag(pf,&pfs);
-			UNDO_return_val_if_fail (bFoundStrux,false);
+			bool bFoundStrux2 = _getStruxFromFrag(pf,&pfs);
+			UNDO_return_val_if_fail (bFoundStrux2,false);
 			if(isEndFootnote(static_cast<pf_Frag *>(pfs)))
 			{
 				bool bFoundStrux = _getStruxFromFragSkip(static_cast<pf_Frag *>(pfs),&pfs);
@@ -381,8 +381,8 @@ bool pt_PieceTable::_doTheDo(const PX_ChangeRecord * pcr, bool bUndo)
 			UNDO_return_val_if_fail (fragOffset == 0, false);
 
 			pf_Frag_Strux * pfs = NULL;
-			bool bFoundStrux = _getStruxFromFrag(pf,&pfs);
-			UNDO_return_val_if_fail (bFoundStrux,false);
+			bool bFoundStrux2 = _getStruxFromFrag(pf,&pfs);
+			UNDO_return_val_if_fail (bFoundStrux2,false);
 			if(isEndFootnote(static_cast<pf_Frag *>(pfs)))
 			{
 				bool bFoundStrux = _getStruxFromFragSkip(static_cast<pf_Frag *>(pfs),&pfs);
@@ -413,8 +413,8 @@ bool pt_PieceTable::_doTheDo(const PX_ChangeRecord * pcr, bool bUndo)
 			UNDO_return_val_if_fail (bFound, false);
 
 			pf_Frag_Strux * pfs = NULL;
-			bool bFoundStrux = _getStruxFromFrag(pf,&pfs);
-			UNDO_return_val_if_fail (bFoundStrux, false);
+			bool bFoundStrux2 = _getStruxFromFrag(pf,&pfs);
+			UNDO_return_val_if_fail (bFoundStrux2, false);
 			if(isEndFootnote(static_cast<pf_Frag *>(pfs)))
 			{
 				bool bFoundStrux = _getStruxFromFragSkip(static_cast<pf_Frag *>(pfs),&pfs);
@@ -560,16 +560,6 @@ bool pt_PieceTable::canDo(bool bUndo) const
 	return m_history.canDo(bUndo);
 }
 
-bool pt_PieceTable::getNthUndo(PX_ChangeRecord ** ppcr, UT_sint32 iUndo) const
-{
-        if(iUndo > static_cast<UT_sint32>(undoCount(true)))
-	{
-	       return false;
-	}
-	m_history.getNthUndo(ppcr, iUndo);
-	return true;
-}
-
 UT_uint32 pt_PieceTable::undoCount(bool bUndo) const
 {
   if(bUndo)
@@ -597,7 +587,7 @@ bool pt_PieceTable::undoCmd(void)
 	// for a simple change, we just do it and return.
 	// for a glob, we loop until we do the
 	// corresponding other end.
-
+	m_history.setScanningUndoGLOB(false);
 	UT_Byte flagsFirst = GETGLOBFLAGS(pcr);
 	if(m_fragments.areFragsDirty())
 	{
@@ -620,6 +610,7 @@ bool pt_PieceTable::undoCmd(void)
 			break;
 
 	} while (m_history.getUndo(&pcr));
+	m_history.setScanningUndoGLOB(false);
 	m_pDocument->updateFields();
 	return true;
 }
@@ -628,7 +619,7 @@ bool pt_PieceTable::redoCmd(void)
 {
 	// do a user-atomic redo.
 	// return false if we can't.
-	
+        m_history.setScanningUndoGLOB(false);	
 	PX_ChangeRecord * pcr;
 	if (!m_history.getRedo(&pcr))
 		return false;
@@ -660,7 +651,7 @@ bool pt_PieceTable::redoCmd(void)
 		if (flagsRevFirst == GETGLOBFLAGS(pcr))		// stop when we have a matching end
 			break;
 	}
-
+	m_history.setScanningUndoGLOB(false);
 	return true;
 }
 
