@@ -60,7 +60,7 @@ public:
 	~pt_PieceTable();
 
 	void					setPieceTableState(PTState pts);
-	const PTState           getPieceTableState() const {return m_pts;}
+	PTState					getPieceTableState() const {return m_pts;}
 	void					beginMultiStepGlob(void);
 	void					endMultiStepGlob(void);
 	void					beginUserAtomicGlob(void);
@@ -73,7 +73,12 @@ public:
 	UT_uint32                               undoCount(bool bUndo) const;
 	bool					undoCmd(void);
 	bool					redoCmd(void);
-    bool                    getNthUndo(PX_ChangeRecord ** ppcr, UT_sint32 iUndo) const;
+	bool					getNthUndo(PX_ChangeRecord ** ppcr, UT_uint32 undoNdx) const
+								{ return m_history.getNthUndo(ppcr, undoNdx); }
+	bool					getUndo(PX_ChangeRecord ** ppcr, bool bStatic=false) const
+								{ return m_history.getUndo(ppcr, bStatic); }
+	bool					getRedo(PX_ChangeRecord ** ppcr) const
+								{ return m_history.getRedo(ppcr); }
 	void                    clearUndo() {m_history.clearHistory();}
 	
 	static void		s_getLocalisedStyleName(const char *szStyle, UT_UTF8String &utf8);
@@ -176,6 +181,8 @@ public:
 	bool                    createAndSendCR(PT_DocPosition  dpos, 
 											UT_sint32 iType,bool bSave, UT_Byte iGlob);
 
+	bool                    createAndSendDocPropCR( const gchar ** pAtts, const gchar ** pProps);
+
 	bool					deleteSpanWithTable(PT_DocPosition dpos1,
 												PT_DocPosition dpos2,
 												PP_AttrProp *p_AttrProp_Before,
@@ -224,6 +231,7 @@ public:
 												const char * pszParentID);
     bool                    changeSectionAttsNoUpdate(pf_Frag_Strux * pfStrux, const char * attr, const char * attvalue);
 	bool                    deleteStruxNoUpdate(PL_StruxDocHandle sdh);
+	bool                    deleteFragNoUpdate(pf_Frag * pf);
 	bool                    deleteStruxWithNotify(PL_StruxDocHandle sdh);
 	bool                    insertStruxNoUpdateBefore(PL_StruxDocHandle sdh, PTStruxType pts,const gchar ** attributes );
 	bool                    changeLastStruxFmtNoUndo(PT_DocPosition dpos, PTStruxType pts,
@@ -256,7 +264,7 @@ public:
 											   bool bSkipEmbededSections);
 	
 	bool					appendFmt(const gchar ** attributes);
-	bool					appendFmt(const UT_GenericVector<gchar*> * pVecAttributes);
+	bool					appendFmt(const UT_GenericVector<const gchar*> * pVecAttributes);
 	bool					appendSpan(const UT_UCSChar * p, UT_uint32 length);
 	bool					appendObject(PTObjectType pto, const gchar ** attributes);
 	bool					appendFmtMark(void);
@@ -271,7 +279,7 @@ public:
 	bool					insertFmtMarkBeforeFrag(pf_Frag * pF, const gchar ** attributes);
 	
 	bool					removeStyle(const gchar * name);
-	size_t					getStyleCount(void);
+	size_t					getStyleCount(void) const;
 
 	bool					tellListener(PL_Listener * pListener);
 	bool					tellListenerSubset(PL_Listener * pListener,
@@ -353,7 +361,7 @@ public:
 #ifdef PT_TEST
 	UT_TestStatus			__test_VerifyCoalescedFrags(FILE * fp) const;
 	void					__dump(FILE * fp) const;
-	px_ChangeHistory*		getChangeHistory(void)
+	px_ChangeHistory*		getChangeHistory(void) const
 		{ return &m_history; }
 #endif /* PT_TEST */
 
