@@ -97,7 +97,7 @@ typedef enum _PTStruxType
 
 //! PTObjectType tells the sub-type of an FragObject.
 
-typedef enum _PTObjectType { PTO_Image = 0, PTO_Field, PTO_Bookmark, PTO_Hyperlink, PTO_Math, PTO_Embed } PTObjectType;
+typedef enum _PTObjectType { PTO_Image = 0, PTO_Field, PTO_Bookmark, PTO_Hyperlink, PTO_Math, PTO_Embed,PTO_Annotation } PTObjectType;
 
 //! PieceTable states
 typedef enum _PTState { PTS_Create=0, PTS_Loading=1, PTS_Editing=2 } PTState;
@@ -145,6 +145,10 @@ typedef const void * PL_StruxFmtHandle;
 #define PT_FOOTERFIRST_ATTRIBUTE_NAME	(static_cast<const gchar *>("footer-first"))
 #define PT_FOOTERLAST_ATTRIBUTE_NAME	(static_cast<const gchar *>("footer-last"))
 #define PT_REVISION_ATTRIBUTE_NAME      (static_cast<const gchar *>("revision"))
+#define PT_REVISION_DESC_ATTRIBUTE_NAME      (static_cast<const gchar *>("revision-desc"))
+#define PT_REVISION_TIME_ATTRIBUTE_NAME      (static_cast<const gchar *>("revision-time"))
+#define PT_REVISION_VERSION_ATTRIBUTE_NAME      (static_cast<const gchar *>("revision-ver"))
+#define PT_DOCPROP_ATTRIBUTE_NAME      (static_cast<const gchar *>("docprop"))
 #define PT_STRUX_IMAGE_DATAID           (static_cast<const gchar *>("strux-image-dataid"))
 #define PT_XID_ATTRIBUTE_NAME           (static_cast<const gchar *>("xid"))
 #define PT_DATAITEM_ATTRIBUTE_NAME           (static_cast<const gchar *>("dataitem"))
@@ -152,6 +156,7 @@ typedef const void * PL_StruxFmtHandle;
 #define PT_IMAGE_TITLE           (static_cast<const gchar *>("title"))
 #define PT_IMAGE_DESCRIPTION           (static_cast<const gchar *>("alt"))
 #define PT_DATA_PREVIEW           (static_cast<const gchar *>("preview"))
-
-
+#define PT_HYPERLINK_TARGET_NAME  (static_cast<const gchar *>("xlink:href"))
+#define PT_AUTHOR_NAME          (static_cast<const gchar *>("author"))
+#define PT_ANNOTATION_NUMBER     (static_cast<const gchar *>("annotation"))
 #endif /* PT_TYPES_H */
