@@ -67,7 +67,6 @@
 
 #include "xav_View.h"
 
-#include "gr_CocoaGraphics.h"
 #include "gr_CocoaImage.h"
 #include "gr_Graphics.h"
 #include "gr_Image.h"
@@ -655,7 +654,7 @@ void AP_CocoaApp::pasteFromClipboard(PD_DocumentRange * pDocRange, bool /*bUseCl
 		  
 		  bytes->append (pData, iLen);
 		  
-		  error = IE_ImpGraphic::constructImporter(bytes, iegft, &pIEG);
+		  error = IE_ImpGraphic::constructImporter(*bytes, iegft, &pIEG);
 		  if(error)
 		  {
 			  UT_DEBUGMSG(("DOM: could not construct importer (%d)\n", 
@@ -674,6 +673,7 @@ void AP_CocoaApp::pasteFromClipboard(PD_DocumentRange * pDocRange, bool /*bUseCl
 		  }
 		  
 		  // at this point, 'bytes' is owned by pFG
+		  bytes = NULL;
 		  FV_View * pView = static_cast<FV_View*>(pFrame->getCurrentView());
 		  
 		  UT_UTF8String newName = UT_UTF8String_sprintf ( "paste_image_%d", UT_newNumber() ) ;
