@@ -26,6 +26,7 @@
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
 
+#include "gr_CocoaCairoGraphics.h"
 #include "xap_Dialog_Id.h"
 #include "xap_CocoaApp.h"
 #include "xap_CocoaFrame.h"
@@ -96,8 +97,8 @@ void AP_CocoaDialog_Lists::runModal( XAP_Frame * /*pFrame*/)
 
 
 	NSView* preview = [m_dlg preview];
-	GR_CocoaAllocInfo ai(preview);
-	m_pPreviewWidget = (GR_CocoaGraphics*)XAP_App::getApp()->newGraphics(ai);
+	GR_CocoaCairoAllocInfo ai(preview);
+	m_pPreviewWidget = (GR_CocoaCairoGraphics*)XAP_App::getApp()->newGraphics(ai);
 
 	// let the widget materialize
 
@@ -143,8 +144,8 @@ void AP_CocoaDialog_Lists::runModeless (XAP_Frame * /*pFrame*/)
 
 	// make a new Cocoa GC
 	NSView* preview = [m_dlg preview];
-	GR_CocoaAllocInfo ai(preview);
-	m_pPreviewWidget = static_cast<GR_CocoaGraphics*>(XAP_App::getApp()->newGraphics(ai));
+	GR_CocoaCairoAllocInfo ai(preview);
+	m_pPreviewWidget = static_cast<GR_CocoaCairoGraphics*>(XAP_App::getApp()->newGraphics(ai));
 
 	// let the widget materialize
 
@@ -588,7 +589,7 @@ void AP_CocoaDialog_Lists::loadXPDataIntoLocal(void)
 	}
 	[m_dlg->_startAtData setIntValue:getiStartValue()];
 
-	[m_dlg->_levelDelimData setStringValue:[NSString stringWithUTF8String:getDelim().c_str()]];
+	[m_dlg->_levelDelimData setStringValue:[NSString stringWithUTF8String:getDecimal().c_str()]];
 	[m_dlg->_formatData setStringValue:[NSString stringWithUTF8String:getDelim().c_str()]];
 
 	//
@@ -632,7 +633,7 @@ void AP_CocoaDialog_Lists::_gatherData(void)
 {
 	UT_sint32 maxWidth = getBlock()->getFirstContainer()->getContainer()->getWidth();
 
-	float fmaxWidthIN = ((float) maxWidth / GR_CocoaGraphics::_getScreenResolution()) - 0.6;
+	float fmaxWidthIN = ((float) maxWidth / GR_CocoaCairoGraphics::_getScreenResolution()) - 0.6;
 	setiLevel(1);
 	float f = [m_dlg->_textAlignData floatValue];
 	if(f >   fmaxWidthIN)
@@ -719,8 +720,8 @@ void AP_CocoaDialog_Lists::_gatherData(void)
 	LocalizeControl(_fontLabel, pSS, AP_STRING_ID_DLG_Lists_Font);
 	LocalizeControl(_levelDelimLabel, pSS, AP_STRING_ID_DLG_Lists_DelimiterString);
 	LocalizeControl(_startAtLabel, pSS, AP_STRING_ID_DLG_Lists_Start);
-	LocalizeControl(_labelAlignLabel, pSS, AP_STRING_ID_DLG_Lists_Align);
-	LocalizeControl(_textAlignLabel, pSS, AP_STRING_ID_DLG_Lists_Indent);
+	LocalizeControl(_textAlignLabel, pSS, AP_STRING_ID_DLG_Lists_Align);
+	LocalizeControl(_labelAlignLabel, pSS, AP_STRING_ID_DLG_Lists_Indent);
 	LocalizeControl(_previewBox, pSS, AP_STRING_ID_DLG_Lists_Preview);
 	LocalizeControl(_startNewListBtn, pSS, AP_STRING_ID_DLG_Lists_Start_New);
 	LocalizeControl(_applyToCurrentBtn, pSS, AP_STRING_ID_DLG_Lists_Apply_Current);
