@@ -26,7 +26,7 @@
 #import "ut_types.h"
 #import "ut_debugmsg.h"
 #import "ut_assert.h"
-#import "gr_CocoaGraphics.h"
+#import "gr_CocoaCairoGraphics.h"
 #import "ev_CocoaToolbar.h"
 #import "ev_CocoaMouse.h"
 
@@ -48,7 +48,7 @@
 @interface XAP_NSScroller : NSScroller
 {
 }
--(id)initWithFrame:(NSRect)frame andController:(AP_CocoaFrameController*)controller vertical:(BOOL)vertical;
+-(id)initWithFrame:(NSRect)frame andController:(NSController*)controller vertical:(BOOL)vertical;
 
 @end
 
@@ -468,10 +468,10 @@ void AP_CocoaFrameImpl::_createDocView(GR_Graphics* &pG)
 	[[_getController() window] makeFirstResponder:m_docAreaGRView];
 	[m_docAreaGRView release];
 	
-	GR_CocoaAllocInfo ai(m_docAreaGRView);
-	pG = (GR_CocoaGraphics*)XAP_App::getApp()->newGraphics(ai);
+	GR_CocoaCairoAllocInfo ai(m_docAreaGRView);
+	pG = (GR_CocoaCairoGraphics*)XAP_App::getApp()->newGraphics(ai);
 
-	static_cast<GR_CocoaGraphics *>(pG)->_setUpdateCallback (&_graphicsUpdateCB, (void *)pFrame);
+	static_cast<GR_CocoaCairoGraphics *>(pG)->_setUpdateCallback (&_graphicsUpdateCB, (void *)pFrame);
 }
 
 
@@ -614,7 +614,7 @@ XAP_CocoaFrameController *AP_CocoaFrameImpl::_createController()
 
 
 
-bool AP_CocoaFrameImpl::_graphicsUpdateCB(NSRect * aRect, GR_CocoaGraphics *pG, void* param)
+bool AP_CocoaFrameImpl::_graphicsUpdateCB(NSRect * aRect, GR_CocoaCairoGraphics *pG, void* param)
 {
 	// a static function
 	AP_CocoaFrame * pCocoaFrame = static_cast<AP_CocoaFrame *>(param);
@@ -685,7 +685,7 @@ void AP_CocoaFrameImpl::giveFocus()
 
 @implementation XAP_NSScroller
 
--(id)initWithFrame:(NSRect)frame andController:(AP_CocoaFrameController*)controller vertical:(BOOL)vertical
+-(id)initWithFrame:(NSRect)frame andController:(NSController*)controller vertical:(BOOL)vertical
 {
 	if(![super initWithFrame:frame]) {
 		return nil;
