@@ -621,8 +621,8 @@ public:
 			UT_uint32 _page_count = m_pView->getLayout()->countPages();
 			UT_uint32 _current_page = m_pView->getCurrentPageNumForStatusBar();
 
-			FIRE_UINT32(_page_count, pageCount_, pageCount); // should be UINT32 ofcourse
-			FIRE_UINT32(_current_page, currentPage_, currentPage); // should be UINT32 ofcourse
+			FIRE_UINT32(_page_count, pageCount_, pageCount);
+			FIRE_UINT32(_current_page, currentPage_, currentPage);
 		}
 
 		if ((AV_CHG_FMTBLOCK | AV_CHG_MOTION) & mask)
@@ -2065,6 +2065,19 @@ abi_widget_size_allocate (GtkWidget     *widget,
     }
 }
 
+static void
+abi_widget_grab_focus (GtkWidget * widget)
+{
+       UT_return_if_fail(widget != NULL);
+       UT_return_if_fail(IS_ABI_WIDGET(widget));
+
+       XAP_Frame *pFrame = ABI_WIDGET(widget)->priv->m_pFrame;
+       UT_return_if_fail(pFrame);
+
+       GtkWidget *dArea = static_cast<AP_UnixFrameImpl *>(pFrame->getFrameImpl())->getDrawingArea();
+       gtk_widget_grab_focus(dArea);
+}
+
 static void
 abi_widget_realize (GtkWidget * widget)
 {
@@ -2190,6 +2203,7 @@ abi_widget_class_init (AbiWidgetClass *abi_class)
 	widget_class->realize       = abi_widget_realize;
 	widget_class->size_request  = abi_widget_size_request;
    	widget_class->size_allocate = abi_widget_size_allocate; 
+	widget_class->grab_focus    = abi_widget_grab_focus;
 
 	// For the container methods
 	container_class->add = abiwidget_add;
