@@ -466,13 +466,6 @@ GtkWidget * AP_UnixDialog_FormatFrame::_constructWindow(void)
 	m_wLineLeft = GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderLeft"));
 	m_wLineRight = GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderRight"));
 	m_wLineBottom = GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderBottom"));
-
-	// the toggle buttons created by GtkBuilder already contain a label, remove that, so we can add a pixmap as a child
-	gtk_container_remove(GTK_CONTAINER(m_wLineTop), gtk_bin_get_child(GTK_BIN(m_wLineTop)));
-	gtk_container_remove(GTK_CONTAINER(m_wLineLeft), gtk_bin_get_child(GTK_BIN(m_wLineLeft)));
-	gtk_container_remove(GTK_CONTAINER(m_wLineRight), gtk_bin_get_child(GTK_BIN(m_wLineRight)));
-	gtk_container_remove(GTK_CONTAINER(m_wLineBottom), gtk_bin_get_child(GTK_BIN(m_wLineBottom)));
-	
 	// place some nice pixmaps on our border toggle buttons
 	label_button_with_abi_pixmap(m_wLineTop, "tb_LineTop_xpm");
 	label_button_with_abi_pixmap(m_wLineLeft, "tb_LineLeft_xpm");
