@@ -1,3 +1,5 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * 
@@ -29,6 +31,7 @@
 #include "ut_units.h"
 #include "ut_debugmsg.h"
 
+#include "xap_App.h"
 #include "xap_Dialog_Id.h"
 #include "xad_Document.h"
 #include "xap_DialogFactory.h"
@@ -39,7 +42,6 @@
 
 #include "ap_Dialog_Tab.h"
 #include "ap_Prefs_SchemeIds.h"
-#include "ap_Strings.h"
 #include "ap_TopRuler.h"		// for AP_TopRulerInfo
 
 
@@ -58,9 +60,7 @@ AP_Dialog_Tab::AP_Dialog_Tab(XAP_DialogFactory * pDlgFactory, XAP_Dialog_Id id)
 
 AP_Dialog_Tab::~AP_Dialog_Tab(void)
 {
-  if (NULL != m_pszTabStops)
-    delete [] m_pszTabStops;
-
+  DELETEPV(m_pszTabStops);
   UT_VECTOR_PURGEALL(fl_TabStop *, m_tabInfo);
 }
 
@@ -189,7 +189,7 @@ void AP_Dialog_Tab::_event_TabSelected( UT_sint32 index )
 
 	if(index >= 0)
 	{
-		UT_return_if_fail (index < (UT_sint32)m_tabInfo.getItemCount());
+		UT_return_if_fail (index < m_tabInfo.getItemCount());
 
 		fl_TabStop *pTabInfo = (fl_TabStop *)m_tabInfo.getNthItem(index);
 
@@ -235,7 +235,7 @@ void AP_Dialog_Tab::_event_Set(void)
 
 		Dimension_size++;
 	}
-	UT_uint32 i;
+	UT_sint32 i;
 	// do we have the tab already.
 
 	for (  i = 0; i < m_tabInfo.getItemCount(); i++ )
@@ -272,7 +272,7 @@ void AP_Dialog_Tab::_event_Set(void)
 	FV_View *pView = static_cast<FV_View *>(m_pFrame->getCurrentView());
 	UT_return_if_fail(pView);
 	
-	buildTabStops(pView->getGraphics(), m_pszTabStops, m_tabInfo);
+	buildTabStops(m_pszTabStops, m_tabInfo);
 
 	_setTabList(m_tabInfo.getItemCount());
 
@@ -303,7 +303,7 @@ void AP_Dialog_Tab::_event_Set(void)
 */
 void AP_Dialog_Tab::_event_Update(void)
 {
-	fl_TabStop *pTabInfo = NULL;
+	fl_TabStop *pTabInfo1 = NULL;
 
 	// check the validity of the input
 	UT_String buffer;
@@ -317,8 +317,8 @@ void AP_Dialog_Tab::_event_Update(void)
 
 	// delete tab
 	UT_uint32 ndx = _gatherSelectTab();
-	pTabInfo = m_tabInfo.getNthItem(ndx);
-	_deleteTabFromTabString(pTabInfo);
+	pTabInfo1 = m_tabInfo.getNthItem(ndx);
+	_deleteTabFromTabString(pTabInfo1);
 	m_tabInfo.deleteNthItem(ndx);
 
 
@@ -338,17 +338,17 @@ void AP_Dialog_Tab::_event_Update(void)
 	}
 
 	// do we have the tab already.
-	UT_uint32 i;
+	UT_sint32 i;
 	for (i = 0; i < m_tabInfo.getItemCount(); i++ )
 	{
-		pTabInfo = (fl_TabStop *)m_tabInfo.getNthItem(i);
-		UT_return_if_fail (pTabInfo);
+		pTabInfo1 = (fl_TabStop *)m_tabInfo.getNthItem(i);
+		UT_return_if_fail (pTabInfo1);
 
 		// if we have a tab at that unit
-		if ( memcmp(cbuffer, _getTabString(pTabInfo), Dimension_size) == 0 )
+		if ( memcmp(cbuffer, _getTabString(pTabInfo1), Dimension_size) == 0 )
 		{
 			// Delete the tab.
-			_deleteTabFromTabString(pTabInfo);
+			_deleteTabFromTabString(pTabInfo1);
 			break;
 		}
 	}
@@ -370,7 +370,7 @@ void AP_Dialog_Tab::_event_Update(void)
 	FV_View *pView = static_cast<FV_View *>(m_pFrame->getCurrentView());
 	UT_return_if_fail(pView);
 	
-	buildTabStops(pView->getGraphics(), m_pszTabStops, m_tabInfo);
+	buildTabStops(m_pszTabStops, m_tabInfo);
 
 	_setTabList(m_tabInfo.getItemCount());
 
@@ -403,15 +403,13 @@ void AP_Dialog_Tab::_event_Clear(void)
 
 	if(index != -1)
 	{
-		UT_return_if_fail(index < static_cast<UT_sint32>(m_tabInfo.getItemCount()));
+		UT_return_if_fail(index < m_tabInfo.getItemCount());
 
 		_deleteTabFromTabString(m_tabInfo.getNthItem(index));
 
 		UT_return_if_fail(m_pFrame); // needs to be set from runModal for some of the event_'s to work
 
-		FV_View *pView = static_cast<FV_View *>(m_pFrame->getCurrentView());
-
-		buildTabStops(pView->getGraphics(), m_pszTabStops, m_tabInfo);
+		buildTabStops(m_pszTabStops, m_tabInfo);
 
 		_setTabList(m_tabInfo.getItemCount());
 
@@ -439,9 +437,7 @@ void AP_Dialog_Tab::_event_ClearAll(void)
 	delete [] m_pszTabStops;
 	m_pszTabStops = new char [1]; m_pszTabStops[0] = 0;
 
-	FV_View *pView = static_cast<FV_View *>(m_pFrame->getCurrentView());
-
-	buildTabStops(pView->getGraphics(), m_pszTabStops, m_tabInfo);
+	buildTabStops(m_pszTabStops, m_tabInfo);
 
 	_clearList();
 
@@ -561,7 +557,7 @@ void AP_Dialog_Tab::_event_somethingChanged()
 	}
 #endif
 
-	for ( UT_uint32 i = 0; i < m_tabInfo.getItemCount(); i++ )
+	for ( UT_sint32 i = 0; i < m_tabInfo.getItemCount(); i++ )
 	{
 		fl_TabStop *pTabInfo = m_tabInfo.getNthItem(i);
 		UT_return_if_fail (pTabInfo);
@@ -589,7 +585,7 @@ void AP_Dialog_Tab::_event_somethingChanged()
 
 }
 
-char *AP_Dialog_Tab::_getTabDimensionString(UT_uint32 tabIndex)
+char *AP_Dialog_Tab::_getTabDimensionString(UT_sint32 tabIndex)
 {
 
 	UT_return_val_if_fail (tabIndex < m_tabInfo.getItemCount(), NULL);
