@@ -18,6 +18,10 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 #include <stdio.h>
 
@@ -28,6 +32,7 @@
 #include "ut_debugmsg.h"
 #include "ut_string.h"
 #include "ap_LeftRuler.h"
+#include "xap_App.h"
 #include "xav_View.h"
 #include "gr_Graphics.h"
 #include "ap_FrameData.h"
@@ -86,7 +91,7 @@ AP_LeftRuler::AP_LeftRuler(XAP_Frame * pFrame)
 	// install top_ruler_prefs_listener as this lister for this func
 	XAP_App::getApp()->getPrefs()->addListener( AP_LeftRuler::_prefsListener, static_cast<void *>(this) );
 	m_lidLeftRuler = 9999999;
-	UT_DEBUGMSG(("Created LeftRuler %x lid is %d \n",this,m_lidLeftRuler));
+	UT_DEBUGMSG(("Created LeftRuler %p lid is %d \n",this,m_lidLeftRuler));
 }
 
 AP_LeftRuler::~AP_LeftRuler(void)
@@ -94,6 +99,7 @@ AP_LeftRuler::~AP_LeftRuler(void)
 	if(m_pView) 
 	{
 		// don't receive anymore scroll messages
+	  UT_DEBUGMSG(("Remove scroll listener %p \n",m_pScrollObj));
 		m_pView->removeScrollListener(m_pScrollObj);
 
 		// no more view messages
@@ -107,9 +113,9 @@ AP_LeftRuler::~AP_LeftRuler(void)
 	}
 	// no more prefs 
 	XAP_App::getApp()->getPrefs()->removeListener( AP_LeftRuler::_prefsListener, static_cast<void *>(this) );
-	UT_DEBUGMSG(("Deleted LeftRuler %x \n",this));
+	UT_DEBUGMSG(("Deleted LeftRuler %p \n",this));
 	m_lidLeftRuler = 0;
-	//UT_DEBUGMSG(("AP_LeftRuler::~AP_LeftRuler (this=%p scroll=%p)\n", this, m_pScrollObj));
+	UT_DEBUGMSG(("AP_LeftRuler::~AP_LeftRuler (this=%p scroll=%p)\n", this, m_pScrollObj));
 
 	DELETEP(m_pScrollObj);
 }
@@ -147,8 +153,11 @@ void AP_LeftRuler::setView(AV_View * pView)
 		// the actual on-screen widgets, we reuse it as documents
 		// change in the frame rather than recreating it with each
 		// view (as we do with some of the other objects).
-
 		DELETEP(m_pScrollObj);
+		if(m_lidLeftRuler !=  9999999)
+		{
+			m_pView->removeListener(m_lidLeftRuler);
+		}
 	}
 	
 	m_pView = pView;
@@ -157,9 +166,7 @@ void AP_LeftRuler::setView(AV_View * pView)
 	if (m_pScrollObj == NULL) 
 	{
 		m_pScrollObj = new AV_ScrollObj(this,_scrollFuncX,_scrollFuncY);
-	}
-	UT_ASSERT(m_pScrollObj);
-	m_pView->addScrollListener(m_pScrollObj);
+		m_pView->addScrollListener(m_pScrollObj);
 
 	// Register the LeftRuler as a ViewListeners on the View.
 	// This lets us receive notify events as the user interacts
@@ -167,7 +174,9 @@ void AP_LeftRuler::setView(AV_View * pView)
 	// us update the display as we move from block to block and
 	// from column to column.
 
-	m_pView->addListener(static_cast<AV_Listener *>(this),&m_lidLeftRuler);
+		m_pView->addListener(static_cast<AV_Listener *>(this),&m_lidLeftRuler);
+	}
+	UT_ASSERT(m_pScrollObj);
 
 	return;
 }
@@ -310,7 +319,7 @@ void AP_LeftRuler::mousePress(EV_EditModifierState /* ems */, EV_EditMouseButton
 
 /*****************************************************************/
 
-void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb, UT_sint32 x, UT_sint32 y)
+void AP_LeftRuler::mouseRelease(EV_EditModifierState /*ems*/, EV_EditMouseButton /*emb*/, UT_sint32 x, UT_sint32 y)
 {
 	if(m_pView == NULL)
 	{
@@ -320,17 +329,17 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 	{
 		return;
 	}
-	FV_View * pView = static_cast<FV_View *>(m_pView);
-	GR_Graphics * pG = pView->getGraphics();
+	FV_View * pView1 = static_cast<FV_View *>(m_pView);
+	GR_Graphics * pG = pView1->getGraphics();
 	if(pG == NULL)
 	{
 		return;
 	}
-	if(pView->getDocument() == NULL)
+	if(pView1->getDocument() == NULL)
 	{
 		return;
 	}
-	if(pView->getDocument()->isPieceTableChanging())
+	if(pView1->getDocument()->isPieceTableChanging())
 	{
 		return;
 	}
@@ -391,9 +400,9 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 
 	const gchar * properties[3];
 
-	bool hdrftr = pView->isHdrFtrEdit();
+	bool hdrftr = pView1->isHdrFtrEdit();
 
-	fl_HdrFtrShadow * pShadow = pView->getEditShadow();
+	fl_HdrFtrShadow * pShadow = pView1->getEditShadow();
 
 	bool hdr = (hdrftr && 
 				pShadow->getHdrFtrSectionLayout()->getHFType() < FL_HDRFTR_FOOTER);
@@ -402,7 +411,7 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 	{
 		hfType = pShadow->getHdrFtrSectionLayout()->getHFType();
 	}
-    PT_DocPosition insPos = pView->getPoint();
+    PT_DocPosition insPos = pView1->getPoint();
 	UT_sint32 iPage = -1;
 	fl_DocSectionLayout * pDSL = NULL;
 	if(pShadow)
@@ -427,7 +436,7 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 		{
 			UT_String sHeights;
 			UT_DEBUGMSG(("Release TOP Margin 1 \n"));
-			if(!(m_infoCache.m_mode == AP_LeftRulerInfo::TRI_MODE_FRAME) && !pView->isInFrame(pView->getPoint()))
+			if(!(m_infoCache.m_mode == AP_LeftRulerInfo::TRI_MODE_FRAME) && !pView1->isInFrame(pView1->getPoint()))
 			{
 				dyrel = tick.scalePixelDistanceToUnits(m_draggingCenter - yAbsTop);
 				UT_DEBUGMSG(("Release TOP Margin 1 Column \n"));
@@ -448,7 +457,7 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 				sHeights = pG->invertDimension(tick.dimType,dyrel);
 				properties[1] = sHeights.c_str();
 				properties[2] = NULL;
-				pView->setSectionFormat(properties);
+				pView1->setSectionFormat(properties);
 			}
 			else
 			{
@@ -511,11 +520,11 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 			}
 			_xorGuide(true);
 			m_draggingWhat = DW_NOTHING;
-			notify(pView, AV_CHG_HDRFTR);
-			pView->setPoint(insPos);
-			pView->notifyListeners(AV_CHG_MOTION | AV_CHG_HDRFTR );
-			pView->setPoint(insPos);
-			pView->ensureInsertionPointOnScreen();
+			notify(pView1, AV_CHG_HDRFTR);
+			pView1->setPoint(insPos);
+			pView1->notifyListeners(AV_CHG_MOTION | AV_CHG_HDRFTR );
+			pView1->setPoint(insPos);
+			pView1->ensureInsertionPointOnScreen();
 //
 // Put the point at the right point in the header/footer on the right page.
 //
@@ -528,12 +537,12 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 					UT_return_if_fail(pShadowC);
 					pShadow = pShadowC->getShadow();
 					UT_return_if_fail(pShadow);
-					pView->setHdrFtrEdit(pShadow);
+					pView1->setHdrFtrEdit(pShadow);
 				}
-				pView->setPoint(insPos);
-				pView->notifyListeners(AV_CHG_MOTION | AV_CHG_HDRFTR );
-				pView->setPoint(insPos);
-				pView->ensureInsertionPointOnScreen();
+				pView1->setPoint(insPos);
+				pView1->notifyListeners(AV_CHG_MOTION | AV_CHG_HDRFTR );
+				pView1->setPoint(insPos);
+				pView1->ensureInsertionPointOnScreen();
 			}
 
 			return;
@@ -542,7 +551,7 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 
 	case DW_BOTTOMMARGIN:
 		{
-			if(!(m_infoCache.m_mode == AP_LeftRulerInfo::TRI_MODE_FRAME) && !pView->isInFrame(pView->getPoint()))
+			if(!(m_infoCache.m_mode == AP_LeftRulerInfo::TRI_MODE_FRAME) && !pView1->isInFrame(pView1->getPoint()))
 			{
 
 				dyrel = tick.scalePixelDistanceToUnits(yEnd - m_draggingCenter);
@@ -564,7 +573,7 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 				UT_String sHeights = pG->invertDimension(tick.dimType,dyrel);
 				properties[1] = sHeights.c_str();
 				properties[2] = NULL;
-				pView->setSectionFormat(properties);
+				pView1->setSectionFormat(properties);
 			}
 			else
 			{
@@ -610,11 +619,11 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 			}
 			_xorGuide(true);
 			m_draggingWhat = DW_NOTHING;
-			notify(pView, AV_CHG_HDRFTR);
-			pView->setPoint(insPos);
-			pView->notifyListeners(AV_CHG_MOTION | AV_CHG_HDRFTR );
-			pView->setPoint(insPos);
-			pView->ensureInsertionPointOnScreen();
+			notify(pView1, AV_CHG_HDRFTR);
+			pView1->setPoint(insPos);
+			pView1->notifyListeners(AV_CHG_MOTION | AV_CHG_HDRFTR );
+			pView1->setPoint(insPos);
+			pView1->ensureInsertionPointOnScreen();
 //
 // Put the point at the right point in the header/footer on the right page.
 //
@@ -625,12 +634,12 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 				{
 					fp_ShadowContainer* pShadowC = pPage->getHdrFtrP(hfType);
 					pShadow = pShadowC->getShadow();
-					pView->setHdrFtrEdit(pShadow);
+					pView1->setHdrFtrEdit(pShadow);
 				}
-				pView->setPoint(insPos);
-				pView->notifyListeners(AV_CHG_MOTION | AV_CHG_HDRFTR );
-				pView->setPoint(insPos);
-				pView->ensureInsertionPointOnScreen();
+				pView1->setPoint(insPos);
+				pView1->notifyListeners(AV_CHG_MOTION | AV_CHG_HDRFTR );
+				pView1->setPoint(insPos);
+				pView1->ensureInsertionPointOnScreen();
 			}
 			return;
 		}
@@ -661,7 +670,7 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 //
 			if(m_infoCache.m_vecTableRowInfo == NULL)
 			{
-				pView->getLeftRulerInfo(m_draggingDocPos,&m_infoCache);
+				pView1->getLeftRulerInfo(m_draggingDocPos,&m_infoCache);
 				UT_ASSERT(m_infoCache.m_yTopMargin >= 0);
 
 				if(m_infoCache.m_vecTableRowInfo == NULL)
@@ -694,26 +703,26 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 //
 // Fill the heights string Now
 //
-			UT_uint32 i =0;
+			UT_sint32 i =0;
 			xxx_UT_DEBUGMSG(("Cell height set to %f for row %d  number item %d \n",dNewHeight,m_draggingCell,m_infoCache.m_vecTableRowInfo->getItemCount()));
-			AP_LeftRulerTableInfo * pTInfo =  NULL;
-			pTInfo = const_cast<AP_LeftRulerTableInfo *>(reinterpret_cast<const AP_LeftRulerTableInfo *>(m_infoCache.m_vecTableRowInfo->getNthItem(0)));
+			const AP_LeftRulerTableInfo * pTInfo =  NULL;
+			pTInfo = m_infoCache.m_vecTableRowInfo->getNthItem(0);
 			fp_TableContainer * pTab = static_cast<fp_TableContainer *>(pTInfo->m_pCell->getContainer());
 			fp_CellContainer * pCell = NULL;
-			posPrev =pTab->getYOfRow(0);  ;
+			posPrev =pTab->getYOfRow(0);
 			for(i=1;i<=m_infoCache.m_vecTableRowInfo->getItemCount();i++)
 			{
 				bool bLast = (m_infoCache.m_vecTableRowInfo->getItemCount() == i);
 				UT_sint32 iCurPos = 0;
 				if(!bLast)
 				{
-					pTInfo =  static_cast<AP_LeftRulerTableInfo *>(m_infoCache.m_vecTableRowInfo->getNthItem(i));
+					pTInfo = m_infoCache.m_vecTableRowInfo->getNthItem(i);
 					pCell = pTInfo->m_pCell;
 					iCurPos = pTab->getYOfRow(pCell->getTopAttach());
 				}
 				else
 				{
-					pTInfo =  static_cast<AP_LeftRulerTableInfo *>(m_infoCache.m_vecTableRowInfo->getNthItem(i-1));
+					pTInfo = m_infoCache.m_vecTableRowInfo->getNthItem(i-1);
 					pCell = pTInfo->m_pCell;
 					iCurPos = pTab->getYOfRow(pCell->getBottomAttach());
 				}
@@ -742,20 +751,20 @@ void AP_LeftRuler::mouseRelease(EV_EditModifierState ems, EV_EditMouseButton emb
 			}
 			xxx_UT_DEBUGMSG(("cell marker string is %s \n",sHeights.c_str()));
 			const char * props[3] = {"table-row-heights",sHeights.c_str(),NULL};
-			if(!pView->getDragTableLine())
+			if(!pView1->getDragTableLine())
 			{
-				pView->setTableFormat(props);
+				pView1->setTableFormat(props);
 			}
 			else
 			{
 				fl_SectionLayout * pSL = pCell->getSectionLayout();
 				fl_BlockLayout * pBL = static_cast<fl_BlockLayout *>(pSL->getFirstLayout());
 				PT_DocPosition pos = pBL->getPosition();
-				if(!pView->isInTable())
+				if(!pView1->isInTable())
 				{
-					pView->setPoint(pos);
+					pView1->setPoint(pos);
 				}
-				pView->setTableFormat(pos,props);
+				pView1->setTableFormat(pos,props);
 			}
 			m_draggingDocPos =0;
 			return;
@@ -849,13 +858,13 @@ void AP_LeftRuler::mouseMotion(EV_EditModifierState ems, UT_sint32 x, UT_sint32
 {
 	// The X and Y that are passed to this function are x and y on the application, not on the ruler.
 	xxx_UT_DEBUGMSG(("In Left mouseMotion \n"));
-	FV_View * pView = static_cast<FV_View *>(m_pView);
-	if(pView == NULL)
+	FV_View * pView1 = static_cast<FV_View *>(m_pView);
+	if(pView1 == NULL)
 	{
 		return;
 	}
-	GR_Graphics * pG = pView->getGraphics();
-	if(m_pG && pView->isLayoutFilling())
+	GR_Graphics * pG = pView1->getGraphics();
+	if(m_pG && pView1->isLayoutFilling())
 	{
 		if(m_pG)
 		{
@@ -863,17 +872,17 @@ void AP_LeftRuler::mouseMotion(EV_EditModifierState ems, UT_sint32 x, UT_sint32
 		}
 		return;
 	}
-	if(pView->getDocument() == NULL)
+	if(pView1->getDocument() == NULL)
 	{
 		return;
 	}
-	if(pView->getDocument()->isPieceTableChanging())
+	if(pView1->getDocument()->isPieceTableChanging())
 	{
 		return;
 	}
 	if(!m_bValidMouseClick)
 	{
-		pView->getLeftRulerInfo(&m_infoCache);
+		pView1->getLeftRulerInfo(&m_infoCache);
 	}
 	UT_ASSERT(m_infoCache.m_yTopMargin >= 0);
 
@@ -953,7 +962,7 @@ void AP_LeftRuler::mouseMotion(EV_EditModifierState ems, UT_sint32 x, UT_sint32
 	}		
 	m_bEventIgnored = false;
 
-	UT_DEBUGMSG(("mouseMotion: [ems 0x%08lx][x %ld][y %ld]\n",ems,x,y));
+	UT_DEBUGMSG(("mouseMotion: [ems 0x%08x][x %d][y %d]\n",(int)ems,x,y));
 	ap_RulerTicks tick(pG,m_dim);
 
 	// if they drag vertically off the ruler, we ignore the whole thing.
@@ -1149,7 +1158,7 @@ void AP_LeftRuler::mouseMotion(EV_EditModifierState ems, UT_sint32 x, UT_sint32
 
 /*****************************************************************/
 
-void AP_LeftRuler::_ignoreEvent(bool bDone)
+void AP_LeftRuler::_ignoreEvent(bool /*bDone*/)
 {
 	// user released the mouse off of the ruler.  we need to treat
 	// this as a cancel.  so we need to put everything back the
@@ -1160,7 +1169,7 @@ void AP_LeftRuler::_ignoreEvent(bool bDone)
 	_xorGuide(true);
 
 	// Clear messages from status bar.
-#if !defined(EMBEDDED_TARGET) || defined(EMBEDDED_STATUSBAR)
+#ifdef ENABLE_STATUSBAR
 	AP_FrameData * pFrameData = static_cast<AP_FrameData *>(m_pFrame->getFrameData());
 	if(m_pFrame->getFrameMode() == XAP_NormalFrame)
 	{
@@ -1341,7 +1350,7 @@ void AP_LeftRuler::_getMarginMarkerRects(AP_LeftRulerInfo * pInfo, UT_Rect &rTop
 }
 
 void AP_LeftRuler::_drawMarginProperties(const UT_Rect * /* pClipRect */,
-										AP_LeftRulerInfo * pInfo, GR_Graphics::GR_Color3D clr)
+										AP_LeftRulerInfo * pInfo, GR_Graphics::GR_Color3D /*clr*/)
 {
 	//FV_View *pView = static_cast<FV_View *>(m_pView);
 	//bool hdrftr = pView->isHdrFtrEdit();
@@ -1419,11 +1428,11 @@ void AP_LeftRuler::_getCellMarkerRects(AP_LeftRulerInfo * pInfo, UT_sint32 iCell
 
 	if(iCell < pInfo->m_iNumRows)
 	{
-		pLInfo = static_cast<AP_LeftRulerTableInfo *>(pInfo->m_vecTableRowInfo->getNthItem(iCell));
+		pLInfo = pInfo->m_vecTableRowInfo->getNthItem(iCell);
 	}
 	else
 	{
-		pLInfo = static_cast<AP_LeftRulerTableInfo *>(pInfo->m_vecTableRowInfo->getNthItem(pInfo->m_iNumRows -1));
+		pLInfo = pInfo->m_vecTableRowInfo->getNthItem(pInfo->m_iNumRows -1);
 	}
 
 //	UT_sint32 yOrigin = pInfo->m_yPageStart + pInfo->m_yTopMargin - m_yScrollOffset;
@@ -1506,15 +1515,15 @@ void AP_LeftRuler::_getCellMarkerRects(AP_LeftRulerInfo * pInfo, UT_sint32 iCell
 	} 
 	else
 	{
-		UT_sint32 imax = static_cast<UT_sint32>(pInfo->m_vecTableRowInfo->getItemCount());
+		UT_sint32 imax = pInfo->m_vecTableRowInfo->getItemCount();
 		AP_LeftRulerTableInfo * pKInfo = NULL;
 		if(iCell - 1 < imax)
 		{
-			pKInfo = static_cast<AP_LeftRulerTableInfo *>(pInfo->m_vecTableRowInfo->getNthItem(iCell-1));
+			pKInfo = pInfo->m_vecTableRowInfo->getNthItem(iCell-1);
 		}
 		else
 		{
-			pKInfo = static_cast<AP_LeftRulerTableInfo *>(pInfo->m_vecTableRowInfo->getNthItem(imax-1));
+			pKInfo = pInfo->m_vecTableRowInfo->getNthItem(imax-1);
 		}
 		bottomSpacing = pKInfo->m_iBotSpacing;
 	}
@@ -1566,6 +1575,7 @@ void AP_LeftRuler::_drawCellProperties(AP_LeftRulerInfo * pInfo)
 	{
 	  AP_LeftRulerTableInfo * pTInfo =  NULL;
 	  pTInfo = pInfo->m_vecTableRowInfo->getNthItem(0);
+	  UT_return_if_fail(pTInfo);
 	  fp_CellContainer * pCell = pTInfo->m_pCell;
 	  fp_Container * pHdr = pCell->getContainer();
 	  while(pHdr && !pHdr->isColumnType())
@@ -1618,7 +1628,7 @@ void AP_LeftRuler::_drawCellProperties(AP_LeftRulerInfo * pInfo)
 	xxx_UT_DEBUGMSG(("ap_LeftRuler: Draw Cell Marks end \n"));
 }
 
-void AP_LeftRuler::_drawCellMark(UT_Rect *prDrag, bool bUp)
+void AP_LeftRuler::_drawCellMark(UT_Rect *prDrag, bool /*bUp*/)
 {
 //
 // Draw square inside
@@ -1937,7 +1947,7 @@ void AP_LeftRuler::_xorGuide(bool bClear)
 	}
 }
 
-/*static*/ void AP_LeftRuler::_prefsListener( XAP_App * /*pApp*/, XAP_Prefs *pPrefs, UT_StringPtrMap * /*phChanges*/, void *data )
+void AP_LeftRuler::_prefsListener( XAP_Prefs *pPrefs, UT_StringPtrMap * /*phChanges*/, void *data )
 {
 	AP_LeftRuler *pLeftRuler = static_cast<AP_LeftRuler *>(data);
 	UT_ASSERT( data && pPrefs );
@@ -1961,7 +1971,7 @@ void AP_LeftRuler::setDimension( UT_Dimension newdim )
 
 void AP_LeftRuler::_displayStatusMessage(XAP_String_Id messageID, const ap_RulerTicks &tick, double dValue)
 {
-#if !defined(EMBEDDED_TARGET) || defined(EMBEDDED_STATUSBAR)
+#ifdef ENABLE_STATUSBAR
 	const gchar * pText = m_pG->invertDimension(tick.dimType, dValue);
 	char temp[100];
 	const gchar *pzMessageFormat = XAP_App::getApp()->getStringSet()->getValue(messageID);
