@@ -309,7 +309,7 @@ menuitem(WEB_SAVEASWEB)
 menuitem(HELP)
 menuitem(HELP_CREDITS)
 menuitem(HELP_CONTENTS)
-menuitem(HELP_INDEX)
+menuitem(HELP_INTRO)
 menuitem(HELP_CHECKVER)
 menuitem(HELP_SEARCH)
 menuitem(HELP_ABOUT)
