@@ -75,8 +75,8 @@ dcl(BottomMarginStatus, 		"Bottom Margin [%s]")
 dcl(HeaderStatus,				"Header [%s]")
 dcl(FooterStatus,				"Footer [%s]")
 dcl(ColumnStatus,               "Column [%d]")
-dcl(InsertModeFieldINS, 		"INS")
-dcl(InsertModeFieldOVR, 		"OVR")
+dcl(InsertModeFieldINS, 		"Insert")
+dcl(InsertModeFieldOVR, 		"Overwrite")
 
 /* */
 dcl(DLG_NEW_Title,			"New Document")
@@ -346,7 +346,7 @@ dcl(DLG_Column_RtlOrder,		"Use RTL Order")
    strings just like this to simulate text, and if your translation
    ends up very, very wordy, it will take up too much room in the preview.
 */
-dcl(DLG_Para_PreviewSampleFallback, "This paragraph represents words as they might appear in your document.  To see text from your document used in this preview, position your cursor in a document paragraph with some text in it and open this dialog.")
+dcl(DLG_Para_PreviewSampleFallback, "This paragraph represents words as they might appear in your document.  To see the text from your document used in this preview, position your cursor in a document paragraph with some text in it and open this dialog.")
 dcl(DLG_Para_PreviewPrevParagraph,	"Previous Paragraph Previous Paragraph Previous Paragraph Previous Paragraph Previous Paragraph Previous Paragraph Previous Paragraph")
 dcl(DLG_Para_PreviewFollowParagraph,"Following Paragraph Following Paragraph Following Paragraph Following Paragraph Following Paragraph Following Paragraph Following Paragraph")
 
@@ -439,6 +439,7 @@ dcl(DLG_Options_Label_CheckEnableSmoothScrolling, "Enable Smooth Scrolling")
 dcl(DLG_Options_Label_CheckWhiteForTransparent, "Allow screen colors other than white")
 dcl(DLG_Options_Label_ChooseForTransparent, "Choose Screen Color")
 dcl(DLG_Options_Label_ColorChooserLabel,	"Choose screen color for AbiWord")
+dcl(DLG_Options_Label_EnableOverwrite,      "&Enable overwrite mode toggle")
 dcl(DLG_Options_Label_InvalidRangeForAutoSave,	"You should choose a range from 1 to 120 for the auto save frequency")
 dcl(DLG_Options_Prompt_YouMustRestart,	"The new user interface language will take effect the next time that you start the application")
 
@@ -742,6 +743,7 @@ dcl(MSG_DirectionModeChg,	"You have changed the direction mode.")
 dcl(MSG_DefaultDirectionChg,"You have changed the default direction.")
 dcl(MSG_AfterRestartNew, "This change will only take effect when you restart AbiWord or create a new document.")
 dcl(MSG_BookmarkNotFound, "Bookmark \"%s\" was not found in this document.")
+dcl(MSG_BookmarkAlreadyExists, "This bookmark already exists. Would you like to replace the existing bookmark with this new one?")
 dcl(MSG_HyperlinkNoSelection, "You must select a portion of the document before inserting a hyperlink.")
 dcl(MSG_HyperlinkNoBookmark, "Warning: the bookmark you provided [%s] does not exist.")
 dcl(MSG_HyperlinkCrossesBoundaries, "The text to which the hyperlink is to be attached must be within a single paragraph.")
@@ -821,7 +823,7 @@ dcl(DLG_Annotation_Author_LBL, "Author:")
 dcl(DLG_Annotation_Description_LBL, "Description:")
 dcl(DLG_Annotation_Replace_LBL, "Replace")
 dcl(DLG_Annotation_OK_tooltip, "Update the annotation")
-dcl(DLG_Annotation_Replace_tooltip, "Replace selection with annotation")
+dcl(DLG_Annotation_Replace_tooltip, "Replace the annotated text with the annotation content")
 
 dcl(WORD_PassRequired, "Password required, this is an encrypted document")
 dcl(WORD_PassInvalid, "Incorrect Password")
@@ -952,6 +954,7 @@ dcl(MENU_LABEL_FMT_LANGUAGE,"Set &Language")
 dcl(MENU_LABEL_FMT_FONT,"&Font")
 dcl(MENU_LABEL_FMT_PARAGRAPH,"&Paragraph")
 dcl(MENU_LABEL_FMT_BULLETS,"Bullets and &Numbering")
+dcl(MENU_LABEL_TABLE_FORMAT, "&Table")
 dcl(MENU_LABEL_FMT_DOCUMENT,"&Document")
 dcl(MENU_LABEL_FMT_BORDERS,"Borders and Shading")
 dcl(MENU_LABEL_FMT_HDRFTR,"Header/Footers")
@@ -1052,7 +1055,6 @@ dcl(MENU_LABEL_TABLE_SELECT_CELL, "&Cell")
 dcl(MENU_LABEL_TABLE_MERGE_CELLS, "&Merge Cells")
 dcl(MENU_LABEL_TABLE_SPLIT_CELLS, "S&plit Cells")
 dcl(MENU_LABEL_TABLE_SPLIT_TABLE, "Spli&t Table")
-dcl(MENU_LABEL_TABLE_FORMAT, "&Format Table")
 dcl(MENU_LABEL_TABLE_AUTOFIT, "&Autofit Table")
 dcl(MENU_LABEL_TABLE_TEXTTOTABLE, "Convert Text to Table")
 dcl(MENU_LABEL_TABLE_TEXTTOTABLE_ALL, "Split text at spaces, commas, or tabs")
@@ -1098,7 +1100,7 @@ dcl(MENU_LABEL_WINDOW_MORE,"&More Documents")
 dcl(MENU_LABEL_HELP,"&Help")
 dcl(MENU_LABEL_HELP_CREDITS,"C&redits")
 dcl(MENU_LABEL_HELP_CONTENTS,"Help &Contents")
-dcl(MENU_LABEL_HELP_INDEX,"Help &Introduction")
+dcl(MENU_LABEL_HELP_INTRO,"Help &Introduction")
 dcl(MENU_LABEL_HELP_CHECKVER,"Check for &Updates")
 dcl(MENU_LABEL_HELP_SEARCH,"&Search for Help")
 dcl(MENU_LABEL_HELP_ABOUT,"&About %s")
@@ -1374,7 +1376,7 @@ dcl(MENU_STATUSLINE_WINDOW_MORE,"Show full list of documents")
 dcl(MENU_STATUSLINE_HELP," ")
 dcl(MENU_STATUSLINE_HELP_CREDITS,"Display Credits")
 dcl(MENU_STATUSLINE_HELP_CONTENTS,"Display Help Contents")
-dcl(MENU_STATUSLINE_HELP_INDEX,"Display Help Index")
+dcl(MENU_STATUSLINE_HELP_INTRO,"Display Help Introduction")
 dcl(MENU_STATUSLINE_HELP_CHECKVER,"Check online for newer versions of AbiWord")
 dcl(MENU_STATUSLINE_HELP_SEARCH,"Search for help about...")
 dcl(MENU_STATUSLINE_HELP_ABOUT,"Display program information, version number, and copyright" )
