@@ -41,7 +41,6 @@ current table via ie_Table::get* methods.
 
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
-#include "ut_exception.h"
 #include "ut_string.h"
 #include "ut_string_class.h"
 #include "ut_units.h"
@@ -319,6 +318,7 @@ ie_Table::ie_Table(PD_Document * pDoc) :
 
 ie_Table::ie_Table(void) :
 	m_pDoc(NULL),
+	m_bNewRow(false),
 	m_sdhLastCell(NULL)
 {
 	m_sLastTable.push(NULL);
@@ -329,10 +329,10 @@ ie_Table::ie_Table(void) :
  */
 ie_Table::~ie_Table(void)
 {
-	while(m_sLastTable.getDepth() > 1)
+	while(m_sLastTable.size() > 1)
 	{
-		ie_PartTable * pPT = NULL;
-		m_sLastTable.pop(reinterpret_cast<void **>(&pPT));
+		ie_PartTable * pPT = m_sLastTable.top();
+		m_sLastTable.pop();
 		delete pPT;
 	}
 }
@@ -344,10 +344,10 @@ void ie_Table::setDoc(PD_Document * pDoc)
 {
 	m_pDoc = pDoc;
 	m_sdhLastCell = NULL;
-	while(m_sLastTable.getDepth() > 1)
+	while(m_sLastTable.size() > 1)
 	{
-		ie_PartTable * pPT = NULL;
-		m_sLastTable.pop(reinterpret_cast<void **>(&pPT));
+		ie_PartTable * pPT = m_sLastTable.top();
+		m_sLastTable.pop();
 		delete pPT;
 	}
 }
@@ -359,7 +359,7 @@ void ie_Table::OpenTable(PL_StruxDocHandle tableSDH, PT_AttrPropIndex iApi)
 {
 	ie_PartTable * pPT = new ie_PartTable(m_pDoc);
 	m_sdhLastCell = NULL;
-	m_sLastTable.push(reinterpret_cast<void *>(pPT));
+	m_sLastTable.push(pPT);
 	pPT->setTableApi(tableSDH,iApi);
 }
 
@@ -368,9 +368,7 @@ void ie_Table::OpenTable(PL_StruxDocHandle tableSDH, PT_AttrPropIndex iApi)
  */ 
 void ie_Table::OpenCell(PT_AttrPropIndex iApi)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
-
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_if_fail(pPT != NULL);
 
 	UT_sint32 iOldTop = pPT->getTop();
@@ -393,15 +391,13 @@ bool ie_Table::isNewRow(void)
 
 bool ie_Table::isCellJustOpenned(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	return pPT->isCellJustOpenned();
 }
 
 void ie_Table::setCellJustOpenned(bool b)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	pPT->setCellJustOpenned(b);
 }
 
@@ -410,8 +406,7 @@ void ie_Table::setCellJustOpenned(bool b)
  */
 PL_StruxDocHandle ie_Table::getTableSDH(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	if(pPT)
 	{
 		return pPT->getTableSDH();
@@ -424,8 +419,7 @@ PL_StruxDocHandle ie_Table::getTableSDH(void)
  */
 void ie_Table::CloseCell(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	pPT->setCellApi(0);
 }
 
@@ -435,8 +429,8 @@ void ie_Table::CloseCell(void)
  */
 void ie_Table::CloseTable(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.pop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
+	m_sLastTable.pop();
 	delete pPT;
 	m_sdhLastCell = NULL;
 }
@@ -447,8 +441,7 @@ void ie_Table::CloseTable(void)
  */
 UT_sint32 ie_Table::getPrevNumRightMostVMerged(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	xxx_UT_DEBUGMSG(("PrevRight %d curRight %d \n",pPT->getPrevRight(),pPT->getRight()));
 	UT_sint32 num = pPT->getNumCols() - pPT->getPrevRight();
 	return num;
@@ -460,9 +453,7 @@ UT_sint32 ie_Table::getPrevNumRightMostVMerged(void)
  */
 UT_sint32 ie_Table::getCurRow(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
-
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT != NULL, 0);
 
 	return pPT->getCurRow();
@@ -473,8 +464,7 @@ UT_sint32 ie_Table::getCurRow(void)
  */
 void ie_Table::incCurRow(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	pPT->incCurRow();
 }
 
@@ -484,8 +474,7 @@ void ie_Table::incCurRow(void)
  */
 UT_sint32 ie_Table::getLeft(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,0);
 	return pPT->getLeft();
 }
@@ -496,8 +485,7 @@ UT_sint32 ie_Table::getLeft(void)
  */
 UT_sint32 ie_Table::getRight(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,0);
 	return pPT->getRight();
 }
@@ -508,8 +496,7 @@ UT_sint32 ie_Table::getRight(void)
  */
 UT_sint32 ie_Table::getTop(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,0);
 	return pPT->getTop();
 }
@@ -519,8 +506,7 @@ UT_sint32 ie_Table::getTop(void)
  */
 UT_sint32 ie_Table::getBot(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,0);
 	return pPT->getBot();
 }
@@ -530,8 +516,7 @@ UT_sint32 ie_Table::getBot(void)
  */
 UT_sint32 ie_Table::getNumRows(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,0);
 	return pPT->getNumRows();
 }
@@ -543,8 +528,7 @@ UT_sint32 ie_Table::getNumRows(void)
  */
 UT_sint32 ie_Table::getNumCols(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,0);
 	return pPT->getNumCols();
 }
@@ -556,7 +540,7 @@ UT_sint32 ie_Table::getNumCols(void)
  */
 UT_sint32 ie_Table::getNestDepth(void)
 {
-	return m_sLastTable.getDepth() -1;
+	return m_sLastTable.size() - 1;
 }
 
 
@@ -565,8 +549,7 @@ UT_sint32 ie_Table::getNestDepth(void)
  */
  PT_AttrPropIndex ie_Table::getTableAPI(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,0);
 	return pPT->getTableAPI();
 }
@@ -576,8 +559,7 @@ UT_sint32 ie_Table::getNestDepth(void)
  */
  PT_AttrPropIndex ie_Table::getCellAPI(void)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,0);
 	return pPT->getCellAPI();
 }
@@ -588,8 +570,7 @@ UT_sint32 ie_Table::getNestDepth(void)
  */
 const char * ie_Table::getTableProp(const char * pProp)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,NULL);
 	return pPT->getTableProp(pProp);
 }
@@ -600,8 +581,7 @@ const char * ie_Table::getTableProp(const char * pProp)
  */
 const char * ie_Table::getCellProp(const char * pProp)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_val_if_fail(pPT,NULL);
 	return pPT->getCellProp(pProp);
 }
@@ -611,8 +591,7 @@ const char * ie_Table::getCellProp(const char * pProp)
 */
 void ie_Table::setCellRowCol(UT_sint32 row, UT_sint32 col)
 {
-	ie_PartTable * pPT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pPT));
+	ie_PartTable * pPT = m_sLastTable.top();
 	UT_return_if_fail(pPT);
 	PL_StruxDocHandle sdhStart = m_sdhLastCell;
 	if(sdhStart == NULL)
@@ -922,7 +901,7 @@ UT_sint32 ie_imp_table::OpenCell(void)
 	m_pCurImpCell = pNewCell;
 	m_vecCells.addItem(pNewCell);
 	UT_sint32 count =0;
-	UT_sint32 i = static_cast<UT_sint32>(m_vecCells.getItemCount()) - 1;
+	UT_sint32 i = m_vecCells.getItemCount() - 1;
 	while((pNewCell->getRow() == m_iRowCounter) && (i>= 0))
 	{
 		pNewCell = m_vecCells.getNthItem(i);
@@ -946,7 +925,7 @@ bool ie_imp_table::getVecOfCellsOnRow(UT_sint32 row, UT_GenericVector<ie_imp_cel
 	ie_imp_cell * pCell = NULL;
 	bool bFound = false;
 	UT_sint32 iFound = 0;
-	for(i=0; !bFound && (i < static_cast<UT_sint32>(m_vecCells.getItemCount())); i++)
+	for(i=0; !bFound && (i < m_vecCells.getItemCount()); i++)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		if(pCell->getRow() == row)
@@ -960,7 +939,7 @@ bool ie_imp_table::getVecOfCellsOnRow(UT_sint32 row, UT_GenericVector<ie_imp_cel
 		return bFound;
 	}
 	bool bEnd = false;
-	for(i=iFound; !bEnd && (i<static_cast<UT_sint32>(m_vecCells.getItemCount())); i++)
+	for(i=iFound; !bEnd && (i<m_vecCells.getItemCount()); i++)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		if(pCell->getRow() != row)
@@ -1024,8 +1003,8 @@ UT_sint32 ie_imp_table::NewRow(void)
 		vecCur.clear();
 		getVecOfCellsOnRow(m_iRowCounter-1, &vecPrev);
 		getVecOfCellsOnRow(m_iRowCounter, &vecCur);
-		UT_sint32 szPrevRow = static_cast<UT_sint32>(vecPrev.getItemCount());
-		UT_sint32 szCurRow = static_cast<UT_sint32>(vecCur.getItemCount());
+		UT_sint32 szPrevRow = vecPrev.getItemCount();
+		UT_sint32 szCurRow = vecCur.getItemCount();
 //
 // Look if this row is just a copy of the previous. We decide this if there
 // are no values of cellX set.
@@ -1063,7 +1042,7 @@ UT_sint32 ie_imp_table::NewRow(void)
 			UT_DEBUGMSG(("Cur cell %d cellx %d \n",i,curX));
 			bool bMatch = false;
 			UT_sint32 j = 0;
-			for(j=0; !bMatch && (j < static_cast<UT_sint32>(m_vecCellX.getItemCount())); j++)
+			for(j=0; !bMatch && (j < m_vecCellX.getItemCount()); j++)
 			{
 				UT_sint32 prevX = m_vecCellX.getNthItem(j);
 				UT_DEBUGMSG(("Prev cell %d cellx %d \n",j,prevX));
@@ -1116,7 +1095,7 @@ void ie_imp_table::setCellRowNthCell(UT_sint32 row, UT_sint32 col)
 	ie_imp_cell * pCell = NULL;
 	UT_sint32 ColCount = 0;
 	bool bFound = false;
-	for(i=0; !bFound && (i < static_cast<UT_sint32>(m_vecCells.getItemCount())); i++)
+	for(i=0; !bFound && (i < m_vecCells.getItemCount()); i++)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		if(pCell->getRow() == row)
@@ -1214,7 +1193,7 @@ void ie_imp_table::writeTablePropsInDoc(void)
 //
 		UT_String sColWidth;
 		sColWidth.clear();
-		for(i=0; i< static_cast<UT_sint32>(m_vecCellX.getItemCount()); i++)
+		for(i=0; i< m_vecCellX.getItemCount(); i++)
 		{
 			UT_sint32 iCellx = m_vecCellX.getNthItem(i);
 			xxx_UT_DEBUGMSG(("final cellx import cellx %d iPrev %x \n",iCellx,iPrev));
@@ -1241,7 +1220,7 @@ void ie_imp_table::writeAllCellPropsInDoc(void)
 #if DEBUG
 	ie_imp_cell * pOldCell = NULL;
 #endif
-	for(i=0; i< static_cast<UT_sint32>(m_vecCells.getItemCount());i++)
+	for(i=0; i< m_vecCells.getItemCount();i++)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		if(!pCell->isMergedAbove() && !pCell->isMergedRight() && !pCell->isMergedLeft())
@@ -1252,7 +1231,7 @@ void ie_imp_table::writeAllCellPropsInDoc(void)
 				//				removeOnThisCellRow(pCell);
 				continue;
 			}
-			UT_DEBUGMSG(("writeallcellprops: pCell %d row %d left %d right %d top %d bot %d sdh %x \n",i,pCell->getRow(),pCell->getLeft(),pCell->getRight(),pCell->getTop(),pCell->getBot(),pCell->getCellSDH())); 
+			UT_DEBUGMSG(("writeallcellprops: pCell %d row %d left %d right %d top %d bot %d sdh %p \n",i,pCell->getRow(),pCell->getLeft(),pCell->getRight(),pCell->getTop(),pCell->getBot(),pCell->getCellSDH())); 
 		}
 		if(pCell->isMergedAbove() && (pCell->getCellSDH() != NULL))
 		{
@@ -1401,7 +1380,7 @@ void ie_imp_table::_buildCellXVector(void)
 	m_vecCellX.clear();
 	UT_sint32 i =0;
 	ie_imp_cell * pCell = NULL;
-	for(i=0; i< static_cast<UT_sint32>(m_vecCells.getItemCount()); i++)
+	for(i=0; i< m_vecCells.getItemCount(); i++)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		UT_sint32 cellx = pCell->getCellX();
@@ -1423,7 +1402,7 @@ UT_sint32 ie_imp_table::getColNumber(ie_imp_cell * pImpCell)
 	bool bFound = false;
 	UT_sint32 iFound = 0;
 	UT_sint32 iSub = 0;
-	for(i=0; !bFound && (i< static_cast<UT_sint32>(m_vecCellX.getItemCount())); i++)
+	for(i=0; !bFound && (i< m_vecCellX.getItemCount()); i++)
 	{
 		UT_sint32 icellx = m_vecCellX.getNthItem(i);
 		if(icellx == -1)
@@ -1449,7 +1428,7 @@ ie_imp_cell *  ie_imp_table::getCellAtRowColX(UT_sint32 iRow,UT_sint32 cellX)
 	UT_sint32 i = 0;
 	ie_imp_cell * pCell = NULL;
 	bool bfound = false;
-	for(i=0; i< static_cast<UT_sint32>(m_vecCells.getItemCount()); i++)
+	for(i=0; i< m_vecCells.getItemCount(); i++)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		UT_sint32 icellx = pCell->getCellX();
@@ -1492,7 +1471,7 @@ void ie_imp_table::buildTableStructure(void)
 	UT_sint32 iTop=0;
 	UT_sint32 iBot=0;
 
-	for(i=0; i< static_cast<UT_sint32>(m_vecCells.getItemCount()); i++)
+	for(i=0; i< m_vecCells.getItemCount(); i++)
 	{
 		bool bSkipThis = false;
 		pCell = m_vecCells.getNthItem(i);
@@ -1583,7 +1562,7 @@ UT_sint32  ie_imp_table::getNumRows(void)
 	UT_sint32 numrows = 0;
 	UT_sint32 i =0;
 	ie_imp_cell * pCell = NULL;
-	for(i= static_cast<UT_sint32>(m_vecCells.getItemCount()) -1; i >=0 ; i--)
+	for(i= m_vecCells.getItemCount() -1; i >=0 ; i--)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		if(pCell->getRow() > numrows)
@@ -1612,7 +1591,7 @@ void ie_imp_table::deleteRow(UT_sint32 row)
 	ie_imp_cell * pCell = NULL;
 	UT_DEBUGMSG(("Deleting row %d \n",row));
 	m_iPosOnRow = 0;
-	for(i= static_cast<UT_sint32>(m_vecCells.getItemCount()) -1; i>=0; i--)
+	for(i= m_vecCells.getItemCount() -1; i>=0; i--)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		UT_DEBUGMSG(("Look at Cell %d row %d cellx %d \n",i,pCell->getRow(),pCell->getCellX()));
@@ -1660,7 +1639,7 @@ void ie_imp_table::deleteRow(UT_sint32 row)
 		PL_StruxDocHandle sdhMyEnd= m_pDoc->getEndCellStruxFromCellSDH(sdhCell);
 		if((sdhMyEnd != NULL) && (sdhEndCell != sdhMyEnd))
 		{
-			UT_DEBUGMSG(("Delete extraneous endCell strux 1 sdhEndCell %x sdhMyEnd %x \n",sdhEndCell,sdhMyEnd));
+			UT_DEBUGMSG(("Delete extraneous endCell strux 1 sdhEndCell %p sdhMyEnd %p \n",sdhEndCell,sdhMyEnd));
 			m_pDoc->deleteStruxNoUpdate(sdhEndCell);
 			m_pDoc->appendStrux(PTX_Block,NULL);
 		}
@@ -1704,7 +1683,7 @@ void ie_imp_table::removeExtraneousCells(void)
 {
 	UT_sint32 i =0;
 	ie_imp_cell * pCell = NULL;
-	for(i= static_cast<UT_sint32>(m_vecCells.getItemCount()) -1; i >=0 ; i--)
+	for(i= m_vecCells.getItemCount() -1; i >=0 ; i--)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		if(pCell->getCellX() == -1 && (pCell->getCellSDH() != NULL))
@@ -1725,18 +1704,18 @@ void ie_imp_table::_removeAllStruxes(void)
 {
 	UT_sint32 i =0;
 	ie_imp_cell * pCell = NULL;
-	for(i= static_cast<UT_sint32>(m_vecCells.getItemCount()) -1; i >=0 ; i--)
+	for(i= m_vecCells.getItemCount() -1; i >=0 ; i--)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		if(pCell->getCellSDH())
 		{
-			UT_DEBUGMSG(("SEVIOR: Removing cell strux %x from PT \n",pCell->getCellSDH())); 
+			UT_DEBUGMSG(("SEVIOR: Removing cell strux %p from PT \n",pCell->getCellSDH())); 
 			m_pDoc->deleteStruxNoUpdate(pCell->getCellSDH());
 		}
 	}
 	if(m_tableSDH)
 	{
-		UT_DEBUGMSG(("SEVIOR: Removing table strux %x from PT \n",m_tableSDH)); 
+		UT_DEBUGMSG(("SEVIOR: Removing table strux %p from PT \n",m_tableSDH)); 
 		m_pDoc->deleteStruxNoUpdate(m_tableSDH);
 	}
 }
@@ -1751,7 +1730,7 @@ bool ie_imp_table::removeRow(UT_sint32 row)
 	UT_sint32 iFound =0;
 	bool bFound = false;
 	ie_imp_cell * pCell = NULL;
-	for(i=0; !bFound &&  (i< static_cast<UT_sint32>(m_vecCells.getItemCount())); i++)
+	for(i=0; !bFound &&  (i< m_vecCells.getItemCount()); i++)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		bFound = (pCell->getRow() == row);
@@ -1762,11 +1741,11 @@ bool ie_imp_table::removeRow(UT_sint32 row)
 		return false;
 	}
 	i = iFound;
-	while(pCell != NULL && i < static_cast<UT_sint32>(m_vecCells.getItemCount()))
+	while(pCell != NULL && i < m_vecCells.getItemCount())
 	{
-		xxx_UT_DEBUGMSG(("SEVIOR: Removing cell %x from row %d \n",pCell,row));
+		xxx_UT_DEBUGMSG(("SEVIOR: Removing cell %p from row %d \n",pCell,row));
 		m_vecCells.deleteNthItem(i);
-		if(i<static_cast<UT_sint32>(m_vecCells.getItemCount()))
+		if(i<m_vecCells.getItemCount())
 		{
 			pCell = m_vecCells.getNthItem(i);
 			if(pCell->getRow() != row)
@@ -1792,7 +1771,7 @@ void ie_imp_table::appendRow(UT_GenericVector<ie_imp_cell*>* pVecRowOfCells)
 	}
 	UT_sint32 i =0;
 	ie_imp_cell * pCell = NULL;
-	for(i=0; i <static_cast<UT_sint32>(pVecRowOfCells->getItemCount()); i++)
+	for(i=0; i <pVecRowOfCells->getItemCount(); i++)
 	{
 		pCell = pVecRowOfCells->getNthItem(i);
 		pCell->setImpTable(this);
@@ -1812,7 +1791,7 @@ ie_imp_cell * ie_imp_table::getNthCellOnRow(UT_sint32 iCell)
 	UT_sint32 iCellOnRow =0;
 	UT_sint32 i=0;
 	bool bFound = false;
-	for(i=0; !bFound &&  (i< static_cast<UT_sint32>(m_vecCells.getItemCount())); i++)
+	for(i=0; !bFound &&  (i< m_vecCells.getItemCount()); i++)
 	{
 		pCell = m_vecCells.getNthItem(i);
 		if(pCell->getRow() == m_iRowCounter)
@@ -1845,10 +1824,10 @@ ie_imp_table_control::ie_imp_table_control(PD_Document * pDoc):
 
 ie_imp_table_control::~ie_imp_table_control(void)
 {
-	while(m_sLastTable.getDepth() > 1)
+	while(m_sLastTable.size() > 1)
 	{
-		ie_imp_table * pT = NULL;
-		m_sLastTable.pop(reinterpret_cast<void **>(&pT));
+		ie_imp_table * pT = m_sLastTable.top();
+		m_sLastTable.pop();
 		if(pT->wasTableUsed())
 		{
 //			pT->removeExtraneousCells();
@@ -1856,34 +1835,32 @@ ie_imp_table_control::~ie_imp_table_control(void)
 			pT->writeTablePropsInDoc();
 			pT->writeAllCellPropsInDoc();
 		}			
-		UT_DEBUGMSG(("SEVIOR: Deleting table %x \n",pT));
+		UT_DEBUGMSG(("SEVIOR: Deleting table %p \n",pT));
 		delete pT;
 	}
 }
 
 UT_sint32 ie_imp_table_control::getNestDepth(void)
 {
-	return m_sLastTable.getDepth() -1;
+	return m_sLastTable.size() - 1;
 }
 
 void ie_imp_table_control::OpenTable(void)
 {
-	ie_imp_table * pT = new ie_imp_table(m_pDoc);
-	m_sLastTable.push(static_cast<void *>(pT));
+	m_sLastTable.push(new ie_imp_table(m_pDoc));
 }
 
 
 UT_sint32 ie_imp_table_control::OpenCell(void)
 {
-	ie_imp_table * pT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pT));
+	ie_imp_table * pT = m_sLastTable.top();
 	return pT->OpenCell();
 }
 
 void ie_imp_table_control::CloseTable(void)
 {
-	ie_imp_table * pT = NULL;
-	m_sLastTable.pop(reinterpret_cast<void **>(&pT));
+	ie_imp_table * pT = m_sLastTable.top();
+	m_sLastTable.pop();
 	if(pT->wasTableUsed())
 	{
 //		pT->removeExtraneousCells();
@@ -1897,15 +1874,13 @@ void ie_imp_table_control::CloseTable(void)
 
 void ie_imp_table_control::CloseCell(void)
 {
-	ie_imp_table * pT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pT));
+	ie_imp_table * pT = m_sLastTable.top();
 	pT->CloseCell();
 }
 
 ie_imp_table *  ie_imp_table_control::getTable(void)
 {
-	ie_imp_table * pT = NULL;
-	m_sLastTable.viewTop(reinterpret_cast<void **>(&pT));
+	ie_imp_table * pT = m_sLastTable.top();
 	return pT;
 }
 
@@ -1949,7 +1924,7 @@ bool ie_imp_table_control::NewRow(void)
 	ie_imp_cell * pCell = NULL;
 	bool bFound = false;
 	bool bAuto = false;
-	for(i=0; i < static_cast<UT_sint32>(vecRow.getItemCount()) && !bFound;i++)
+	for(i=0; i < vecRow.getItemCount() && !bFound;i++)
 	{
 		pCell = vecRow.getNthItem(i);
 		if(pCell->getCellSDH())
@@ -2041,7 +2016,7 @@ IE_Imp_TableHelper::IE_Imp_TableHelper (PD_Document * pDocument, pf_Frag_Strux *
 	m_thead.clear();
 	m_tfoot.clear();
 	m_tbody.clear();
-	UT_DEBUGMSG(("TableHelper created document = %x \n",m_pDocument)); 
+	UT_DEBUGMSG(("TableHelper created document = %p \n",m_pDocument)); 
 }
 
 IE_Imp_TableHelper::~IE_Imp_TableHelper ()
@@ -2284,7 +2259,7 @@ void IE_Imp_TableHelper::padRowWithCells(UT_GenericVector<CellHelper *>& vecCell
 	CellHelper * pCell = NULL;
 	UT_sint32 i =0;
 	bool bFoundRow = false;
-	for(i= static_cast<UT_sint32>(vecCells.getItemCount()-1); i>=0;i--)
+	for(i= vecCells.getItemCount()-1; i>=0;i--)
 		{
 			pCell = vecCells.getNthItem(i);
 			if(pCell->m_top == row)
@@ -2331,7 +2306,7 @@ CellHelper * IE_Imp_TableHelper::getCellAtRowCol(UT_GenericVector<CellHelper *>
 {
 	CellHelper * pCell = NULL;
 	UT_sint32 i =0;
-	for(i= static_cast<UT_sint32>(vecCells.getItemCount()-1); i>=0;i--)
+	for(i=vecCells.getItemCount()-1; i>=0;i--)
 		{
 			pCell = vecCells.getNthItem(i);
 			if((pCell->m_left <= col) && (pCell->m_right > col) && (pCell->m_top == row))
@@ -2464,7 +2439,7 @@ bool IE_Imp_TableHelper::tdEnd(void)
 			pVecCells->addItem(m_current);
 			return false;
 		}
-	if(iPrev == static_cast<UT_sint32>(pVecCells->getItemCount()))
+	if(iPrev == pVecCells->getItemCount())
 		{
 			pVecCells->addItem(m_current);
 			return true;
@@ -2481,7 +2456,7 @@ bool IE_Imp_TableHelper::tdPending ()
 }
 
 
-bool IE_Imp_TableHelper::Block (PTStruxType pts, const gchar ** attributes)
+bool IE_Imp_TableHelper::Block (PTStruxType /*pts*/, const gchar ** attributes)
 {
 	pf_Frag * pf = NULL;
 	if(m_bCaptionOn)
@@ -2621,7 +2596,7 @@ IE_Imp_TableHelperStack::IE_Imp_TableHelperStack (void) :
 	m_max(0),
 	m_stack(0)
 {
-	UT_DEBUGMSG(("TableHelperStack created document = %x \n",m_pDocument)); 
+	UT_DEBUGMSG(("TableHelperStack created document = %p \n",m_pDocument)); 
 }
 
 IE_Imp_TableHelperStack::~IE_Imp_TableHelperStack ()
@@ -2664,7 +2639,7 @@ bool IE_Imp_TableHelperStack::push (const char * style)
 	IE_Imp_TableHelper * th = 0;
 
 	// TODO: not sure this needs to happen...
-	UT_TRY
+	try
 		{
 			IE_Imp_TableHelper * prev = top();
 			pf_Frag_Strux * pfs = NULL;
@@ -2674,11 +2649,10 @@ bool IE_Imp_TableHelperStack::push (const char * style)
 			}
 			th = new IE_Imp_TableHelper(m_pDocument,pfs,style);
 		}
-	UT_CATCH(UT_CATCH_ANY)
+    catch(...)
 		{
 			th = 0;
 		}
-	UT_END_CATCH
 
 	if (th == 0)
 		return false;
