@@ -481,11 +481,12 @@ void s_AbiWord_1_Listener::_openTag(const char * szPrefix, const char * szSuffix
 #else /* ENABLE_RESOURCE_MANAGER */
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
-	UT_DEBUGMSG(("_openTag: api %d, bHaveProp %d\n",api, bHaveProp));
-	m_pie->write("<");
+	xxx_UT_DEBUGMSG(("_openTag: api %d, bHaveProp %d\n",api, bHaveProp));
 
 	UT_return_if_fail(szPrefix && *szPrefix);
 
+	m_pie->write("<");
+
 	if(strcmp(szPrefix,"c")== 0)
 		m_bOpenChar = true;
 	m_pie->write(szPrefix);
@@ -1392,13 +1393,13 @@ void s_AbiWord_1_Listener::_handleStyles(void)
 
 	UT_GenericVector<PD_Style*> * pStyles = NULL;
 	m_pDocument->enumStyles(pStyles);
-	UT_return_if_fail( pStyles );
+	UT_ASSERT_HARMLESS( pStyles );
 	UT_sint32 iStyleCount = m_pDocument->getStyleCount();
 	
-	for (k=0; k < iStyleCount; k++)
+	for (k=0; (k < iStyleCount) && pStyles; k++)
 	{
 		pStyle = pStyles->getNthItem(k);
-		UT_return_if_fail( pStyle );
+		UT_continue_if_fail( pStyle );
 		
 		if (!pStyle->isUserDefined() || (vecStyles.findItem(const_cast<PD_Style*>(pStyle))) >= 0)
 			continue;
@@ -1567,8 +1568,7 @@ void s_AbiWord_1_Listener::_handleDataItems(void)
 	bool bWroteOpenDataSection = false;
 
 	const char * szName;
-   	const char * szMimeType;
-   	const char ** pszMimeType = &szMimeType;
+    std::string mimeType;
 	const UT_ByteBuf * pByteBuf;
 
 	UT_ByteBuf bbEncoded(1024);
@@ -1576,7 +1576,7 @@ void s_AbiWord_1_Listener::_handleDataItems(void)
 	UT_DEBUGMSG(("Used images are... \n"));
 	for (UT_uint32 k=0;
 		 
-		 (m_pDocument->enumDataItems(k,NULL,&szName,&pByteBuf,reinterpret_cast<const void**>(pszMimeType)));
+		 (m_pDocument->enumDataItems(k, NULL, &szName, &pByteBuf, &mimeType));
 		 k++)
 	{
 		string_set::iterator it(m_pUsedImages.find(szName));
@@ -1601,7 +1601,9 @@ void s_AbiWord_1_Listener::_handleDataItems(void)
 	   	bool status = false;
 	   	bool encoded = true;
 
-		if (szMimeType && (strcmp(szMimeType, "image/svg+xml") == 0 || strcmp(szMimeType, "application/mathml+xml") == 0))
+		if (!mimeType.empty() 
+            && ((mimeType ==  "image/svg+xml") 
+                || (mimeType == "application/mathml+xml")))
 	    {
 		   bbEncoded.truncate(0);
 		   bbEncoded.append(reinterpret_cast<const UT_Byte*>("<![CDATA["), 9);
@@ -1638,10 +1640,10 @@ void s_AbiWord_1_Listener::_handleDataItems(void)
 			// That's not really a good assumption, but, hey.
 			// TODO: make szName, szMimeType be UT_gchars.
 			_outputXMLChar(szName, strlen(szName));
-		   	if (szMimeType)
+		   	if (!mimeType.empty())
 			{
 			   m_pie->write("\" mime-type=\"");
-			   _outputXMLChar(szMimeType, strlen(szMimeType));
+			   _outputXMLChar(mimeType.c_str(), mimeType.size());
 			}
 		   	if (encoded)
 		    {
@@ -1685,7 +1687,7 @@ void s_AbiWord_1_Listener::_handleRevisions(void)
 	for (k=0; k < vRevisions.getItemCount(); k++)
 	{
 		pRev = vRevisions.getNthItem(k);
-		UT_return_if_fail(pRev);
+		UT_continue_if_fail(pRev);
 		
 		UT_String s;
 		
